@@ -1,5 +1,5 @@
 // rak - Rakshasa's toolbox
-// Copyright (C) 2005-2006, Jari Sundell
+// Copyright (C) 2005-2007, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -38,7 +38,7 @@
 #define RAK_FILE_STAT_H
 
 #include <string>
-#include <inttypes.h>
+#include <cinttypes>
 #include <sys/stat.h>
 
 namespace rak {
@@ -51,6 +51,9 @@ public:
   bool                update(const char* filename)          { return stat(filename, &m_stat) == 0; }
   bool                update(const std::string& filename)   { return update(filename.c_str()); }
 
+  bool                update_link(const char* filename)        { return lstat(filename, &m_stat) == 0; }
+  bool                update_link(const std::string& filename) { return update_link(filename.c_str()); }
+
   bool                is_regular() const                    { return S_ISREG(m_stat.st_mode); }
   bool                is_directory() const                  { return S_ISDIR(m_stat.st_mode); }
   bool                is_character() const                  { return S_ISCHR(m_stat.st_mode); }
