@@ -38,7 +38,7 @@
 #define RAK_FS_STAT_H
 
 #include <string>
-#include <inttypes.h>
+#include <cinttypes>
 
 #include <rak/error_number.h>
 
@@ -51,12 +51,6 @@
 #if HAVE_SYS_STATFS_H
 #include <sys/statfs.h>
 #endif
-#if HAVE_SYS_PARAM_H
-#include <sys/param.h>
-#endif
-#if HAVE_SYS_MOUNT_H
-#include <sys/mount.h>
-#endif
 
 namespace rak {
 
