@@ -60,12 +60,12 @@ namespace torrent {
 
 bool
 Chunk::is_all_valid() const {
-  return !empty() && std::find_if(begin(), end(), std::not1(std::mem_fun_ref(&ChunkPart::is_valid))) == end();
+  return !empty() && std::all_of(begin(), end(), std::mem_fn(&ChunkPart::is_valid));
 }
 
 void
 Chunk::clear() {
-  std::for_each(begin(), end(), std::mem_fun_ref(&ChunkPart::clear));
+  std::for_each(begin(), end(), std::mem_fn(&ChunkPart::clear));
 
   m_chunkSize = 0;
   m_prot = ~0;
@@ -95,8 +95,7 @@ Chunk::at_position(uint32_t pos) {
   if (pos >= m_chunkSize)
     throw internal_error("Chunk::at_position(...) tried to get Chunk position out of range.");
 
-  iterator itr = std::find_if(begin(), end(), std::bind2nd(std::mem_fun_ref(&ChunkPart::is_contained), pos));
-
+  auto itr = std::find_if(begin(), end(), [pos](const auto& chunk) { return chunk.is_contained(pos); });
   if (itr == end())
     throw internal_error("Chunk::at_position(...) might be mangled, at_position failed horribly");
 
@@ -124,7 +123,7 @@ Chunk::at_memory(uint32_t offset, iterator part) {
 
 bool
 Chunk::is_incore(uint32_t pos, uint32_t length) {
-  iterator itr = at_position(pos);
+  auto itr = at_position(pos);
 
   if (itr == end())
     throw internal_error("Chunk::incore_length(...) at end()");
@@ -146,7 +145,7 @@ Chunk::is_incore(uint32_t pos, uint32_t length) {
 uint32_t
 Chunk::incore_length(uint32_t pos, uint32_t length) {
   uint32_t result = 0;
-  iterator itr = at_position(pos);
+  auto itr = at_position(pos);
 
   if (itr == end())
     throw internal_error("Chunk::incore_length(...) at end()");
@@ -172,8 +171,8 @@ bool
 Chunk::sync(int flags) {
   bool success = true;
 
-  for (iterator itr = begin(), last = end(); itr != last; ++itr)
-    if (!itr->chunk().sync(0, itr->chunk().size(), flags))
+  for (auto& c : *this)
+    if (!c.chunk().sync(0, c.chunk().size(), flags))
       success = false;
 
   return success;
@@ -199,11 +198,11 @@ Chunk::preload(uint32_t position, uint32_t length, bool useAdvise) {
       itr.memory_chunk()->advise(itr.memory_chunk_first(), data.second, MemoryChunk::advice_willneed);
 
     } else {
-      for (char* first = (char*)data.first, *last = (char*)data.first + data.second; first < last; first += 4096)
-        volatile char __UNUSED touchChunk = *(char*)data.first;
+      for (char* first = static_cast<char*>(data.first), *last = static_cast<char*>(data.first) + data.second; first < last; first += 4096)
+        [[maybe_unused]] volatile char touchChunk = *static_cast<char*>(data.first);
 
       // Make sure we touch the last page in the range.
-      volatile char __UNUSED touchChunk = *((char*)data.first + data.second - 1);
+      [[maybe_unused]] volatile char ouchChunk = *(static_cast<char*>(data.first) + data.second - 1);
     }
 
   } while (itr.next());
