@@ -1,39 +1,3 @@
-// libTorrent - BitTorrent library
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #include "config.h"
 
 #include <rak/error_number.h>
@@ -46,7 +10,6 @@
 
 #include "chunk_list.h"
 #include "chunk.h"
-#include "globals.h"
 
 #define LT_LOG_THIS(log_level, log_fmt, ...)                              \
   lt_log_print_data(LOG_STORAGE_##log_level, m_data, "chunk_list", log_fmt, __VA_ARGS__);
@@ -54,14 +17,12 @@
 namespace torrent {
 
 struct chunk_list_earliest_modified {
-  chunk_list_earliest_modified() : m_time(cachedTime) {}
-
   void operator () (ChunkListNode* node) {
-    if (node->time_modified() < m_time && node->time_modified() != rak::timer())
+    if (node->time_modified() < m_time && node->time_modified() != 0us)
       m_time = node->time_modified();
   }
 
-  rak::timer m_time;
+  std::chrono::microseconds m_time{this_thread::cached_time()};
 };
 
 inline bool
@@ -76,7 +37,7 @@ ChunkList::has_chunk(size_type index, int prot) const {
 
 void
 ChunkList::resize(size_type to_size) {
-  LT_LOG_THIS(INFO, "Resizing: from:%" PRIu32 " to:%" PRIu32 ".", size(), to_size);
+  LT_LOG_THIS(INFO, "Resizing: from:%zu to:%u.", size(), to_size);
 
   if (!empty())
     throw internal_error("ChunkList::resize(...) called on an non-empty object.");
@@ -85,8 +46,10 @@ ChunkList::resize(size_type to_size) {
 
   uint32_t index = 0;
 
-  for (iterator itr = begin(), last = end(); itr != last; ++itr, ++index)
-    itr->set_index(index);
+  for (auto& chunk : *this) {
+    chunk.set_index(index);
+    ++index;
+  }
 }
 
 void
@@ -95,33 +58,33 @@ ChunkList::clear() {
 
   // Don't do any sync'ing as whomever decided to shut down really
   // doesn't care, so just de-reference all chunks in queue.
-  for (Queue::iterator itr = m_queue.begin(), last = m_queue.end(); itr != last; ++itr) {
-    if ((*itr)->references() != 1 || (*itr)->writable() != 1)
+  for (auto chunk : m_queue) {
+    if (chunk->references() != 1 || chunk->writable() != 1)
       throw internal_error("ChunkList::clear() called but a node in the queue is still referenced.");
 
-    (*itr)->dec_rw();
-    clear_chunk(*itr);
+    chunk->dec_rw();
+    clear_chunk(chunk, release_default);
   }
 
   m_queue.clear();
 
-  if (std::find_if(begin(), end(), std::mem_fun_ref(&ChunkListNode::chunk)) != end())
+  if (std::any_of(begin(), end(), std::mem_fn(&ChunkListNode::chunk)))
     throw internal_error("ChunkList::clear() called but a node with a valid chunk was found.");
 
-  if (std::find_if(begin(), end(), std::mem_fun_ref(&ChunkListNode::references)) != end())
+  if (std::any_of(begin(), end(), std::mem_fn(&ChunkListNode::references)))
     throw internal_error("ChunkList::clear() called but a node with references != 0 was found.");
 
-  if (std::find_if(begin(), end(), std::mem_fun_ref(&ChunkListNode::writable)) != end())
+  if (std::any_of(begin(), end(), std::mem_fn(&ChunkListNode::writable)))
     throw internal_error("ChunkList::clear() called but a node with writable != 0 was found.");
 
-  if (std::find_if(begin(), end(), std::mem_fun_ref(&ChunkListNode::blocking)) != end())
+  if (std::any_of(begin(), end(), std::mem_fn(&ChunkListNode::blocking)))
     throw internal_error("ChunkList::clear() called but a node with blocking != 0 was found.");
 
   base_type::clear();
 }
 
 ChunkHandle
-ChunkList::get(size_type index, int flags) {
+ChunkList::get(size_type index, get_flags flags) {
   LT_LOG_THIS(DEBUG, "Get: index:%" PRIu32 " flags:%#x.", index, flags);
 
   rak::error_number::clear_global();
@@ -138,20 +101,30 @@ ChunkList::get(size_type index, int flags) {
       return ChunkHandle::from_error(rak::error_number::e_nomem);
     }
 
-    Chunk* chunk = m_slot_create_chunk(index, prot_flags);
+    Chunk* chunk;
+
+    if ((flags & get_hashing))
+      chunk = m_slot_create_hashing_chunk(index, prot_flags);
+    else if (flags & get_not_hashing)
+      chunk = m_slot_create_chunk(index, prot_flags);
+    else
+      throw internal_error("ChunkList::get(...) called with get_hashing and get_not_hashing flags set.");
 
     if (chunk == NULL) {
       rak::error_number current_error = rak::error_number::current();
 
       LT_LOG_THIS(DEBUG, "Could not create: memory:%" PRIu64 " block:%" PRIu32 " errno:%i errmsg:%s.",
-                  m_manager->memory_usage(), m_manager->memory_block_count(),
-                  current_error.value(), current_error.c_str());
+                  m_manager->memory_usage(),
+                  m_manager->memory_block_count(),
+                  current_error.value(),
+                  current_error.c_str());
+
       m_manager->deallocate(m_chunk_size, allocate_flags | ChunkManager::allocate_revert_log);
       return ChunkHandle::from_error(current_error.is_valid() ? current_error : rak::error_number::e_noent);
     }
 
     node->set_chunk(chunk);
-    node->set_time_modified(rak::timer());
+    node->set_time_modified(0us);
 
   } else if (flags & get_writable && !node->chunk()->is_writable()) {
     if (node->blocking() != 0) {
@@ -169,7 +142,7 @@ ChunkList::get(size_type index, int flags) {
     delete node->chunk();
 
     node->set_chunk(chunk);
-    node->set_time_modified(rak::timer());
+    node->set_time_modified(0us);
   }
 
   node->inc_references();
@@ -194,15 +167,15 @@ ChunkList::get(size_type index, int flags) {
 // will allow us to schedule writes at more resonable intervals.
 
 void
-ChunkList::release(ChunkHandle* handle, int release_flags) {
+ChunkList::release(ChunkHandle* handle, release_flags flags) {
   if (!handle->is_valid())
     throw internal_error("ChunkList::release(...) received an invalid handle.");
 
   if (handle->object() < &*begin() || handle->object() >= &*end())
     throw internal_error("ChunkList::release(...) received an unknown handle.");
 
-  LT_LOG_THIS(DEBUG, "Release: index:%" PRIu32 " flags:%#x.", handle->index(), release_flags);
- 
+  LT_LOG_THIS(DEBUG, "Release: index:%" PRIu32 " flags:%#x.", handle->index(), flags);
+
   if (handle->object()->references() <= 0 ||
       (handle->is_writable() && handle->object()->writable() <= 0) ||
       (handle->is_blocking() && handle->object()->blocking() <= 0))
@@ -233,7 +206,7 @@ ChunkList::release(ChunkHandle* handle, int release_flags) {
       if (is_queued(handle->object()))
         throw internal_error("ChunkList::release(...) tried to unmap a queued chunk.");
 
-      clear_chunk(handle->object(), release_flags);
+      clear_chunk(handle->object(), flags);
     }
   }
 
@@ -241,14 +214,14 @@ ChunkList::release(ChunkHandle* handle, int release_flags) {
 }
 
 void
-ChunkList::clear_chunk(ChunkListNode* node, int flags) {
+ChunkList::clear_chunk(ChunkListNode* node, release_flags flags) {
   if (!node->is_valid())
     throw internal_error("ChunkList::clear_chunk(...) !node->is_valid().");
 
   delete node->chunk();
   node->set_chunk(NULL);
 
-  m_manager->deallocate(m_chunk_size, (flags & get_dont_log) ? ChunkManager::allocate_dont_log : 0);
+  m_manager->deallocate(m_chunk_size, (flags & release_dont_log) ? ChunkManager::allocate_dont_log : 0);
 }
 
 inline bool
@@ -268,20 +241,20 @@ ChunkList::sync_chunk(ChunkListNode* node, std::pair<int,bool> options) {
     return true;
 
   node->dec_rw();
- 
+
   if (node->references() == 0)
-    clear_chunk(node);
+    clear_chunk(node, release_default);
 
   return true;
 }
 
 uint32_t
-ChunkList::sync_chunks(int flags) {
+ChunkList::sync_chunks(sync_flags flags) {
   LT_LOG_THIS(DEBUG, "Sync chunks: flags:%#x.", flags);
 
   Queue::iterator split;
 
-  if (flags & sync_all)
+  if ((flags & sync_all))
     split = m_queue.begin();
   else
     split = std::stable_partition(m_queue.begin(), m_queue.end(), [](ChunkListNode* n) {
@@ -295,14 +268,14 @@ ChunkList::sync_chunks(int flags) {
   // only areas with timers are (preferably) synced?
 
   std::sort(split, m_queue.end());
-  
+
   // If we got enough diskspace and have not requested safe syncing,
   // then sync all chunks with MS_ASYNC.
   if (!(flags & (sync_safe | sync_sloppy))) {
     if (m_manager->safe_sync() || m_slot_free_diskspace() <= m_manager->safe_free_diskspace())
-      flags |= sync_safe;
+      flags = flags | sync_safe;
     else
-      flags |= sync_force;
+      flags = flags | sync_force;
   }
 
   // TODO: This won't trigger for default sync_force.
@@ -311,8 +284,8 @@ ChunkList::sync_chunks(int flags) {
 
   uint32_t failed = 0;
 
-  for (Queue::iterator itr = split, last = m_queue.end(); itr != last; ++itr) {
-    
+  for (auto itr = split, last = m_queue.end(); itr != last; ++itr) {
+
     // We can easily skip pieces by swap_iter, so there should be no
     // problem being selective about the ranges we sync.
 
@@ -326,7 +299,7 @@ ChunkList::sync_chunks(int flags) {
 
     if (!sync_chunk(*itr, options)) {
       std::iter_swap(itr, split++);
-      
+
       failed++;
       continue;
     }
@@ -339,7 +312,7 @@ ChunkList::sync_chunks(int flags) {
     instrumentation_update(INSTRUMENTATION_MINCORE_SYNC_SUCCESS, std::distance(split, m_queue.end()));
     instrumentation_update(INSTRUMENTATION_MINCORE_SYNC_FAILED, failed);
     instrumentation_update(INSTRUMENTATION_MINCORE_SYNC_NOT_SYNCED, std::distance(m_queue.begin(), split));
-    instrumentation_update(INSTRUMENTATION_MINCORE_SYNC_NOT_DEALLOCATED, std::count_if(split, m_queue.end(), std::mem_fun(&ChunkListNode::is_valid)));
+    instrumentation_update(INSTRUMENTATION_MINCORE_SYNC_NOT_DEALLOCATED, std::count_if(split, m_queue.end(), std::mem_fn(&ChunkListNode::is_valid)));
   }
 
   m_queue.erase(split, m_queue.end());
@@ -353,20 +326,14 @@ ChunkList::sync_chunks(int flags) {
 }
 
 std::pair<int, bool>
-ChunkList::sync_options(ChunkListNode* node, int flags) {
-  // Using if statements since some linkers have problem with static
-  // const int members inside the ?: operators. The compiler should
-  // be optimizing this anyway.
-
-  if (flags & sync_force) {
-
-    if (flags & sync_safe)
+ChunkList::sync_options(ChunkListNode* node, sync_flags flags) {
+  if ((flags & sync_force)) {
+    if ((flags & sync_safe))
       return std::make_pair(MemoryChunk::sync_sync, true);
     else
       return std::make_pair(MemoryChunk::sync_async, true);
 
-  } else if (flags & sync_safe) {
-      
+  } else if ((flags & sync_safe)) {
     if (node->sync_triggered())
       return std::make_pair(MemoryChunk::sync_sync, true);
     else
@@ -397,8 +364,8 @@ ChunkList::seek_range(Queue::iterator first, Queue::iterator last) {
 inline bool
 ChunkList::check_node(ChunkListNode* node) {
   return
-    node->time_modified() != rak::timer() &&
-    node->time_modified() + rak::timer::from_seconds(m_manager->timeout_sync()) < cachedTime;
+    node->time_modified() != 0us &&
+    node->time_modified() + std::chrono::seconds(m_manager->timeout_sync()) < this_thread::cached_time();
 }
 
 // Optimize the selection of chunks to sync. Continuous regions are
@@ -407,10 +374,10 @@ ChunkList::check_node(ChunkListNode* node) {
 
 ChunkList::Queue::iterator
 ChunkList::partition_optimize(Queue::iterator first, Queue::iterator last, int weight, int maxDistance, bool dontSkip) {
-  for (Queue::iterator itr = first; itr != last;) {
-    Queue::iterator range = seek_range(itr, last);
+  for (auto itr = first; itr != last;) {
+    auto range = seek_range(itr, last);
 
-    bool required = std::find_if(itr, range, std::bind1st(std::mem_fun(&ChunkList::check_node), this)) != range;
+    bool required = std::any_of(itr, range, [this](auto wrapper) { return check_node(wrapper); });
     dontSkip = dontSkip || required;
 
     if (!required && std::distance(itr, range) < maxDistance) {
@@ -437,14 +404,14 @@ ChunkList::partition_optimize(Queue::iterator first, Queue::iterator last, int w
 
 ChunkList::chunk_address_result
 ChunkList::find_address(void* ptr) {
-  iterator first = begin();
-  iterator last = end();
+  auto first = begin();
+  auto last  = end();
 
   for (; first != last; first++) {
     if (!first->is_valid())
       continue;
 
-    Chunk::iterator partition = first->chunk()->find_address(ptr);
+    auto partition = first->chunk()->find_address(ptr);
 
     if (partition != first->chunk()->end())
       return chunk_address_result(first, partition);
