@@ -19,13 +19,13 @@ class FileList;
 
 class ChunkList : private std::vector<ChunkListNode> {
 public:
-  typedef uint32_t                            size_type;
-  typedef std::vector<ChunkListNode>          base_type;
-  typedef std::vector<ChunkListNode*>         Queue;
+  using size_type = uint32_t;
+  using base_type = std::vector<ChunkListNode>;
+  using Queue     = std::vector<ChunkListNode*>;
 
-  typedef std::function<Chunk* (uint32_t, int)>    slot_chunk_index;
-  typedef std::function<uint64_t ()>               slot_value;
-  typedef std::function<void (const std::string&)> slot_string;
+  using slot_chunk_index = std::function<Chunk*(uint32_t, int)>;
+  using slot_value       = std::function<uint64_t()>;
+  using slot_string      = std::function<void(const std::string&)>;
 
   using base_type::value_type;
   using base_type::reference;
@@ -41,21 +41,32 @@ public:
   using base_type::empty;
   using base_type::operator[];
 
-  static const int sync_all          = (1 << 0);
-  static const int sync_force        = (1 << 1);
-  static const int sync_safe         = (1 << 2);
-  static const int sync_sloppy       = (1 << 3);
-  static const int sync_use_timeout  = (1 << 4);
-  static const int sync_ignore_error = (1 << 5);
+  enum sync_flags {
+    sync_all          = (1 << 0),
+    sync_force        = (1 << 1),
+    sync_safe         = (1 << 2),
+    sync_sloppy       = (1 << 3),
+    sync_use_timeout  = (1 << 4),
+    sync_ignore_error = (1 << 5)
+  };
 
-  static const int get_writable      = (1 << 0);
-  static const int get_blocking      = (1 << 1);
-  static const int get_dont_log      = (1 << 2);
-  static const int get_nonblock      = (1 << 3);
+  enum get_flags {
+    get_writable      = (1 << 0),
+    get_blocking      = (1 << 1),
+    get_nonblock      = (1 << 2),
+    get_hashing       = (1 << 3),
+    get_not_hashing   = (1 << 4),
+    get_dont_log      = (1 << 5)
+  };
 
-  static const int flag_active       = (1 << 0);
+  enum release_flags {
+    release_default   = 0,
+    release_dont_log  = (1 << 0)
+  };
 
-  ChunkList() : m_data(NULL), m_manager(NULL), m_flags(0), m_chunk_size(0) {}
+  static constexpr int flag_active = (1 << 0);
+
+  ChunkList() = default;
   ~ChunkList() { clear(); }
 
   int                 flags() const                       { return m_flags; }
@@ -78,28 +89,32 @@ public:
   void                resize(size_type to_size);
   void                clear();
 
-  ChunkHandle         get(size_type index, int flags = 0);
-  void                release(ChunkHandle* handle, int flags = 0);
+  ChunkHandle         get(size_type index, get_flags flags);
+  void                release(ChunkHandle* handle, release_flags flags);
 
   // Replace use_timeout with something like performance related
   // keyword. Then use that flag to decide if we should skip
   // non-continious regions.
 
   // Returns the number of failed syncs.
-  uint32_t            sync_chunks(int flags);
+  uint32_t            sync_chunks(sync_flags flags);
 
-  slot_string&        slot_storage_error()  { return m_slot_storage_error; }
-  slot_chunk_index&   slot_create_chunk()   { return m_slot_create_chunk; }
-  slot_value&         slot_free_diskspace() { return m_slot_free_diskspace; }
+  slot_string&        slot_storage_error()        { return m_slot_storage_error; }
+  slot_chunk_index&   slot_create_chunk()         { return m_slot_create_chunk; }
+  slot_chunk_index&   slot_create_hashing_chunk() { return m_slot_create_hashing_chunk; }
+  slot_value&         slot_free_diskspace()       { return m_slot_free_diskspace; }
 
-  typedef std::pair<iterator, Chunk::iterator> chunk_address_result;
+  using chunk_address_result = std::pair<iterator, Chunk::iterator>;
 
   chunk_address_result find_address(void* ptr);
 
 private:
+  ChunkList(const ChunkList&) = delete;
+  ChunkList& operator=(const ChunkList&) = delete;
+
   inline bool         is_queued(ChunkListNode* node);
 
-  inline void         clear_chunk(ChunkListNode* node, int flags = 0);
+  inline void         clear_chunk(ChunkListNode* node, release_flags flags);
   inline bool         sync_chunk(ChunkListNode* node, std::pair<int,bool> options);
 
   Queue::iterator     partition_optimize(Queue::iterator first, Queue::iterator last, int weight, int maxDistance, bool dontSkip);
@@ -107,20 +122,36 @@ private:
   inline Queue::iterator seek_range(Queue::iterator first, Queue::iterator last);
   inline bool            check_node(ChunkListNode* node);
 
-  std::pair<int,bool> sync_options(ChunkListNode* node, int flags);
+  std::pair<int,bool> sync_options(ChunkListNode* node, sync_flags flags);
 
-  download_data*      m_data;
-  ChunkManager*       m_manager;
+  download_data*      m_data{};
+  ChunkManager*       m_manager{};
   Queue               m_queue;
 
-  int                 m_flags;
-  uint32_t            m_chunk_size;
+  int                 m_flags{0};
+  uint32_t            m_chunk_size{0};
 
   slot_string         m_slot_storage_error;
   slot_chunk_index    m_slot_create_chunk;
+  slot_chunk_index    m_slot_create_hashing_chunk;
   slot_value          m_slot_free_diskspace;
 };
 
+inline ChunkList::sync_flags
+operator|(ChunkList::sync_flags a, ChunkList::sync_flags b) {
+  return static_cast<ChunkList::sync_flags>(static_cast<int>(a) | static_cast<int>(b));
+}
+
+inline ChunkList::get_flags
+operator|(ChunkList::get_flags a, ChunkList::get_flags b) {
+  return static_cast<ChunkList::get_flags>(static_cast<int>(a) | static_cast<int>(b));
+}
+
+inline ChunkList::release_flags
+operator|(ChunkList::release_flags a, ChunkList::release_flags b) {
+  return static_cast<ChunkList::release_flags>(static_cast<int>(a) | static_cast<int>(b));
+}
+
 }
 
 #endif
