@@ -1,55 +1,19 @@
-// libTorrent - BitTorrent library
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #include "config.h"
 
+#include "data/hash_queue.h"
+
 #include <functional>
 #include <unistd.h>
+#include <utility>
 
+#include "data/chunk.h"
+#include "data/chunk_list_node.h"
+#include "data/hash_chunk.h"
+#include "data/thread_disk.h"
 #include "torrent/exceptions.h"
 #include "torrent/data/download_data.h"
 #include "torrent/utils/log.h"
-#include "torrent/utils/thread_base.h"
-
-#include "hash_queue.h"
-#include "hash_chunk.h"
-#include "chunk.h"
-#include "chunk_list_node.h"
-#include "globals.h"
-#include "thread_disk.h"
+#include "torrent/utils/thread.h"
 
 #define LT_LOG_DATA(data, log_level, log_fmt, ...)                       \
   lt_log_print_data(LOG_STORAGE_##log_level, data, "hash_queue", log_fmt, __VA_ARGS__);
@@ -78,14 +42,6 @@ struct HashQueueWillneed {
 // disk usage. But this may cause too much blocking as it will think
 // everything is in memory, thus we need to throttle.
 
-HashQueue::HashQueue(thread_disk* thread) :
-  m_thread_disk(thread) {
-
-  pthread_mutex_init(&m_done_chunks_lock, NULL);
-  m_thread_disk->hash_queue()->slot_chunk_done() = std::bind(&HashQueue::chunk_done, this, std::placeholders::_1, std::placeholders::_2);
-}
-
-
 // If we're done immediately, move the chunk to the front of the list so
 // the next work cycle gets stuff done.
 void
@@ -95,12 +51,12 @@ HashQueue::push_back(ChunkHandle handle, HashQueueNode::id_type id, slot_done_ty
   if (!handle.is_loaded())
     throw internal_error("HashQueue::add(...) received an invalid chunk");
 
-  HashChunk* hash_chunk = new HashChunk(handle);
+  auto hash_chunk = new HashChunk(handle);
 
-  base_type::push_back(HashQueueNode(id, hash_chunk, d));
+  base_type::push_back(HashQueueNode(id, hash_chunk, std::move(d)));
 
-  m_thread_disk->hash_queue()->push_back(hash_chunk);
-  m_thread_disk->interrupt();
+  thread_disk()->hash_check_queue()->push_back(hash_chunk);
+  thread_disk()->interrupt();
 }
 
 bool
@@ -110,7 +66,7 @@ HashQueue::has(HashQueueNode::id_type id) {
 
 bool
 HashQueue::has(HashQueueNode::id_type id, uint32_t index) {
-  return std::find_if(begin(), end(), HashQueueEqual(id, index)) != end();
+  return std::any_of(begin(), end(), HashQueueEqual(id, index));
 }
 
 void
@@ -118,29 +74,20 @@ HashQueue::remove(HashQueueNode::id_type id) {
   base_type::erase(std::remove_if(begin(), end(), [id, this](auto& itr) {
     if (itr.id() != id)
       return false;
-  
+
     HashChunk *hash_chunk = itr.get_chunk();
 
     LT_LOG_DATA(id, DEBUG, "Removing index:%" PRIu32 " from queue.", hash_chunk->handle().index());
 
-    thread_base::release_global_lock();
-    bool result = m_thread_disk->hash_queue()->remove(hash_chunk);
-    thread_base::acquire_global_lock();
+    bool result = thread_disk()->hash_check_queue()->remove(hash_chunk);
 
     // The hash chunk was not found, so we need to wait until the hash
     // check finishes.
     if (!result) {
-      pthread_mutex_lock(&m_done_chunks_lock);
-      done_chunks_type::iterator done_itr;
+      auto lock = std::unique_lock(m_done_chunks_lock);
 
-      while ((done_itr = m_done_chunks.find(hash_chunk)) == m_done_chunks.end()) {
-        pthread_mutex_unlock(&m_done_chunks_lock);
-        usleep(100);
-        pthread_mutex_lock(&m_done_chunks_lock);
-      }
-
-      m_done_chunks.erase(done_itr);
-      pthread_mutex_unlock(&m_done_chunks_lock);
+      m_cv.wait(lock, [this, hash_chunk] { return m_done_chunks.find(hash_chunk) != m_done_chunks.end(); });
+      m_done_chunks.erase(hash_chunk);
     }
 
     itr.slot_done()(*hash_chunk->chunk(), NULL);
@@ -157,14 +104,14 @@ HashQueue::clear() {
     throw internal_error("HashQueue::clear() called but valid nodes were found.");
 
   // Replace with a dtor check to ensure it is empty?
-//   std::for_each(begin(), end(), std::mem_fun_ref(&HashQueueNode::clear));
-//   base_type::clear();
+  //   std::for_each(begin(), end(), std::mem_fn(&HashQueueNode::clear));
+  //   base_type::clear();
 }
 
 void
 HashQueue::work() {
-  pthread_mutex_lock(&m_done_chunks_lock);
-    
+  auto lock = std::scoped_lock(m_done_chunks_lock);
+
   while (!m_done_chunks.empty()) {
     HashChunk* hash_chunk = m_done_chunks.begin()->first;
     HashString hash_value = m_done_chunks.begin()->second;
@@ -173,9 +120,7 @@ HashQueue::work() {
     // TODO: This is not optimal as we jump around... Check for front
     // of HashQueue in done_chunks instead.
 
-    iterator itr = std::find_if(begin(), end(), std::bind(std::equal_to<HashChunk*>(),
-                                                          hash_chunk,
-                                                          std::bind(&HashQueueNode::get_chunk, std::placeholders::_1)));
+    auto itr = std::find_if(begin(), end(), [hash_chunk](auto& node) { return node.get_chunk() == hash_chunk; });
 
     // TODO: Fix this...
     if (itr == end())
@@ -191,18 +136,15 @@ HashQueue::work() {
     slotDone(hash_chunk->handle(), hash_value.c_str());
     delete hash_chunk;
   }
-
-  pthread_mutex_unlock(&m_done_chunks_lock);
 }
 
 void
 HashQueue::chunk_done(HashChunk* hash_chunk, const HashString& hash_value) {
-  pthread_mutex_lock(&m_done_chunks_lock);
+  auto lock = std::scoped_lock(m_done_chunks_lock);
 
   m_done_chunks[hash_chunk] = hash_value;
   m_slot_has_work(m_done_chunks.empty());
-
-  pthread_mutex_unlock(&m_done_chunks_lock);
+  m_cv.notify_all();
 }
 
 }
