@@ -1,39 +1,3 @@
-// libTorrent - BitTorrent library
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #include "config.h"
 
 #include "data/chunk_list.h"
@@ -43,7 +7,6 @@
 
 #include "hash_torrent.h"
 #include "hash_queue.h"
-#include "globals.h"
 
 #define LT_LOG_THIS(log_level, log_fmt, ...)                            \
   lt_log_print_data(LOG_STORAGE_##log_level, m_chunk_list->data(), "hash_torrent", log_fmt, __VA_ARGS__);
@@ -51,16 +14,12 @@
 namespace torrent {
 
 HashTorrent::HashTorrent(ChunkList* c) :
-  m_position(0),
-  m_outstanding(-1),
-  m_errno(0),
-
-  m_chunk_list(c) {
+    m_chunk_list(c) {
 }
 
 bool
 HashTorrent::start(bool try_quick) {
-  LT_LOG_THIS(INFO, "Start: position:%u size:%" PRIu64 " try_quick:%u.",
+  LT_LOG_THIS(INFO, "Start: position:%u size:%zu try_quick:%u.",
               m_position, m_chunk_list->size(), try_quick);
 
   if (m_position == m_chunk_list->size())
@@ -83,8 +42,7 @@ HashTorrent::clear() {
   m_position = 0;
   m_errno = 0;
 
-  // Correct?
-  rak::priority_queue_erase(&taskScheduler, &m_delayChecked);
+  this_thread::scheduler()->erase(&m_delay_checked);
 }
 
 bool
@@ -134,7 +92,7 @@ HashTorrent::receive_chunk_cleared(uint32_t index) {
 
   if (m_outstanding <= 0)
     throw internal_error("HashTorrent::receive_chunk_cleared() m_outstanding < 0.");
-  
+
   if (m_ranges.has(index))
     throw internal_error("HashTorrent::receive_chunk_cleared() m_ranges.has(index).");
 
@@ -154,7 +112,7 @@ HashTorrent::queue(bool quick) {
       return;
 
     // Not very efficient, but this is seldomly done.
-    Ranges::iterator itr = m_ranges.find(m_position);
+    auto itr = m_ranges.find(m_position);
 
     if (itr == m_ranges.end()) {
       m_position = m_chunk_list->size();
@@ -165,7 +123,7 @@ HashTorrent::queue(bool quick) {
 
     // Need to do increment later if we're going to support resume
     // hashing a quick hashed torrent.
-    ChunkHandle handle = m_chunk_list->get(m_position, ChunkList::get_dont_log);
+    ChunkHandle handle = m_chunk_list->get(m_position, ChunkList::get_dont_log | ChunkList::get_hashing);
 
     if (quick) {
       // We're not actually interested in doing any hashing, so just
@@ -179,9 +137,9 @@ HashTorrent::queue(bool quick) {
 
       if (handle.is_valid()) {
         LT_LOG_THIS(DEBUG, "Return on handle.is_valid(): position:%u.", m_position);
-        return m_chunk_list->release(&handle, ChunkList::get_dont_log);
+        return m_chunk_list->release(&handle, ChunkList::release_dont_log);
       }
-      
+
       if (handle.error_number().is_valid() && handle.error_number().value() != rak::error_number::e_noent) {
         LT_LOG_THIS(DEBUG, "Return on handle errno == E_NOENT: position:%u.", m_position);
         return;
@@ -212,7 +170,8 @@ HashTorrent::queue(bool quick) {
 
       LT_LOG_THIS(INFO, "Completed (error): position:%u try_quick:%u errno:%i msg:'%s'.",
                   m_position, quick, m_errno, handle.error_number().c_str());
-      rak::priority_queue_update(&taskScheduler, &m_delayChecked, cachedTime);
+
+      this_thread::scheduler()->update_wait_for(&m_delay_checked, 0s);
       return;
     }
 
@@ -236,7 +195,7 @@ HashTorrent::queue(bool quick) {
 
     // Update the scheduled item just to make sure that if hashing is
     // started again during the delay it won't cause an exception.
-    rak::priority_queue_update(&taskScheduler, &m_delayChecked, cachedTime);
+    this_thread::scheduler()->update_wait_for(&m_delay_checked, 0s);
   }
 }
 
