@@ -1,39 +1,3 @@
-// libTorrent - BitTorrent library
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #ifndef LIBTORRENT_DATA_MEMORY_CHUNK_H
 #define LIBTORRENT_DATA_MEMORY_CHUNK_H
 
@@ -41,6 +5,7 @@
 #include <cinttypes>
 #include <sys/mman.h>
 #include <cstddef>
+#include <memory>
 
 namespace torrent {
 
@@ -49,31 +14,34 @@ class MemoryChunk {
   // Consider information about whetever the memory maps to a file or
   // not, since mincore etc can only be called on files.
 
-  static const int prot_exec              = PROT_EXEC;
-  static const int prot_read              = PROT_READ;
-  static const int prot_write             = PROT_WRITE;
-  static const int prot_none              = PROT_NONE;
-  static const int map_shared             = MAP_SHARED;
+  static constexpr int prot_exec              = PROT_EXEC;
+  static constexpr int prot_read              = PROT_READ;
+  static constexpr int prot_write             = PROT_WRITE;
+  static constexpr int prot_none              = PROT_NONE;
+  static constexpr int map_shared             = MAP_SHARED;
+  static constexpr int map_anon               = MAP_ANON;
 
 #ifdef USE_MADVISE
-  static const int advice_normal          = MADV_NORMAL;
-  static const int advice_random          = MADV_RANDOM;
-  static const int advice_sequential      = MADV_SEQUENTIAL;
-  static const int advice_willneed        = MADV_WILLNEED;
-  static const int advice_dontneed        = MADV_DONTNEED;
+  static constexpr int advice_normal          = MADV_NORMAL;
+  static constexpr int advice_random          = MADV_RANDOM;
+  static constexpr int advice_sequential      = MADV_SEQUENTIAL;
+  static constexpr int advice_willneed        = MADV_WILLNEED;
+  static constexpr int advice_dontneed        = MADV_DONTNEED;
 #else
-  static const int advice_normal          = 0;
-  static const int advice_random          = 1;
-  static const int advice_sequential      = 2;
-  static const int advice_willneed        = 3;
-  static const int advice_dontneed        = 4;
+  static constexpr int advice_normal          = 0;
+  static constexpr int advice_random          = 1;
+  static constexpr int advice_sequential      = 2;
+  static constexpr int advice_willneed        = 3;
+  static constexpr int advice_dontneed        = 4;
 #endif
-  static const int sync_sync              = MS_SYNC;
-  static const int sync_async             = MS_ASYNC;
-  static const int sync_invalidate        = MS_INVALIDATE;
+  static constexpr int sync_sync              = MS_SYNC;
+  static constexpr int sync_async             = MS_ASYNC;
+  static constexpr int sync_invalidate        = MS_INVALIDATE;
 
-  MemoryChunk() { clear(); }
+  MemoryChunk() = default;
   ~MemoryChunk() { clear(); }
+  MemoryChunk(const MemoryChunk&) = default;
+  MemoryChunk& operator=(const MemoryChunk&) = default;
 
   // Doesn't allow ptr == NULL, use the default ctor instead.
   MemoryChunk(char* ptr, char* begin, char* end, int prot, int flags);
@@ -120,17 +88,17 @@ private:
 
   static uint32_t     m_pagesize;
 
-  char*               m_ptr;
-  char*               m_begin;
-  char*               m_end;
+  char*               m_ptr{};
+  char*               m_begin{};
+  char*               m_end{};
 
   int                 m_prot;
-  int                 m_flags;
+  int                 m_flags{PROT_NONE};
 };
 
 inline bool
 MemoryChunk::is_valid_range(uint32_t offset, uint32_t length) const {
-  return length != 0 && (uint64_t)offset + length <= size();
+  return length != 0 && static_cast<uint64_t>(offset) + length <= size();
 }
 
 inline void
@@ -154,12 +122,14 @@ MemoryChunk::size_aligned() const {
 
 inline bool
 MemoryChunk::is_incore(uint32_t offset, uint32_t length) {
-  uint32_t size = pages_touched(offset, length);
-  char buf[size];
-  
-  incore(buf, offset, length);
+  const uint32_t size = pages_touched(offset, length);
+  auto buf = std::make_unique<char[]>(size);
+  auto begin = buf.get();
+  auto end = begin + size;
 
-  return std::find(buf, buf + size, 0) == buf + size;
+  incore(begin, offset, length);
+
+  return std::find(begin, end, 0) == end;
 }
 
 }
