@@ -10,22 +10,21 @@
 
 namespace torrent {
 
-// Inherit from SocketBase?
-
 class SocketFile {
 public:
-  typedef int fd_type;
+  using fd_type = int;
 
-  static const fd_type invalid_fd         = -1;
+  static constexpr fd_type invalid_fd         = -1;
 
-  static const int o_create               = O_CREAT;
-  static const int o_truncate             = O_TRUNC;
-  static const int o_nonblock             = O_NONBLOCK;
+  static constexpr int o_create               = O_CREAT;
+  static constexpr int o_truncate             = O_TRUNC;
+  static constexpr int o_nonblock             = O_NONBLOCK;
 
-  static const int flag_fallocate          = (1 << 0);
-  static const int flag_fallocate_blocking = (1 << 1);
+  static constexpr int flag_fallocate          = (1 << 0);
+  static constexpr int flag_fallocate_blocking = (1 << 1);
 
-  SocketFile() : m_fd(invalid_fd) {}
+  SocketFile() = default;
+  ~SocketFile() = default;
   SocketFile(fd_type fd) : m_fd(fd) {}
 
   bool                is_open() const                                   { return m_fd != invalid_fd; }
@@ -38,17 +37,17 @@ public:
 
   bool                allocate(uint64_t size, int flags = 0) const;
 
+  MemoryChunk         create_padding_chunk(uint32_t length, int prot, int flags) const;
   MemoryChunk         create_chunk(uint64_t offset, uint32_t length, int prot, int flags) const;
 
   fd_type             fd() const                                        { return m_fd; }
 
 private:
+  SocketFile(const SocketFile&) = delete;
+  SocketFile& operator=(const SocketFile&) = delete;
+
   // Use custom flags if stuff like file locking etc is implemented.
-
-  SocketFile(const SocketFile&);
-  void operator = (const SocketFile&);
-
-  fd_type             m_fd;
+  fd_type             m_fd{invalid_fd};
 };
 
 }
