@@ -1,56 +1,23 @@
-// libTorrent - BitTorrent library
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #include "config.h"
-#include "globals.h"
 
+#include "dht_router.h"
+
+#include <cassert>
 #include <sstream>
 
-#include "torrent/dht_manager.h"
-#include "torrent/download_info.h"
-#include "torrent/exceptions.h"
-#include "torrent/utils/log.h"
-
-#include "utils/sha1.h"
-#include "manager.h"
-
 #include "dht_bucket.h"
-#include "dht_router.h"
 #include "dht_tracker.h"
 #include "dht_transaction.h"
+#include "manager.h"
+#include "torrent/connection_manager.h"
+#include "torrent/download_info.h"
+#include "torrent/exceptions.h"
+#include "torrent/net/resolver.h"
+#include "torrent/net/socket_address.h"
+#include "torrent/tracker/dht_controller.h"
+#include "torrent/utils/log.h"
+#include "torrent/utils/thread.h"
+#include "utils/sha1.h"
 
 #define LT_LOG_THIS(log_fmt, ...)                                       \
   lt_log_print_hash(torrent::LOG_DHT_ROUTER, this->id(), "dht_router", log_fmt, __VA_ARGS__);
@@ -62,8 +29,6 @@ HashString DhtRouter::zero_id;
 DhtRouter::DhtRouter(const Object& cache, const rak::socket_address* sa) :
   DhtNode(zero_id, sa),  // actual ID is set later
   m_server(this),
-  m_contacts(NULL),
-  m_numRefresh(0),
   m_curToken(random()),
   m_prevToken(random()) {
 
@@ -102,42 +67,38 @@ DhtRouter::DhtRouter(const Object& cache, const rak::socket_address* sa) :
 
     LT_LOG_THIS("adding nodes (size:%zu)", nodes.size());
 
-    for (Object::map_type::const_iterator itr = nodes.begin(); itr != nodes.end(); ++itr) {
-      if (itr->first.length() != HashString::size_data)
+    for (const auto& [id, node] : nodes) {
+      if (id.length() != HashString::size_data)
         throw bencode_error("Loading cache: Invalid node hash.");
 
-      add_node_to_bucket(m_nodes.add_node(new DhtNode(itr->first, itr->second)));
+      add_node_to_bucket(m_nodes.add_node(new DhtNode(id, node)));
     }
   }
 
   if (m_nodes.size() < num_bootstrap_complete) {
-    m_contacts = new std::deque<contact_t>;
-
+    m_contacts.emplace();
     if (cache.has_key("contacts")) {
-      const Object::list_type& contacts = cache.get_key_list("contacts");
-
-      for (Object::list_type::const_iterator itr = contacts.begin(); itr != contacts.end(); ++itr) {
-        Object::list_type::const_iterator litr = itr->as_list().begin();
-        const std::string& host = litr->as_string();
-        int port = (++litr)->as_value();
-        m_contacts->emplace_back(host, port);
+      for (const auto& contact : cache.get_key_list("contacts")) {
+        auto litr = contact.as_list().begin();
+        auto host = litr->as_string();
+        auto port = std::next(litr)->as_value();
+        m_contacts->emplace_back(std::move(host), port);
       }
     }
   }
 }
 
 DhtRouter::~DhtRouter() {
-  stop();
-  delete m_contacts;
+  assert(!is_active() && "DhtRouter::~DhtRouter() called while still active.");
 
-  for (DhtBucketList::iterator itr = m_routingTable.begin(), last = m_routingTable.end(); itr != last; itr++)
-    delete itr->second;
+  for (auto& route : m_routingTable)
+    delete route.second;
 
-  for (DhtTrackerList::iterator itr = m_trackers.begin(), last = m_trackers.end(); itr != last; itr++)
-    delete itr->second;
+  for (auto& tracker : m_trackers)
+    delete tracker.second;
 
-  for (DhtNodeList::iterator itr = m_nodes.begin(), last = m_nodes.end(); itr != last; itr++)
-    delete itr->second;
+  for (auto& node : m_nodes)
+    delete node.second;
 }
 
 void
@@ -146,46 +107,55 @@ DhtRouter::start(int port) {
 
   m_server.start(port);
 
-  // Set timeout slot and schedule it to be called immediately for initial bootstrapping if necessary.
-  m_taskTimeout.slot() = std::bind(&DhtRouter::receive_timeout_bootstrap, this);
-  priority_queue_insert(&taskScheduler, &m_taskTimeout, (cachedTime + rak::timer::from_seconds(1)).round_seconds());
+  // Set timeout slot and schedule it to be called immediately for initial bootstrapping if
+  // necessary.
+  m_task_timeout.slot() = [this] { receive_timeout_bootstrap(); };
+
+  this_thread::scheduler()->wait_for_ceil_seconds(&m_task_timeout, 1s);
 }
 
 void
 DhtRouter::stop() {
-  priority_queue_erase(&taskScheduler, &m_taskTimeout);
+  if (!is_active())
+    return;
+
+  LT_LOG_THIS("stopping", 0);
+
+  this_thread::resolver()->cancel(this);
+  this_thread::scheduler()->erase(&m_task_timeout);
+
   m_server.stop();
 }
 
 // Start a DHT get_peers and announce_peer request.
 void
-DhtRouter::announce(DownloadInfo* info, TrackerDht* tracker) {
-  m_server.announce(*find_bucket(info->hash())->second, info->hash(), tracker);
+DhtRouter::announce(const HashString& info_hash, TrackerDht* tracker) {
+  m_server.announce(*find_bucket(info_hash)->second, info_hash, tracker);
 }
 
 // Cancel any running requests from the given tracker.
 // If info or tracker is not NULL, only cancel matching requests.
 void
-DhtRouter::cancel_announce(DownloadInfo* info, const TrackerDht* tracker) {
-  m_server.cancel_announce(info, tracker);
+DhtRouter::cancel_announce(const HashString* info_hash, const TrackerDht* tracker) {
+  m_server.cancel_announce(info_hash, tracker);
 }
 
 DhtTracker*
 DhtRouter::get_tracker(const HashString& hash, bool create) {
-  DhtTrackerList::accessor itr = m_trackers.find(hash);
+  auto itr = m_trackers.find(hash);
 
   if (itr != m_trackers.end())
-    return itr.tracker();
+    return itr->second;
 
   if (!create)
     return NULL;
 
-  std::pair<DhtTrackerList::accessor, bool> res = m_trackers.emplace(hash, new DhtTracker());
+  auto [tr, ins] = m_trackers.emplace(hash, new DhtTracker());
 
-  if (!res.second)
+  if (!ins)
     throw internal_error("DhtRouter::get_tracker did not actually insert tracker.");
 
-  return res.first.tracker();
+  return tr->second;
 }
 
 bool
@@ -217,7 +187,7 @@ DhtRouter::get_node(const HashString& id) {
 
 DhtRouter::DhtBucketList::iterator
 DhtRouter::find_bucket(const HashString& id) {
-  DhtBucketList::iterator itr = m_routingTable.lower_bound(id);
+  auto itr = m_routingTable.lower_bound(id);
 
 #ifdef USE_EXTRA_DEBUG
   if (itr == m_routingTable.end())
@@ -234,7 +204,7 @@ void
 DhtRouter::add_contact(const std::string& host, int port) {
   // Externally obtained nodes are added to the contact list, but only if
   // we're still bootstrapping. We don't contact external nodes after that.
-  if (m_contacts != NULL) {
+  if (m_contacts.has_value()) {
     if (m_contacts->size() >= num_bootstrap_contacts)
       m_contacts->pop_front();
 
@@ -243,12 +213,14 @@ DhtRouter::add_contact(const std::string& host, int port) {
 }
 
 void
-DhtRouter::contact(const rak::socket_address* sa, int port) {
-  if (is_active()) {
-    rak::socket_address sa_port = *sa;
-    sa_port.set_port(port);
-    m_server.ping(zero_id, &sa_port);
-  }
+DhtRouter::contact(const sockaddr* sa, int port) {
+  if (!is_active())
+    return;
+
+  auto sa_port = sa_copy(sa);
+  sap_set_port(sa_port, port);
+
+  m_server.ping(zero_id, rak::socket_address::cast_from(sa_port.get()));
 }
 
 // Received a query from the given node. If it has previously replied
@@ -352,28 +324,28 @@ DhtRouter::store_cache(Object* container) const {
 
   // Insert all nodes.
   Object& nodes = container->insert_key("nodes", Object::create_map());
-  for (DhtNodeList::const_accessor itr = m_nodes.begin(); itr != m_nodes.end(); ++itr) {
-    if (!itr.node()->is_bad())
-      itr.node()->store_cache(&nodes.insert_key(itr.id().str(), Object::create_map()));
+  for (const auto& [id, node] : m_nodes) {
+    if (!node->is_bad())
+      node->store_cache(&nodes.insert_key(id->str(), Object::create_map()));
   }
 
   // Insert contacts, if we have any.
-  if (m_contacts != NULL) {
+  if (m_contacts.has_value()) {
     Object& contacts = container->insert_key("contacts", Object::create_list());
 
-    for (std::deque<contact_t>::const_iterator itr = m_contacts->begin(); itr != m_contacts->end(); ++itr) {
+    for (const auto& m_contact : *m_contacts) {
       Object::list_type& list = contacts.insert_back(Object::create_list()).as_list();
-      list.emplace_back(itr->first);
-      list.emplace_back(itr->second);
+      list.emplace_back(m_contact.first);
+      list.emplace_back(m_contact.second);
     }
   }
 
   return container;
 }
 
-DhtManager::statistics_type
+tracker::DhtController::statistics_type
 DhtRouter::get_statistics() const {
-  DhtManager::statistics_type stats(*m_server.upload_throttle_node()->rate(), *m_server.download_throttle_node()->rate());
+  tracker::DhtController::statistics_type stats(*m_server.upload_throttle_node()->rate(), *m_server.download_throttle_node()->rate());
 
   if (!m_server.is_active())
     stats.cycle = 0;
@@ -395,8 +367,8 @@ DhtRouter::get_statistics() const {
   stats.max_peers        = 0;
   stats.num_trackers     = m_trackers.size();
 
-  for (DhtTrackerList::const_accessor itr = m_trackers.begin(); itr != m_trackers.end(); ++itr) {
-    unsigned int peers = itr.tracker()->size();
+  for (const auto& [_, tracker] : m_trackers) {
+    unsigned int peers = tracker->size();
     stats.num_peers += peers;
     stats.max_peers = std::max(peers, stats.max_peers);
   }
@@ -411,22 +383,22 @@ DhtRouter::receive_timeout_bootstrap() {
   // to a less aggressive non-bootstrap mode of collecting nodes that contact us
   // and through doing normal torrent announces.
   if (m_nodes.size() < num_bootstrap_complete) {
-    if (m_contacts == NULL)
+    if (!m_contacts.has_value())
       throw internal_error("DhtRouter::receive_timeout_bootstrap called without contact list.");
 
     if (!m_nodes.empty() || !m_contacts->empty())
       bootstrap();
 
     // Retry in 60 seconds.
-    priority_queue_insert(&taskScheduler, &m_taskTimeout, (cachedTime + rak::timer::from_seconds(timeout_bootstrap_retry)).round_seconds());
+    this_thread::scheduler()->wait_for_ceil_seconds(&m_task_timeout, std::chrono::seconds(timeout_bootstrap_retry));
+
     m_numRefresh = 1;  // still bootstrapping
 
   } else {
     // We won't be needing external contacts after this.
-    delete m_contacts;
-    m_contacts = NULL;
+    m_contacts.reset();
 
-    m_taskTimeout.slot() = std::bind(&DhtRouter::receive_timeout, this);
+    m_task_timeout.slot() = [this] { receive_timeout(); };
 
     if (!m_numRefresh) {
       // If we're still in the startup, do the usual refreshing too.
@@ -434,7 +406,7 @@ DhtRouter::receive_timeout_bootstrap() {
 
     } else {
       // Otherwise just set the 15 minute timer.
-      priority_queue_insert(&taskScheduler, &m_taskTimeout, (cachedTime + rak::timer::from_seconds(timeout_update)).round_seconds());
+      this_thread::scheduler()->wait_for_ceil_seconds(&m_task_timeout, std::chrono::seconds(timeout_update));
     }
 
     m_numRefresh = 2;
@@ -443,7 +415,7 @@ DhtRouter::receive_timeout_bootstrap() {
 
 void
 DhtRouter::receive_timeout() {
-  priority_queue_insert(&taskScheduler, &m_taskTimeout, (cachedTime + rak::timer::from_seconds(timeout_update)).round_seconds());
+  this_thread::scheduler()->wait_for_ceil_seconds(&m_task_timeout, std::chrono::seconds(timeout_update));
 
   m_prevToken = m_curToken;
   m_curToken = random();
@@ -452,40 +424,40 @@ DhtRouter::receive_timeout() {
   // bad nodes.
 
   // Update nodes.
-  for (DhtNodeList::accessor itr = m_nodes.begin(); itr != m_nodes.end(); ++itr) {
-    if (!itr.node()->bucket())
+  for (const auto& [id, node] : m_nodes) {
+    if (!node->bucket())
       throw internal_error("DhtRouter::receive_timeout has node without bucket.");
 
-    itr.node()->update();
+    node->update();
 
     // Try contacting nodes we haven't received anything from for a while.
     // Don't contact repeatedly unresponsive nodes; we keep them in case they
     // do send a query, until we find a better node. However, give it a last
     // chance just before deleting it.
-    if (itr.node()->is_questionable() && (!itr.node()->is_bad() || itr.node()->age() >= timeout_remove_node))
-      m_server.ping(itr.node()->id(), itr.node()->address());
+    if (node->is_questionable() && (!node->is_bad() || node->age() >= timeout_remove_node))
+      m_server.ping(node->id(), node->address());
   }
 
   // If bucket isn't full yet or hasn't received replies/queries from
   // its nodes for a while, try to find new nodes now.
-  for (DhtBucketList::const_iterator itr = m_routingTable.begin(); itr != m_routingTable.end(); ++itr) {
-    itr->second->update();
+  for (const auto& route : m_routingTable) {
+    route.second->update();
 
-    if (!itr->second->is_full() || itr->second == bucket() || itr->second->age() > timeout_bucket_bootstrap)
-      bootstrap_bucket(itr->second);
+    if (!route.second->is_full() || route.second == bucket() || route.second->age() > timeout_bucket_bootstrap)
+      bootstrap_bucket(route.second);
   }
 
   // Remove old peers and empty torrents from the tracker.
-  for (DhtTrackerList::accessor itr = m_trackers.begin(); itr != m_trackers.end(); ) {
-    itr.tracker()->prune(timeout_peer_announce);
+  for (auto itr = m_trackers.begin(); itr != m_trackers.end();) {
+    auto tracker = itr->second;
+    tracker->prune(timeout_peer_announce);
 
-    if (itr.tracker()->empty()) {
-      delete itr.tracker();
-      m_trackers.erase(itr++);
-
-    } else {
-      ++itr;
+    if (tracker->empty()) {
+      delete tracker;
+      itr = m_trackers.erase(itr);
+      continue;
     }
+    ++itr;
   }
 
   m_server.update();
@@ -518,18 +490,18 @@ DhtRouter::token_valid(raw_string token, const rak::socket_address* sa) {
   //
   // Else if token recently changed, some clients may be using the older one.
   // That way a token is valid for 15-30 minutes, instead of 0-15.
-  return 
+  return
     token == raw_string(generate_token(sa, m_curToken, reference), size_token) ||
     token == raw_string(generate_token(sa, m_prevToken, reference), size_token);
 }
 
 DhtNode*
 DhtRouter::find_node(const rak::socket_address* sa) {
-  for (DhtNodeList::accessor itr = m_nodes.begin(); itr != m_nodes.end(); ++itr)
-    if (itr.node()->address()->sa_inet()->address_n() == sa->sa_inet()->address_n())
-      return itr.node();
+  for (const auto& [id, node] : m_nodes)
+    if (node->address()->sa_inet()->address_n() == sa->sa_inet()->address_n())
+      return node;
 
-  return NULL;
+  return nullptr;
 }
 
 DhtRouter::DhtBucketList::iterator
@@ -546,7 +518,7 @@ DhtRouter::split_bucket(const DhtBucketList::iterator& itr, DhtNode* node) {
     throw internal_error("DhtRouter::split_bucket router ID ended up in wrong bucket.");
 
   // Insert new bucket with iterator hint = just before current bucket.
-  DhtBucketList::iterator other = m_routingTable.emplace_hint(itr, newBucket->id_range_end(), newBucket);
+  auto other = m_routingTable.emplace_hint(itr, newBucket->id_range_end(), newBucket);
 
   // Check that the bucket we're not adding the node to isn't empty.
   if (other->second->is_in_range(node->id())) {
@@ -565,7 +537,7 @@ DhtRouter::split_bucket(const DhtBucketList::iterator& itr, DhtNode* node) {
 
 bool
 DhtRouter::add_node_to_bucket(DhtNode* node) {
-  DhtBucketList::iterator itr = find_bucket(node->id());
+  auto itr = find_bucket(node->id());
 
   while (itr->second->is_full()) {
     // Bucket is full. If there are any bad nodes, remove the oldest.
@@ -606,22 +578,16 @@ DhtRouter::delete_node(const DhtNodeList::accessor& itr) {
   m_nodes.erase(itr);
 }
 
-struct contact_node_t {
-  contact_node_t(DhtRouter* router, int port) : m_router(router), m_port(port) { }
-
-  void operator() (const sockaddr* sa, int err)
-    { if (sa != NULL) m_router->contact(rak::socket_address::cast_from(sa), m_port); }
-
-  DhtRouter* m_router;
-  int        m_port;
-};
-
 void
 DhtRouter::bootstrap() {
   // Contact up to 8 nodes from the contact list (newest first).
   for (int count = 0; count < 8 && !m_contacts->empty(); count++) {
-    manager->connection_manager()->resolver()(m_contacts->back().first.c_str(), (int)rak::socket_address::pf_inet, SOCK_DGRAM,
-                                              contact_node_t(this, m_contacts->back().second));
+    // Currently discarding SOCK_DGRAM.
+    this_thread::resolver()->resolve_specific(this, m_contacts->back().first.c_str(), rak::socket_address::pf_inet, [this](auto sa, int) {
+      if (sa != nullptr)
+        contact(sa.get(), m_contacts->back().second);
+    });
+
     m_contacts->pop_back();
   }
 
@@ -633,15 +599,15 @@ DhtRouter::bootstrap() {
 
   // Aggressively ping all questionable nodes in our own bucket to weed
   // out bad nodes as early as possible and make room for fresh nodes.
-  for (DhtBucket::iterator itr = bucket()->begin(); itr != bucket()->end(); ++itr)
-    if (!(*itr)->is_good())
-      m_server.ping((*itr)->id(), (*itr)->address());
+  for (auto node : *bucket())
+    if (!node->is_good())
+      m_server.ping(node->id(), node->address());
 
   // Also bootstrap a random bucket, if there are others.
   if (m_routingTable.size() < 2)
     return;
 
-  DhtBucketList::iterator itr = m_routingTable.begin();
+  auto itr = m_routingTable.begin();
   std::advance(itr, random() % m_routingTable.size());
 
   if (itr->second != bucket() && itr != m_routingTable.end())
