@@ -1,52 +1,17 @@
-// libTorrent - BitTorrent library
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #ifndef LIBTORRENT_DHT_ROUTER_H
 #define LIBTORRENT_DHT_ROUTER_H
 
-#include <rak/priority_queue_default.h>
-#include <rak/socket_address.h>
-
-#include "torrent/dht_manager.h"
+#include "dht/dht_node.h"
+#include "dht/dht_hash_map.h"
+#include "dht/dht_server.h"
+#include "rak/socket_address.h"
 #include "torrent/hash_string.h"
 #include "torrent/object.h"
+#include "torrent/net/types.h"
+#include "torrent/tracker/dht_controller.h"
+#include "torrent/utils/scheduler.h"
 
-#include "dht_node.h"
-#include "dht_hash_map.h"
-#include "dht_server.h"
+#include <optional>
 
 namespace torrent {
 
@@ -60,13 +25,13 @@ class TrackerDht;
 class DhtRouter : public DhtNode {
 public:
   // How many bytes to return and verify from the 20-byte SHA token.
-  static const unsigned int size_token = 8;
+  static constexpr unsigned int size_token = 8;
 
-  static const unsigned int timeout_bootstrap_retry  =          60;  // Retry initial bootstrapping every minute.
-  static const unsigned int timeout_update           =     15 * 60;  // Regular housekeeping updates every 15 minutes.
-  static const unsigned int timeout_bucket_bootstrap =     15 * 60;  // Bootstrap idle buckets after 15 minutes.
-  static const unsigned int timeout_remove_node      = 4 * 60 * 60;  // Remove unresponsive nodes after 4 hours.
-  static const unsigned int timeout_peer_announce    =     30 * 60;  // Remove peers which haven't reannounced for 30 minutes.
+  static constexpr unsigned int timeout_bootstrap_retry  =          60;  // Retry initial bootstrapping every minute.
+  static constexpr unsigned int timeout_update           =     15 * 60;  // Regular housekeeping updates every 15 minutes.
+  static constexpr unsigned int timeout_bucket_bootstrap =     15 * 60;  // Bootstrap idle buckets after 15 minutes.
+  static constexpr unsigned int timeout_remove_node      = 4 * 60 * 60;  // Remove unresponsive nodes after 4 hours.
+  static constexpr unsigned int timeout_peer_announce    =     30 * 60;  // Remove peers which haven't reannounced for 30 minutes.
 
   // A node ID of all zero.
   static HashString zero_id;
@@ -74,19 +39,15 @@ public:
   DhtRouter(const Object& cache, const rak::socket_address* sa);
   ~DhtRouter();
 
-  // Start and stop the router. This starts/stops the UDP server as well.
   void                start(int port);
   void                stop();
 
   bool                is_active()                        { return m_server.is_active(); }
 
-  // Find peers for given download and announce ourselves.
-  void                announce(DownloadInfo* info, TrackerDht* tracker);
+  // Pass NULL to cancel_announce to cancel all announces for the tracker.
+  void                announce(const HashString& info_hash, TrackerDht* tracker);
+  void                cancel_announce(const HashString* info_hash, const TrackerDht* tracker);
 
-  // Cancel any pending transactions related to the given download (or all if NULL).
-  void                cancel_announce(DownloadInfo* info, const TrackerDht* tracker);
-
-  // Retrieve tracked torrent for the hash.
   // Returns NULL if not tracking the torrent unless create is true.
   DhtTracker*         get_tracker(const HashString& hash, bool create);
 
@@ -97,7 +58,7 @@ public:
   // Add the given host to the list of potential contacts if we haven't
   // completed the bootstrap process, or contact the given address directly.
   void                add_contact(const std::string& host, int port);
-  void                contact(const rak::socket_address* sa, int port);
+  void                contact(const sockaddr* sa, int port);
 
   // Retrieve node of given ID in constant time. Return NULL if not found, unless
   // it's our own ID in which case it returns the DhtRouter object.
@@ -124,23 +85,23 @@ public:
   raw_string          make_token(const rak::socket_address* sa, char* buffer);
   bool                token_valid(raw_string token, const rak::socket_address* sa);
 
-  DhtManager::statistics_type get_statistics() const;
-  void                reset_statistics()                      { m_server.reset_statistics(); }
+  tracker::DhtController::statistics_type get_statistics() const;
+  void                                    reset_statistics()  { m_server.reset_statistics(); }
 
   void                set_upload_throttle(ThrottleList* t)    { m_server.set_upload_throttle(t); }
   void                set_download_throttle(ThrottleList* t)  { m_server.set_download_throttle(t); }
 
 private:
   // Hostname and port of potential bootstrap nodes.
-  typedef std::pair<std::string, int> contact_t;
+  using contact_t = std::pair<std::string, int>;
 
   // Number of nodes we need to consider the bootstrap process complete.
-  static const unsigned int num_bootstrap_complete = 32;
+  static constexpr unsigned int num_bootstrap_complete = 32;
 
   // Maximum number of potential contacts to keep until bootstrap complete.
-  static const unsigned int num_bootstrap_contacts = 64;
+  static constexpr unsigned int num_bootstrap_contacts = 64;
 
-  typedef std::map<const HashString, DhtBucket*> DhtBucketList;
+  using DhtBucketList = std::map<const HashString, DhtBucket*>;
 
   DhtBucketList::iterator find_bucket(const HashString& id);
 
@@ -160,16 +121,16 @@ private:
   // buffer needs to hold an SHA1 hash (20 bytes), not just the token (8 bytes)
   char*               generate_token(const rak::socket_address* sa, int token, char buffer[20]);
 
-  rak::priority_item  m_taskTimeout;
+  utils::SchedulerEntry m_task_timeout;
 
-  DhtServer           m_server;
+  DhtServer           m_server{nullptr};
   DhtNodeList         m_nodes;
   DhtBucketList       m_routingTable;
   DhtTrackerList      m_trackers;
 
-  std::deque<contact_t>* m_contacts;
+  std::optional<std::deque<contact_t>> m_contacts;
 
-  int                 m_numRefresh;
+  int                 m_numRefresh{0};
 
   bool                m_networkUp;
 
