@@ -83,12 +83,12 @@ AvailableList::insert(AddressList* l) {
   AddressList difference;
   std::set_difference(l->begin(), l->end(), begin(), end(), std::back_inserter(difference));
 
-  std::copy(difference.begin(), difference.end(), std::back_inserter(*static_cast<base_type*>(this)));
+  static_cast<base_type*>(this)->insert(end(), difference.begin(), difference.end());
 }
 
 void
 AvailableList::erase(const rak::socket_address& sa) {
-  iterator itr = std::find(begin(), end(), sa);
+  auto itr = std::find(begin(), end(), sa);
 
   if (itr != end()) {
     *itr = back();
