@@ -46,23 +46,25 @@ class PeerChunks;
 
 class ChunkStatistics : public std::vector<uint8_t> {
 public:
-  typedef std::vector<uint8_t>            base_type;
-  typedef uint32_t                        size_type;
+  using base_type = std::vector<uint8_t>;
+  using size_type = uint32_t;
 
-  typedef base_type::value_type           value_type;
-  typedef base_type::reference            reference;
-  typedef base_type::const_reference      const_reference;
-  typedef base_type::iterator             iterator;
-  typedef base_type::const_iterator       const_iterator;
-  typedef base_type::reverse_iterator     reverse_iterator;
+  using value_type       = base_type::value_type;
+  using reference        = base_type::reference;
+  using const_reference  = base_type::const_reference;
+  using iterator         = base_type::iterator;
+  using const_iterator   = base_type::const_iterator;
+  using reverse_iterator = base_type::reverse_iterator;
 
   using base_type::empty;
   using base_type::size;
 
-  static const size_type max_accounted = 255;
+  static constexpr size_type max_accounted = 255;
 
-  ChunkStatistics() : m_complete(0), m_accounted(0) {}
-  ~ChunkStatistics() {}
+  ChunkStatistics() = default;
+  ~ChunkStatistics() = default;
+  ChunkStatistics(const ChunkStatistics&) = delete;
+  ChunkStatistics& operator=(const ChunkStatistics&) = delete;
 
   size_type           complete() const              { return m_complete; }
   //size_type           incomplete() const;
@@ -102,12 +104,8 @@ public:
 
 private:
   inline bool         should_add(PeerChunks* pc);
-
-  ChunkStatistics(const ChunkStatistics&);
-  void operator = (const ChunkStatistics&);
-
-  size_type           m_complete;
-  size_type           m_accounted;
+  size_type           m_complete{};
+  size_type           m_accounted{};
 };
 
 }
