@@ -1,9 +1,17 @@
 #include "config.h"
 
+#include "download/download_main.h"
+
+#include <cassert>
 #include <cstring>
 #include <limits>
 
+#include "manager.h"
 #include "data/chunk_list.h"
+#include "download/available_list.h"
+#include "download/chunk_selector.h"
+#include "download/chunk_statistics.h"
+#include "download/download_wrapper.h"
 #include "protocol/extensions.h"
 #include "protocol/handshake_manager.h"
 #include "protocol/initial_seed.h"
@@ -19,92 +27,59 @@
 #include "torrent/peer/connection_list.h"
 #include "torrent/peer/peer.h"
 #include "torrent/peer/peer_info.h"
-#include "torrent/tracker_controller.h"
-#include "torrent/tracker_list.h"
+#include "torrent/tracker/manager.h"
 #include "torrent/utils/log.h"
-
-#include "available_list.h"
-#include "chunk_selector.h"
-#include "chunk_statistics.h"
-#include "download_main.h"
-#include "download_wrapper.h"
+#include "tracker/thread_tracker.h"
+#include "tracker/tracker_controller.h"
+#include "tracker/tracker_list.h"
 
 #define LT_LOG_THIS(log_level, log_fmt, ...)                         \
   lt_log_print_info(LOG_TORRENT_##log_level, m_ptr->info(), "download", log_fmt, __VA_ARGS__);
 
 namespace torrent {
 
-DownloadInfo::DownloadInfo() :
-  m_flags(flag_compact | flag_accepting_new_peers | flag_accepting_seeders | flag_pex_enabled | flag_pex_active),
+DownloadMain::DownloadMain()
+  : m_info(new DownloadInfo),
+    m_tracker_list(new TrackerList),
 
-  m_upRate(60),
-  m_downRate(60),
-  m_skipRate(60),
-  
-  m_uploadedBaseline(0),
-  m_completedBaseline(0),
-  m_sizePex(0),
-  m_maxSizePex(8),
-  m_metadataSize(0),
-  
-  m_creationDate(0),
-  m_loadDate(rak::timer::current_seconds()),
+    m_chunkList(new ChunkList),
+    m_chunkSelector(new ChunkSelector(file_list()->mutable_data())),
+    m_chunkStatistics(new ChunkStatistics),
+    m_connectionList(new ConnectionList(this)) {
 
-  m_upload_unchoked(0),
-  m_download_unchoked(0) {
-}
+  m_info->set_load_date(utils::cast_seconds(utils::time_since_epoch()).count());
 
-DownloadMain::DownloadMain() :
-  m_info(new DownloadInfo),
+  // Only set trivial values here, the rest is done in DownloadWrapper.
 
-  m_choke_group(NULL),
-  m_chunkList(new ChunkList),
-  m_chunkSelector(new ChunkSelector(file_list()->mutable_data())),
-  m_chunkStatistics(new ChunkStatistics),
+  m_delegator.slot_chunk_find() = [this](auto pc, auto prio) { return m_chunkSelector->find(pc, prio); };
+  m_delegator.slot_chunk_size() = [this](auto i) { return file_list()->chunk_index_size(i); };
 
-  m_initialSeeding(NULL),
-  m_uploadThrottle(NULL),
-  m_downloadThrottle(NULL) {
+  m_delegator.transfer_list()->slot_canceled()  = [this](auto i) { m_chunkSelector->not_using_index(i); };
+  m_delegator.transfer_list()->slot_queued()    = [this](auto i) { m_chunkSelector->using_index(i); };
+  m_delegator.transfer_list()->slot_completed() = [this](auto i) { receive_chunk_done(i); };
+  m_delegator.transfer_list()->slot_corrupt()   = [this](auto i) { receive_corrupt_chunk(i); };
 
-  m_tracker_list = new TrackerList();
-  m_tracker_controller = new TrackerController(m_tracker_list);
-
-  m_tracker_list->slot_success() = std::bind(&TrackerController::receive_success, m_tracker_controller, std::placeholders::_1, std::placeholders::_2);
-  m_tracker_list->slot_failure() = std::bind(&TrackerController::receive_failure, m_tracker_controller, std::placeholders::_1, std::placeholders::_2);
-  m_tracker_list->slot_scrape_success() = std::bind(&TrackerController::receive_scrape, m_tracker_controller, std::placeholders::_1);
-  m_tracker_list->slot_tracker_enabled()  = std::bind(&TrackerController::receive_tracker_enabled, m_tracker_controller, std::placeholders::_1);
-  m_tracker_list->slot_tracker_disabled() = std::bind(&TrackerController::receive_tracker_disabled, m_tracker_controller, std::placeholders::_1);
-
-  m_connectionList = new ConnectionList(this);
-
-  m_delegator.slot_chunk_find() = std::bind(&ChunkSelector::find, m_chunkSelector, std::placeholders::_1, std::placeholders::_2);
-  m_delegator.slot_chunk_size() = std::bind(&FileList::chunk_index_size, file_list(), std::placeholders::_1);
-
-  m_delegator.transfer_list()->slot_canceled()  = std::bind(&ChunkSelector::not_using_index, m_chunkSelector, std::placeholders::_1);
-  m_delegator.transfer_list()->slot_queued()    = std::bind(&ChunkSelector::using_index, m_chunkSelector, std::placeholders::_1);
-  m_delegator.transfer_list()->slot_completed() = std::bind(&DownloadMain::receive_chunk_done, this, std::placeholders::_1);
-  m_delegator.transfer_list()->slot_corrupt()   = std::bind(&DownloadMain::receive_corrupt_chunk, this, std::placeholders::_1);
-
-  m_delayDisconnectPeers.slot() = std::bind(&ConnectionList::disconnect_queued, m_connectionList);
-  m_taskTrackerRequest.slot() = std::bind(&DownloadMain::receive_tracker_request, this);
+  m_delay_disconnect_peers.slot() = [this] { m_connectionList->disconnect_queued(); };
+  m_task_tracker_request.slot()     = [this] { receive_tracker_request(); };
 
   m_chunkList->set_data(file_list()->mutable_data());
-  m_chunkList->slot_create_chunk() = std::bind(&FileList::create_chunk_index, file_list(), std::placeholders::_1, std::placeholders::_2);
-  m_chunkList->slot_free_diskspace() = std::bind(&FileList::free_diskspace, file_list());
+
+  m_chunkList->slot_create_chunk() = [this](uint32_t index, int prot) {
+      return file_list()->create_chunk_index(index, prot);
+    };
+  m_chunkList->slot_create_hashing_chunk() = [this](uint32_t index, int prot) {
+      return file_list()->create_hashing_chunk_index(index, prot);
+    };
+  m_chunkList->slot_free_diskspace() = [this]() {
+      return file_list()->free_diskspace();
+    };
 }
 
 DownloadMain::~DownloadMain() {
-  if (m_taskTrackerRequest.is_queued())
-    throw internal_error("DownloadMain::~DownloadMain(): m_taskTrackerRequest is queued.");
+  assert(!m_task_tracker_request.is_scheduled() && "DownloadMain::~DownloadMain(): m_task_tracker_request is scheduled.");
 
-  // Check if needed.
-  m_connectionList->clear();
-  m_tracker_list->clear();
+  assert(m_info->size_pex() == 0 && "DownloadMain::~DownloadMain(): m_info->size_pex() != 0.");
 
-  if (m_info->size_pex() != 0)
-    throw internal_error("DownloadMain::~DownloadMain(): m_info->size_pex() != 0.");
-
-  delete m_tracker_controller;
   delete m_tracker_list;
   delete m_connectionList;
 
@@ -117,6 +92,20 @@ DownloadMain::~DownloadMain() {
   m_ut_pex_initial.clear();
 }
 
+void
+DownloadMain::post_initialize() {
+  auto tracker_controller = new TrackerController(m_tracker_list);
+
+  m_tracker_list->slot_success()          = [tracker_controller](const auto& t, auto al) { return tracker_controller->receive_success(t, al); };
+  m_tracker_list->slot_failure()          = [tracker_controller](const auto& t, const auto& str) { tracker_controller->receive_failure(t, str); };
+  m_tracker_list->slot_scrape_success()   = [tracker_controller](const auto& t) { tracker_controller->receive_scrape(t); };
+  m_tracker_list->slot_tracker_enabled()  = [tracker_controller](const auto& t) { tracker_controller->receive_tracker_enabled(t); };
+  m_tracker_list->slot_tracker_disabled() = [tracker_controller](const auto& t) { tracker_controller->receive_tracker_disabled(t); };
+
+  // TODO: Move tracker list to manager, and add the proper barrier for slots.
+  m_tracker_controller = thread_tracker()->tracker_manager()->add_controller(info(), tracker_controller);
+}
+
 std::pair<ThrottleList*, ThrottleList*>
 DownloadMain::throttles(const sockaddr* sa) {
   ThrottlePair pair = ThrottlePair(NULL, NULL);
@@ -133,7 +122,8 @@ DownloadMain::open(int flags) {
   if (info()->is_open())
     throw internal_error("Tried to open a download that is already open");
 
-  file_list()->open(flags & FileList::open_no_create);
+  // TODO: Move file_list open calls to DownloadMain.
+  file_list()->open(true, (flags & FileList::open_no_create));
 
   m_chunkList->resize(file_list()->size_chunks());
   m_chunkStatistics->initialize(file_list()->size_chunks());
@@ -166,21 +156,32 @@ DownloadMain::close() {
   m_chunkSelector->cleanup();
 }
 
-void DownloadMain::start() {
+void DownloadMain::start(int flags) {
   if (!info()->is_open())
     throw internal_error("Tried to start a closed download");
 
   if (info()->is_active())
     throw internal_error("Tried to start an active download");
 
+  // Close and clear open files to ensure hashing file/mmap advise is cleared.
+  //
+  // We should not need to clear chunks after hash checking the whole torrent as those chunk handle
+  // references go to zero.
+  file_list()->close_all_files();
+
+  // If the FileList::open_no_create flag was not set, our new
+  // behavior is to create all zero-length files with
+  // flag_queued_create set.
+  file_list()->open(false, (flags & ~FileList::open_no_create));
+
   info()->set_flags(DownloadInfo::flag_active);
   chunk_list()->set_flags(ChunkList::flag_active);
 
   m_delegator.set_aggressive(false);
-  update_endgame();  
+  update_endgame();
 
   receive_connect_peers();
-}  
+}
 
 void
 DownloadMain::stop() {
@@ -192,14 +193,13 @@ DownloadMain::stop() {
   info()->unset_flags(DownloadInfo::flag_active);
   chunk_list()->unset_flags(ChunkList::flag_active);
 
-  m_slotStopHandshakes(this);
+  m_slot_stop_handshakes(this);
   connection_list()->erase_remaining(connection_list()->begin(), ConnectionList::disconnect_available);
 
-  delete m_initialSeeding;
-  m_initialSeeding = NULL;
+  m_initial_seeding.reset();
 
-  priority_queue_erase(&taskScheduler, &m_delayDisconnectPeers);
-  priority_queue_erase(&taskScheduler, &m_taskTrackerRequest);
+  this_thread::scheduler()->erase(&m_delay_disconnect_peers);
+  this_thread::scheduler()->erase(&m_task_tracker_request);
 
   if (info()->upload_unchoked() != 0 || info()->download_unchoked() != 0)
     throw internal_error("DownloadMain::stop(): info()->upload_unchoked() != 0 || info()->download_unchoked() != 0.");
@@ -210,13 +210,13 @@ DownloadMain::start_initial_seeding() {
   if (!file_list()->is_done())
     return false;
 
-  m_initialSeeding = new InitialSeeding(this);
+  m_initial_seeding.reset(new InitialSeeding(this));
   return true;
 }
 
 void
 DownloadMain::initial_seeding_done(PeerConnectionBase* pcb) {
-  if (m_initialSeeding == NULL)
+  if (m_initial_seeding == nullptr)
     throw internal_error("DownloadMain::initial_seeding_done called when not initial seeding.");
 
   // Close all connections but the currently active one (pcb), that
@@ -226,7 +226,7 @@ DownloadMain::initial_seeding_done(PeerConnectionBase* pcb) {
   // the connection list, so don't treat it as an error. Make sure to
   // catch close_connection() at the caller of new_peer(...) and just
   // close the filedesc before proceeding as normal.
-  ConnectionList::iterator pcb_itr = std::find(m_connectionList->begin(), m_connectionList->end(), pcb);
+  auto pcb_itr = std::find(m_connectionList->begin(), m_connectionList->end(), pcb);
 
   if (pcb_itr != m_connectionList->end()) {
     std::iter_swap(m_connectionList->begin(), pcb_itr);
@@ -236,12 +236,11 @@ DownloadMain::initial_seeding_done(PeerConnectionBase* pcb) {
   }
 
   // Switch to normal seeding.
-  DownloadManager::iterator itr = manager->download_manager()->find(m_info);
+  auto itr = manager->download_manager()->find(m_info);
   (*itr)->set_connection_type(Download::CONNECTION_SEED);
   m_connectionList->slot_new_connection(&createPeerConnectionSeed);
 
-  delete m_initialSeeding;
-  m_initialSeeding = NULL;
+  m_initial_seeding.reset();
 
   // And close the current connection.
   throw close_connection();
@@ -256,12 +255,13 @@ DownloadMain::update_endgame() {
 
 void
 DownloadMain::receive_chunk_done(unsigned int index) {
-  ChunkHandle handle = m_chunkList->get(index);
+  // TODO: Should we unmap the chunk here if we want sequential access?
+  ChunkHandle handle = m_chunkList->get(index, ChunkList::get_hashing);
 
   if (!handle.is_valid())
     throw storage_error("DownloadState::chunk_done(...) called with an index we couldn't retrieve from storage");
 
-  m_slotHashCheckAdd(handle);
+  m_slot_hash_check_add(handle);
 }
 
 void
@@ -280,7 +280,7 @@ DownloadMain::receive_corrupt_chunk(PeerInfo* peerInfo) {
 
 void
 DownloadMain::add_peer(const rak::socket_address& sa) {
-  m_slotStartHandshake(sa, this);
+  m_slot_start_handshake(sa, this);
 }
 
 void
@@ -300,11 +300,11 @@ DownloadMain::receive_connect_peers() {
   while (!peer_list()->available_list()->empty() &&
          manager->connection_manager()->can_connect() &&
          connection_list()->size() < connection_list()->min_size() &&
-         connection_list()->size() + m_slotCountHandshakes(this) < connection_list()->max_size()) {
+         connection_list()->size() + m_slot_count_handshakes(this) < connection_list()->max_size()) {
     rak::socket_address sa = peer_list()->available_list()->pop_random();
 
     if (connection_list()->find(sa.c_sockaddr()) == connection_list()->end())
-      m_slotStartHandshake(sa, this);
+      m_slot_start_handshake(sa, this);
   }
 }
 
@@ -313,7 +313,7 @@ DownloadMain::receive_tracker_success() {
   if (!info()->is_active())
     return;
 
-  priority_queue_update(&taskScheduler, &m_taskTrackerRequest, (cachedTime + rak::timer::from_seconds(10)).round_seconds());
+  this_thread::scheduler()->update_wait_for_ceil_seconds(&m_task_tracker_request, 10s);
 }
 
 void
@@ -321,11 +321,11 @@ DownloadMain::receive_tracker_request() {
   if ((info()->is_pex_enabled() && info()->size_pex()) > 0
       || connection_list()->size() + peer_list()->available_list()->size() / 2 >= connection_list()->min_size()) {
 
-    m_tracker_controller->stop_requesting();
+    m_tracker_controller.stop_requesting();
     return;
   }
 
-  m_tracker_controller->start_requesting();
+  m_tracker_controller.start_requesting();
 }
 
 bool
@@ -362,9 +362,9 @@ DownloadMain::do_peer_exchange() {
 
   ProtocolExtension::PEXList current;
 
-  for (ConnectionList::iterator itr = m_connectionList->begin(); itr != m_connectionList->end(); ++itr) {
-    PeerConnectionBase* pcb = (*itr)->m_ptr();
-    const rak::socket_address* sa = rak::socket_address::cast_from(pcb->peer_info()->socket_address());
+  for (auto& connection : *m_connectionList) {
+    auto pcb = connection->m_ptr();
+    auto sa  = rak::socket_address::cast_from(pcb->peer_info()->socket_address());
 
     if (pcb->peer_info()->listen_port() != 0 && sa->family() == rak::socket_address::af_inet)
       current.emplace_back(sa->sa_inet()->address_n(), htons(pcb->peer_info()->listen_port()));
@@ -391,7 +391,7 @@ DownloadMain::do_peer_exchange() {
     DataBuffer* message = pcb->extension_message();
 
     if (!message->empty() && (message->data() == m_ut_pex_initial.data() || message->data() == m_ut_pex_delta.data())) {
-      char* buffer = new char[message->length()];
+      auto buffer = new char[message->length()];
       memcpy(buffer, message->data(), message->length());
       message->set(buffer, buffer + message->length(), true);
     }
