@@ -2,18 +2,18 @@
 #define LIBTORRENT_DOWNLOAD_MAIN_H
 
 #include <deque>
-
-#include "globals.h"
-
-#include "delegator.h"
+#include <utility>
 
 #include "data/chunk_handle.h"
 #include "download/available_list.h"
+#include "download/delegator.h"
 #include "net/data_buffer.h"
 #include "torrent/download_info.h"
 #include "torrent/download/group_entry.h"
 #include "torrent/data/file_list.h"
 #include "torrent/peer/peer_list.h"
+#include "torrent/tracker/wrappers.h"
+#include "torrent/utils/scheduler.h"
 
 namespace torrent {
 
@@ -25,32 +25,35 @@ class choke_group;
 class ConnectionList;
 class DownloadWrapper;
 class HandshakeManager;
-class TrackerController;
-class TrackerList;
 class DownloadInfo;
 class ThrottleList;
 class InitialSeeding;
 
 class DownloadMain {
 public:
-  typedef std::deque<std::pair<rak::timer, uint32_t> > have_queue_type;
-  typedef std::vector<SocketAddressCompact>            pex_list;
+  using have_queue_type = std::deque<std::pair<std::chrono::microseconds, uint32_t>>;
+  using pex_list        = std::vector<SocketAddressCompact>;
 
   DownloadMain();
   ~DownloadMain();
 
+  DownloadMain(const DownloadMain&) = delete;
+  DownloadMain& operator=(const DownloadMain&) = delete;
+
+  void                post_initialize();
+
   void                open(int flags);
   void                close();
 
-  void                start();
+  void                start(int flags);
   void                stop();
 
-  class choke_group*       choke_group()                              { return m_choke_group; }
-  const class choke_group* c_choke_group() const                      { return m_choke_group; }
-  void                set_choke_group(class choke_group* grp)         { m_choke_group = grp; }
+  class choke_group*       choke_group()                           { return m_choke_group; }
+  const class choke_group* c_choke_group() const                   { return m_choke_group; }
+  void                     set_choke_group(class choke_group* grp) { m_choke_group = grp; }
 
-  TrackerController*  tracker_controller()                       { return m_tracker_controller; }
-  TrackerList*        tracker_list()                             { return m_tracker_list; }
+  tracker::TrackerControllerWrapper tracker_controller()           { return m_tracker_controller; }
+  TrackerList*                      tracker_list()                 { return m_tracker_list; }
 
   DownloadInfo*       info()                                     { return m_info; }
 
@@ -63,7 +66,7 @@ public:
 
   have_queue_type*    have_queue()                               { return &m_haveQueue; }
 
-  InitialSeeding*     initial_seeding()                          { return m_initialSeeding; }
+  InitialSeeding*     initial_seeding()                          { return m_initial_seeding.get(); }
   bool                start_initial_seeding();
   void                initial_seeding_done(PeerConnectionBase* pcb);
 
@@ -73,18 +76,18 @@ public:
 
   std::pair<ThrottleList*, ThrottleList*> throttles(const sockaddr* sa);
 
-  ThrottleList*       upload_throttle()                          { return m_uploadThrottle; }
-  void                set_upload_throttle(ThrottleList* t)       { m_uploadThrottle = t; }
+  ThrottleList*       upload_throttle()                          { return m_upload_throttle; }
+  void                set_upload_throttle(ThrottleList* t)       { m_upload_throttle = t; }
 
-  ThrottleList*       download_throttle()                        { return m_downloadThrottle; }
-  void                set_download_throttle(ThrottleList* t)     { m_downloadThrottle = t; }
+  ThrottleList*       download_throttle()                        { return m_download_throttle; }
+  void                set_download_throttle(ThrottleList* t)     { m_download_throttle = t; }
 
   group_entry*        up_group_entry()                           { return &m_up_group_entry; }
   group_entry*        down_group_entry()                         { return &m_down_group_entry; }
 
   DataBuffer          get_ut_pex(bool initial)                   { return (initial ? m_ut_pex_initial : m_ut_pex_delta).clone(); }
 
-  bool                want_pex_msg()                             { return m_info->is_pex_active() && m_peerList.available_list()->want_more(); }; 
+  bool                want_pex_msg()                             { return m_info->is_pex_active() && m_peerList.available_list()->want_more(); };
 
   void                set_metadata_size(size_t s);
 
@@ -92,16 +95,16 @@ public:
   void                setup_delegator();
   void                setup_tracker();
 
-  typedef std::function<uint32_t(DownloadMain*)>                         slot_count_handshakes_type;
-  typedef std::function<void(ChunkHandle)>                               slot_hash_check_add_type;
+  using slot_count_handshakes_type = std::function<uint32_t(DownloadMain*)>;
+  using slot_hash_check_add_type   = std::function<void(ChunkHandle)>;
 
-  typedef std::function<void(const rak::socket_address&, DownloadMain*)> slot_start_handshake_type;
-  typedef std::function<void(DownloadMain*)>                             slot_stop_handshakes_type;
+  using slot_start_handshake_type = std::function<void(const rak::socket_address&, DownloadMain*)>;
+  using slot_stop_handshakes_type = std::function<void(DownloadMain*)>;
 
-  void                slot_start_handshake(slot_start_handshake_type s) { m_slotStartHandshake = s; }
-  void                slot_stop_handshakes(slot_stop_handshakes_type s) { m_slotStopHandshakes = s; }
-  void                slot_count_handshakes(slot_count_handshakes_type s) { m_slotCountHandshakes = s; }
-  void                slot_hash_check_add(slot_hash_check_add_type s)     { m_slotHashCheckAdd = s; }
+  void                slot_start_handshake(slot_start_handshake_type s) { m_slot_start_handshake = std::move(s); }
+  void                slot_stop_handshakes(slot_stop_handshakes_type s) { m_slot_stop_handshakes = std::move(s); }
+  void                slot_count_handshakes(slot_count_handshakes_type s) { m_slot_count_handshakes = std::move(s); }
+  void                slot_hash_check_add(slot_hash_check_add_type s)     { m_slot_hash_check_add = std::move(s); }
 
   void                add_peer(const rak::socket_address& sa);
 
@@ -118,26 +121,22 @@ public:
 
   void                update_endgame();
 
-  rak::priority_item& delay_download_done()       { return m_delay_download_done; }
-  rak::priority_item& delay_partially_done()      { return m_delay_partially_done; }
-  rak::priority_item& delay_partially_restarted() { return m_delay_partially_restarted; }
+  auto&               delay_download_done()       { return m_delay_download_done; }
+  auto&               delay_partially_done()      { return m_delay_partially_done; }
+  auto&               delay_partially_restarted() { return m_delay_partially_restarted; }
 
-  rak::priority_item& delay_disconnect_peers() { return m_delayDisconnectPeers; }
+  auto&               delay_disconnect_peers()    { return m_delay_disconnect_peers; }
 
 private:
-  // Disable copy ctor and assignment.
-  DownloadMain(const DownloadMain&);
-  void operator = (const DownloadMain&);
-
   void                setup_start();
   void                setup_stop();
 
   DownloadInfo*       m_info;
 
-  TrackerController*  m_tracker_controller;
-  TrackerList*        m_tracker_list;
+  tracker::TrackerControllerWrapper m_tracker_controller;
+  TrackerList*                      m_tracker_list;
 
-  class choke_group*  m_choke_group;
+  class choke_group*  m_choke_group{};
 
   group_entry         m_up_group_entry;
   group_entry         m_down_group_entry;
@@ -148,7 +147,7 @@ private:
 
   Delegator           m_delegator;
   have_queue_type     m_haveQueue;
-  InitialSeeding*     m_initialSeeding;
+  std::unique_ptr<InitialSeeding> m_initial_seeding;
 
   ConnectionList*     m_connectionList;
   FileList            m_fileList;
@@ -158,21 +157,21 @@ private:
   DataBuffer          m_ut_pex_initial;
   pex_list            m_ut_pex_list;
 
-  ThrottleList*       m_uploadThrottle;
-  ThrottleList*       m_downloadThrottle;
+  ThrottleList*       m_upload_throttle{};
+  ThrottleList*       m_download_throttle{};
 
-  slot_start_handshake_type m_slotStartHandshake;
-  slot_stop_handshakes_type m_slotStopHandshakes;
+  slot_start_handshake_type  m_slot_start_handshake;
+  slot_stop_handshakes_type  m_slot_stop_handshakes;
 
-  slot_count_handshakes_type m_slotCountHandshakes;
-  slot_hash_check_add_type   m_slotHashCheckAdd;
+  slot_count_handshakes_type m_slot_count_handshakes;
+  slot_hash_check_add_type   m_slot_hash_check_add;
 
-  rak::priority_item  m_delay_download_done;
-  rak::priority_item  m_delay_partially_done;
-  rak::priority_item  m_delay_partially_restarted;
+  utils::SchedulerEntry      m_delay_download_done;
+  utils::SchedulerEntry      m_delay_partially_done;
+  utils::SchedulerEntry      m_delay_partially_restarted;
 
-  rak::priority_item  m_delayDisconnectPeers;
-  rak::priority_item  m_taskTrackerRequest;
+  utils::SchedulerEntry      m_delay_disconnect_peers;
+  utils::SchedulerEntry      m_task_tracker_request;
 };
 
 }
