@@ -21,6 +21,8 @@ class DownloadWrapper {
 public:
   DownloadWrapper();
   ~DownloadWrapper();
+  DownloadWrapper(const DownloadWrapper&) = delete;
+  DownloadWrapper& operator=(const DownloadWrapper&) = delete;
 
   DownloadInfo*       info()                                  { return m_main->info(); }
   download_data*      data()                                  { return m_main->file_list()->mutable_data(); }
@@ -28,21 +30,21 @@ public:
   ChunkList*          chunk_list()                            { return m_main->chunk_list(); }
 
   // Initialize hash checker and various download stuff.
-  void                initialize(const std::string& hash, const std::string& id);
+  void                initialize(const std::string& hash, const std::string& id, uint32_t tracker_key);
 
   void                close();
 
   bool                is_stopped() const;
 
-  DownloadMain*       main()                                  { return m_main; }
-  const DownloadMain* main() const                            { return m_main; }
-  HashTorrent*        hash_checker()                          { return m_hashChecker; }
+  DownloadMain*       main()                                  { return m_main.get(); }
+  const DownloadMain* main() const                            { return m_main.get(); }
+  HashTorrent*        hash_checker()                          { return m_hash_checker.get(); }
 
-  Object*             bencode()                               { return m_bencode; }
-  void                set_bencode(Object* o)                  { m_bencode = o; }
+  Object*             bencode()                               { return m_bencode.get(); }
+  void                set_bencode(Object* o)                  { m_bencode.reset(o); }
 
-  HashQueue*          hash_queue()                            { return m_hashQueue; }
-  void                set_hash_queue(HashQueue* q)            { m_hashQueue = q; }
+  HashQueue*          hash_queue()                            { return m_hash_queue; }
+  void                set_hash_queue(HashQueue* q)            { m_hash_queue = q; }
 
   const std::string&  complete_hash()                            { return m_hash; }
   const char*         chunk_hash(unsigned int index)             { return m_hash.c_str() + 20 * index; }
@@ -58,7 +60,7 @@ public:
   void                receive_initial_hash();
   void                receive_hash_done(ChunkHandle handle, const char* hash);
 
-  void                check_chunk_hash(ChunkHandle handle);
+  void                check_chunk_hash(ChunkHandle handle, bool hashing);
 
   void                receive_storage_error(const std::string& str);
   uint32_t            receive_tracker_success(AddressList* l);
@@ -69,19 +71,16 @@ public:
   void                receive_update_priorities();
 
 private:
-  DownloadWrapper(const DownloadWrapper&);
-  void operator = (const DownloadWrapper&);
-
   void                finished_download();
 
-  DownloadMain*       m_main;
-  Object*             m_bencode;
-  HashTorrent*        m_hashChecker;
-  HashQueue*          m_hashQueue;
+  std::unique_ptr<DownloadMain> m_main;
+  std::unique_ptr<Object>       m_bencode;
+  std::unique_ptr<HashTorrent>  m_hash_checker;
+  HashQueue*                    m_hash_queue;
 
   std::string         m_hash;
 
-  int                 m_connectionType;
+  int                 m_connectionType{0};
 };
 
 }
