@@ -52,7 +52,7 @@ public:
 
   ~Listen() override { close(); }
 
-  bool                open(uint16_t first, uint16_t last, int backlog, const rak::socket_address* bindAddress);
+  bool                open(uint16_t first, uint16_t last, int backlog, const sockaddr* bindAddress);
   void                close();
 
   bool                is_open() const { return get_fd().is_valid(); }
