@@ -1,39 +1,3 @@
-// libTorrent - BitTorrent library
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #ifndef LIBTORRENT_NET_PROTOCOL_BUFFER_H
 #define LIBTORRENT_NET_PROTOCOL_BUFFER_H
 
@@ -48,11 +12,11 @@ namespace torrent {
 template <uint16_t tmpl_size>
 class ProtocolBuffer {
 public:
-  typedef uint8_t     value_type;
-  typedef value_type* iterator;
+  using value_type = uint8_t;
+  using iterator   = value_type*;
   // TODO: Change to 32-bit,
-  typedef uint16_t    size_type;
-  typedef int16_t     difference_type;
+  using size_type       = uint16_t;
+  using difference_type = int16_t;
 
   void                reset()                       { m_position = m_end = begin(); }
   void                reset_position()              { m_position = m_buffer; }
@@ -144,7 +108,7 @@ ProtocolBuffer<tmpl_size>::consume(difference_type v) {
   if (remaining())
     return false;
 
-  return true; 
+  return true;
 }
 
 template <uint16_t tmpl_size>
