@@ -1,39 +1,3 @@
-// libTorrent - BitTorrent library
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #include "config.h"
 
 #include <errno.h>
@@ -210,6 +174,11 @@ SocketFd::bind(const rak::socket_address& sa, unsigned int length) {
   return !::bind(m_fd, sa.c_sockaddr(), length);
 }
 
+bool
+SocketFd::bind_sa(const sockaddr* sa) {
+  return bind(*rak::socket_address::cast_from(sa));
+}
+
 bool
 SocketFd::connect(const rak::socket_address& sa) {
   check_valid();
@@ -222,6 +191,11 @@ SocketFd::connect(const rak::socket_address& sa) {
   return !::connect(m_fd, sa.c_sockaddr(), sa.length()) || errno == EINPROGRESS;
 }
 
+bool
+SocketFd::connect_sa(const sockaddr* sa) {
+  return connect(*rak::socket_address::cast_from(sa));
+}
+
 bool
 SocketFd::getsockname(rak::socket_address *sa) {
   check_valid();
