@@ -55,12 +55,12 @@ namespace torrent {
 
 class SocketSet : private std::vector<Event*, rak::cacheline_allocator<Event*> > {
 public:
-  typedef uint32_t    size_type;
+  using size_type = uint32_t;
 
-  typedef std::vector<Event*, rak::cacheline_allocator<Event*> > base_type;
-  typedef std::vector<size_type, rak::cacheline_allocator<size_type> > Table;
+  using base_type = std::vector<Event*, rak::cacheline_allocator<Event*>>;
+  using Table     = std::vector<size_type, rak::cacheline_allocator<size_type>>;
 
-  static const size_type npos = static_cast<size_type>(-1);
+  static constexpr auto npos = ~size_type{0};
 
   using base_type::value_type;
 
