@@ -1,39 +1,3 @@
-// libTorrent - BitTorrent library
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #include "config.h"
 
 #include <algorithm>
@@ -46,13 +10,6 @@
 namespace torrent {
 
 ThrottleList::ThrottleList() :
-  m_enabled(false),
-  m_size(0),
-  m_outstandingQuota(0),
-  m_unallocatedQuota(0),
-  m_unusedUnthrottledQuota(0),
-  m_rateAdded(0),
-
   m_minChunkSize(2 << 10),
   m_maxChunkSize(16 << 10),
 
@@ -62,12 +19,12 @@ ThrottleList::ThrottleList() :
 
 bool
 ThrottleList::is_active(const ThrottleNode* node) const {
-  return std::find(begin(), (const_iterator)m_splitActive, node) != m_splitActive;
+  return std::find(begin(), const_iterator(m_splitActive), node) != m_splitActive;
 }
 
 bool
 ThrottleList::is_inactive(const ThrottleNode* node) const {
-  return std::find((const_iterator)m_splitActive, end(), node) != end();
+  return std::find(const_iterator(m_splitActive), end(), node) != end();
 }
 
 bool
@@ -112,8 +69,8 @@ ThrottleList::disable() {
   m_unallocatedQuota = 0;
   m_unusedUnthrottledQuota = 0;
 
-  std::for_each(begin(), end(), std::mem_fun(&ThrottleNode::clear_quota));
-  std::for_each(m_splitActive, end(), std::mem_fun(&ThrottleNode::activate));
+  std::for_each(begin(), end(), std::mem_fn(&ThrottleNode::clear_quota));
+  std::for_each(m_splitActive, end(), std::mem_fn(&ThrottleNode::activate));
 
   m_splitActive = end();
 }
