@@ -49,12 +49,13 @@ class SocketBase;
 
 class ThrottleNode {
 public:
-  typedef ThrottleList::iterator                  iterator;
-  typedef ThrottleList::const_iterator            const_iterator;
+  using iterator       = ThrottleList::iterator;
+  using const_iterator = ThrottleList::const_iterator;
 
-  typedef std::function<void ()> slot_void;
+  using slot_void = std::function<void()>;
 
   ThrottleNode(uint32_t rateSpan) : m_rate(rateSpan)  { clear_quota(); }
+  ~ThrottleNode() = default;
 
   Rate*               rate()                          { return &m_rate; }
   const Rate*         rate() const                    { return &m_rate; }
@@ -72,8 +73,8 @@ public:
   slot_void&          slot_activate()                 { return m_slot_activate; }
 
 private:
-  ThrottleNode(const ThrottleNode&);
-  void operator = (const ThrottleNode&);
+  ThrottleNode(const ThrottleNode&) = delete;
+  ThrottleNode& operator=(const ThrottleNode&) = delete;
 
   uint32_t            m_quota;
   iterator            m_listIterator;
