@@ -159,7 +159,7 @@ ProtocolExtension::generate_handshake_message() {
                                                       message);
 
   int length = result.second - buffer;
-  char* copy = new char[length];
+  auto copy = new char[length];
   memcpy(copy, buffer, length);
 
   return DataBuffer(copy, copy + length);
@@ -167,7 +167,7 @@ ProtocolExtension::generate_handshake_message() {
 
 inline DataBuffer
 ProtocolExtension::build_bencode(size_t maxLength, const char* format, ...) {
-  char* b = new char[maxLength];
+  auto b = new char[maxLength];
 
   va_list args;
   va_start(args, format);
@@ -197,8 +197,8 @@ ProtocolExtension::generate_ut_pex_message(const PEXList& added, const PEXList&
   int removed_len = removed.size() * 6;
 
   // Manually create bencoded map { "added" => added, "dropped" => dropped }
-  char* buffer = new char[32 + added_len + removed_len];
-  char* end = buffer;
+  auto buffer = new char[32 + added_len + removed_len];
+  auto end = buffer;
 
   end += sprintf(end, "d5:added%d:", added_len);
   memcpy(end, added.begin()->c_str(), added_len);
@@ -220,7 +220,7 @@ ProtocolExtension::read_start(int type, uint32_t length, bool skip) {
   if (is_default() || (type >= FIRST_INVALID) || length > (1 << 15))
     throw communication_error("Received invalid extension message.");
 
-  if (m_read != NULL || (int32_t)length < 0)
+  if (m_read != NULL || static_cast<int32_t>(length) < 0)
     throw internal_error("ProtocolExtension::read_start called in inconsistent state.");
 
   m_readLeft = length;
@@ -394,20 +394,20 @@ ProtocolExtension::send_metadata_piece(size_t piece) {
   if (m_download->info()->is_meta_download() || piece >= pieceEnd) {
     // reject: { "msg_type" => 2, "piece" => ... }
     m_pendingType = UT_METADATA;
-    m_pending = build_bencode(40, "d8:msg_typei2e5:piecei%zuee", piece);
+    m_pending = build_bencode(sizeof(size_t) + 36, "d8:msg_typei2e5:piecei%zuee", piece);
     return;
   }
 
   // These messages will be rare, so we'll just build the
   // metadata here instead of caching it uselessly.
-  char* buffer = new char[metadataSize];
+  auto buffer = new char[metadataSize];
   object_write_bencode_c(object_write_to_buffer, NULL, object_buffer_t(buffer, buffer + metadataSize), 
                          &(*manager->download_manager()->find(m_download->info()))->bencode()->get_key("info"));
 
   // data: { "msg_type" => 1, "piece" => ..., "total_size" => ... } followed by piece data (outside of dictionary)
   size_t length = piece == pieceEnd - 1 ? m_download->info()->metadata_size() % metadata_piece_size : metadata_piece_size;
   m_pendingType = UT_METADATA;
-  m_pending = build_bencode(length + 128, "d8:msg_typei1e5:piecei%zue10:total_sizei%zuee", piece, metadataSize);
+  m_pending = build_bencode((2 * sizeof(size_t)) + length + 120, "d8:msg_typei1e5:piecei%zue10:total_sizei%zuee", piece, metadataSize);
 
   memcpy(m_pending.end(), buffer + (piece << metadata_piece_shift), length);
   m_pending.set(m_pending.data(), m_pending.end() + length, m_pending.owned());
@@ -423,7 +423,7 @@ ProtocolExtension::request_metadata_piece(const Piece* p) {
     return false;
 
   m_pendingType = UT_METADATA;
-  m_pending = build_bencode(40, "d8:msg_typei0e5:piecei%uee", (unsigned)(p->offset() >> metadata_piece_shift));
+  m_pending     = build_bencode(40, "d8:msg_typei0e5:piecei%uee", static_cast<unsigned>(p->offset() >> metadata_piece_shift));
   return true;
 }
 
