@@ -1,26 +1,25 @@
 #include "config.h"
 
+#include "handshake.h"
+
+#include <cassert>
 #include <stdio.h>
 
+#include "manager.h"
 #include "download/download_main.h"
 #include "net/throttle_list.h"
-#include "torrent/dht_manager.h"
+#include "protocol/extensions.h"
+#include "protocol/handshake_manager.h"
 #include "torrent/download_info.h"
 #include "torrent/exceptions.h"
 #include "torrent/error.h"
 #include "torrent/poll.h"
 #include "torrent/throttle.h"
-#include "torrent/net/socket_address.h"
+#include "torrent/tracker/dht_controller.h"
 #include "torrent/utils/log.h"
+#include "torrent/utils/thread.h"
 #include "utils/diffie_hellman.h"
 
-#include "globals.h"
-#include "manager.h"
-
-#include "extensions.h"
-#include "handshake.h"
-#include "handshake_manager.h"
-
 #define LT_LOG(log_fmt, ...)                                            \
   lt_log_print(LOG_CONNECTION_HANDSHAKE, "handshake->%s: " log_fmt,     \
                m_address.pretty_address_str().c_str(), __VA_ARGS__);
@@ -34,8 +33,6 @@
 
 namespace torrent {
 
-const char* Handshake::m_protocol = "BitTorrent protocol";
-
 class handshake_error : public network_error {
 public:
   handshake_error(int type, int error) : m_type(type), m_error(error) {}
@@ -51,23 +48,16 @@ private:
 
 class handshake_succeeded : public network_error {
 public:
-  handshake_succeeded() {}
+  using network_error::network_error;
 };
 
 Handshake::Handshake(SocketFd fd, HandshakeManager* m, int encryptionOptions) :
-  m_state(INACTIVE),
-
   m_manager(m),
-  m_peerInfo(NULL),
-  m_download(NULL),
 
   // Use global throttles until we know which download it is.
   m_uploadThrottle(manager->upload_throttle()->throttle_list()),
   m_downloadThrottle(manager->download_throttle()->throttle_list()),
 
-  m_readDone(false),
-  m_writeDone(false),
-
   m_encryption(encryptionOptions),
   m_extensions(m->default_extensions()) {
 
@@ -76,16 +66,12 @@ Handshake::Handshake(SocketFd fd, HandshakeManager* m, int encryptionOptions) :
   m_readBuffer.reset();
   m_writeBuffer.reset();
 
-  m_taskTimeout.clear_time();
-  m_taskTimeout.slot() = std::bind(&HandshakeManager::receive_timeout, m, this);
+  m_task_timeout.slot() = [this, m] { m->receive_timeout(this); };
 }
 
 Handshake::~Handshake() {
-  if (m_taskTimeout.is_queued())
-    throw internal_error("Handshake m_taskTimeout bork bork bork.");
-
-  if (get_fd().is_valid())
-    throw internal_error("Handshake dtor called but m_fd is still open.");
+  assert(!m_task_timeout.is_scheduled());
+  assert(!get_fd().is_valid());
 
   m_encryption.cleanup();
 }
@@ -100,12 +86,12 @@ Handshake::initialize_incoming(const sockaddr* sa) {
   else
     m_state = READ_INFO;
 
-  manager->poll()->open(this);
-  manager->poll()->insert_read(this);
-  manager->poll()->insert_error(this);
+  this_thread::poll()->open(this);
+  this_thread::poll()->insert_read(this);
+  this_thread::poll()->insert_error(this);
 
   // Use lower timeout here.
-  priority_queue_insert(&taskScheduler, &m_taskTimeout, (cachedTime + rak::timer::from_seconds(60)).round_seconds());
+  this_thread::scheduler()->wait_for_ceil_seconds(&m_task_timeout, 60s);
 }
 
 void
@@ -122,11 +108,11 @@ Handshake::initialize_outgoing(const sockaddr* sa, DownloadMain* d, PeerInfo* pe
 
   m_state = CONNECTING;
 
-  manager->poll()->open(this);
-  manager->poll()->insert_write(this);
-  manager->poll()->insert_error(this);
+  this_thread::poll()->open(this);
+  this_thread::poll()->insert_write(this);
+  this_thread::poll()->insert_error(this);
 
-  priority_queue_insert(&taskScheduler, &m_taskTimeout, (cachedTime + rak::timer::from_seconds(60)).round_seconds());
+  this_thread::scheduler()->wait_for_ceil_seconds(&m_task_timeout, 60s);
 }
 
 void
@@ -136,12 +122,9 @@ Handshake::deactivate_connection() {
 
   m_state = INACTIVE;
 
-  priority_queue_erase(&taskScheduler, &m_taskTimeout);
+  this_thread::scheduler()->erase(&m_task_timeout);
 
-  manager->poll()->remove_read(this);
-  manager->poll()->remove_write(this);
-  manager->poll()->remove_error(this);
-  manager->poll()->close(this);
+  this_thread::poll()->remove_and_close(this);
 }
 
 void
@@ -217,8 +200,8 @@ Handshake::read_proxy_connect() {
   if (m_readBuffer.remaining() < patternLength)
     return false;
 
-  Buffer::iterator itr = std::search(m_readBuffer.begin(), m_readBuffer.end(),
-                                     (uint8_t*)pattern, (uint8_t*)pattern + patternLength);
+  auto itr = std::search(m_readBuffer.begin(), m_readBuffer.end(),
+                                     reinterpret_cast<const uint8_t*>(pattern), reinterpret_cast<const uint8_t*>(pattern) + patternLength);
 
   m_readBuffer.set_position_itr(itr != m_readBuffer.end() ? (itr + patternLength) : (itr - patternLength));
   m_readBuffer.move_unused();
@@ -290,8 +273,8 @@ bool
 Handshake::read_encryption_sync() {
   // Check if we've read the sync string already in the previous
   // state. This is very likely and avoids an unneeded read.
-  Buffer::iterator itr = std::search(m_readBuffer.position(), m_readBuffer.end(),
-                                     (uint8_t*)m_encryption.sync(), (uint8_t*)m_encryption.sync() + m_encryption.sync_length());
+  auto itr = std::search(m_readBuffer.position(), m_readBuffer.end(),
+                                     reinterpret_cast<const uint8_t*>(m_encryption.sync()), reinterpret_cast<const uint8_t*>(m_encryption.sync()) + m_encryption.sync_length());
 
   if (itr == m_readBuffer.end()) {
     // Otherwise read as many bytes as possible until we find the sync
@@ -304,7 +287,7 @@ Handshake::read_encryption_sync() {
     m_readBuffer.move_end(read_unthrottled(m_readBuffer.end(), toRead));
 
     itr = std::search(m_readBuffer.position(), m_readBuffer.end(),
-                      (uint8_t*)m_encryption.sync(), (uint8_t*)m_encryption.sync() + m_encryption.sync_length());
+                      reinterpret_cast<const uint8_t*>(m_encryption.sync()), reinterpret_cast<const uint8_t*>(m_encryption.sync()) + m_encryption.sync_length());
 
     if (itr == m_readBuffer.end())
       return false;
@@ -331,8 +314,8 @@ Handshake::read_encryption_skey() {
   if (!fill_read_buffer(20))
     return false;
 
-  m_encryption.deobfuscate_hash((char*)m_readBuffer.position());
-  m_download = m_manager->download_info_obfuscated((char*)m_readBuffer.position());
+  m_encryption.deobfuscate_hash(reinterpret_cast<char*>(m_readBuffer.position()));
+  m_download = m_manager->download_info_obfuscated(reinterpret_cast<char*>(m_readBuffer.position()));
   m_readBuffer.consume(20);
 
   validate_download();
@@ -481,11 +464,11 @@ Handshake::read_info() {
     if (m_download != NULL) {
       // Have the download from the encrypted handshake, make sure it
       // matches the BT handshake.
-      if (m_download->info()->hash().not_equal_to((char*)m_readBuffer.position()))
+      if (m_download->info()->hash().not_equal_to(reinterpret_cast<char*>(m_readBuffer.position())))
         throw handshake_error(ConnectionManager::handshake_failed, e_handshake_invalid_value);
 
     } else {
-      m_download = m_manager->download_info((char*)m_readBuffer.position());
+      m_download = m_manager->download_info(reinterpret_cast<char*>(m_readBuffer.position()));
     }
 
     validate_download();
@@ -495,7 +478,7 @@ Handshake::read_info() {
     prepare_handshake();
 
   } else {
-    if (m_download->info()->hash().not_equal_to((char*)m_readBuffer.position()))
+    if (m_download->info()->hash().not_equal_to(reinterpret_cast<char*>(m_readBuffer.position())))
       throw handshake_error(ConnectionManager::handshake_failed, e_handshake_invalid_value);
   }
 
@@ -523,7 +506,7 @@ Handshake::read_peer() {
   // handshake and now (e.g. when connecting takes longer). Ideally we
   // should make a snapshot of the bitfield here in case it changes while
   // we're sending it (if it can't be sent in one write() call).
-  m_initializedTime = cachedTime;
+  m_initialized_time = this_thread::cached_time();
 
   // The download is just starting so we're not sending any
   // bitfield. Pretend we wrote it already.
@@ -539,10 +522,10 @@ Handshake::read_peer() {
   }
 
   m_state = READ_MESSAGE;
-  manager->poll()->insert_write(this);
+  this_thread::poll()->insert_write(this);
 
   // Give some extra time for reading/writing the bitfield.
-  priority_queue_update(&taskScheduler, &m_taskTimeout, (cachedTime + rak::timer::from_seconds(120)).round_seconds());
+  this_thread::scheduler()->update_wait_for_ceil_seconds(&m_task_timeout, 120s);
 
   return true;
 }
@@ -630,7 +613,7 @@ Handshake::read_port() {
   m_readBuffer.read_8();
 
   if (length == 2)
-    manager->dht_manager()->add_node(m_address.get(), m_readBuffer.peek_16());
+    manager->dht_controller()->add_node(m_address.get(), m_readBuffer.peek_16());
 
   m_readBuffer.consume(length);
   return true;
@@ -645,7 +628,7 @@ Handshake::read_done() {
 //     throw handshake_error(ConnectionManager::handshake_failed, e_handshake_invalid_order);
 
   m_readDone = true;
-  manager->poll()->remove_read(this);
+  this_thread::poll()->remove_read(this);
 
   if (m_bitfield.empty()) {
     m_bitfield.set_size_bits(m_download->file_list()->bitfield()->size_bits());
@@ -678,7 +661,7 @@ restart:
 
       m_state = PROXY_DONE;
 
-      manager->poll()->insert_write(this);
+      this_thread::poll()->insert_write(this);
       return event_write();
 
     case READ_ENC_KEY:
@@ -851,8 +834,8 @@ restart:
 
     // Call event_write if we have any data to write. Make sure
     // event_write() doesn't get called twice in this function.
-    if (m_writeBuffer.remaining() && !manager->poll()->in_write(this)) {
-      manager->poll()->insert_write(this);
+    if (m_writeBuffer.remaining() && !this_thread::poll()->in_write(this)) {
+      this_thread::poll()->insert_write(this);
       return event_write();
     }
 
@@ -904,7 +887,7 @@ Handshake::event_write() {
       if (get_fd().get_error())
         throw handshake_error(ConnectionManager::handshake_failed, e_handshake_network_unreachable);
 
-      manager->poll()->insert_read(this);
+      this_thread::poll()->insert_read(this);
 
       if (m_encryption.options() & ConnectionManager::encryption_use_proxy) {
         prepare_proxy_connect();
@@ -963,7 +946,7 @@ Handshake::event_write() {
       if (m_state == POST_HANDSHAKE)
         write_done();
       else
-        manager->poll()->remove_write(this);
+        this_thread::poll()->remove_write(this);
     }
 
   } catch (handshake_succeeded& e) {
@@ -979,7 +962,7 @@ Handshake::event_write() {
 
 void
 Handshake::prepare_proxy_connect() {
-  int advance = snprintf((char*)m_writeBuffer.position(), m_writeBuffer.reserved_left(),
+  int advance = snprintf(reinterpret_cast<char*>(m_writeBuffer.position()), m_writeBuffer.reserved_left(),
                          "CONNECT %s:%hu HTTP/1.0\r\n\r\n", sap_addr_str(m_address).c_str(), sap_port(m_address));
 
   if (advance == -1 || advance > m_writeBuffer.reserved_left())
@@ -996,11 +979,11 @@ Handshake::prepare_key_plus_pad() {
   m_encryption.key()->store_pub_key(m_writeBuffer.end(), 96);
   m_writeBuffer.move_end(96);
 
-  int length = random() % enc_pad_size;
-  char pad[length];
+  const int length = random() % enc_pad_size;
+  auto pad = std::make_unique<char[]>(length);
 
-  std::generate_n(pad, length, &::random);
-  m_writeBuffer.write_len(pad, length);
+  std::generate_n(pad.get(), length, &::random);
+  m_writeBuffer.write_len(pad.get(), length);
 }
 
 void
@@ -1046,7 +1029,7 @@ Handshake::prepare_handshake() {
 
   std::memset(m_writeBuffer.end(), 0, 8);
   *(m_writeBuffer.end()+5) |= 0x10;    // support extension protocol
-  if (manager->dht_manager()->is_active())
+  if (manager->dht_controller()->is_active())
     *(m_writeBuffer.end()+7) |= 0x01;  // DHT support, enable PORT message
   m_writeBuffer.move_end(8);
 
@@ -1081,7 +1064,7 @@ Handshake::prepare_peer_info() {
 
   std::memcpy(m_peerInfo->set_options(), m_options, 8);
 
-  m_peerInfo->mutable_id().assign((const char*)m_readBuffer.position());
+  m_peerInfo->mutable_id().assign(reinterpret_cast<const char*>(m_readBuffer.position()));
   m_readBuffer.consume(20);
 
   hash_string_to_hex(m_peerInfo->id(), m_peerInfo->mutable_id_hex());
@@ -1112,11 +1095,15 @@ Handshake::prepare_post_handshake(bool must_write) {
   Buffer::iterator old_end = m_writeBuffer.end();
 
   // Send PORT message for DHT if enabled and peer supports it.
-  if (m_peerInfo->supports_dht() && manager->dht_manager()->is_active() && manager->dht_manager()->can_receive_queries()) {
+  if (m_peerInfo->supports_dht() &&
+      manager->dht_controller()->is_active() &&
+      manager->dht_controller()->is_receiving_requests()) {
+
     m_writeBuffer.write_32(3);
     m_writeBuffer.write_8(protocol_port);
-    m_writeBuffer.write_16(manager->dht_manager()->port());
-    manager->dht_manager()->port_sent();
+    m_writeBuffer.write_16(manager->dht_controller()->port());
+
+    // manager->dht_controller()->port_sent();
   }
 
   // Send a keep-alive if we still must send something.
@@ -1133,7 +1120,7 @@ Handshake::prepare_post_handshake(bool must_write) {
 void
 Handshake::write_done() {
   m_writeDone = true;
-  manager->poll()->remove_write(this);
+  this_thread::poll()->remove_write(this);
 
   // Ok to just check m_readDone as the call in event_read() won't
   // set it before the call.
@@ -1211,7 +1198,7 @@ Handshake::write_bitfield() {
   // poll in that case.
   if (m_writePos == bitfield->size_bytes()) {
     if (!m_readDone)
-      manager->poll()->remove_write(this);
+      this_thread::poll()->remove_write(this);
     else
       prepare_post_handshake(false);
   }
