@@ -1,24 +1,21 @@
 #include "config.h"
 
-#include <rak/socket_address.h>
+#include "handshake_manager.h"
 
-#include "torrent/exceptions.h"
-#include "torrent/error.h"
+#include "handshake.h"
+#include "manager.h"
+#include "peer_connection_base.h"
 #include "download/download_main.h"
 #include "torrent/connection_manager.h"
 #include "torrent/download_info.h"
+#include "torrent/error.h"
+#include "torrent/exceptions.h"
 #include "torrent/net/socket_address.h"
 #include "torrent/peer/peer_info.h"
 #include "torrent/peer/client_list.h"
 #include "torrent/peer/connection_list.h"
 #include "torrent/utils/log.h"
 
-#include "peer_connection_base.h"
-#include "handshake.h"
-#include "handshake_manager.h"
-
-#include "manager.h"
-
 #define LT_LOG_SA(sa, log_fmt, ...)                                     \
   lt_log_print(LOG_CONNECTION_HANDSHAKE, "handshake_manager->%s: " log_fmt, (sa)->address_str().c_str(), __VA_ARGS__);
 #define LT_LOG_SAP(sa, log_fmt, ...)                                 \
@@ -49,7 +46,7 @@ HandshakeManager::clear() {
 
 void
 HandshakeManager::erase(Handshake* handshake) {
-  iterator itr = std::find(base_type::begin(), base_type::end(), handshake);
+  auto itr = std::find(base_type::begin(), base_type::end(), handshake);
 
   if (itr == base_type::end())
     throw internal_error("HandshakeManager::erase(...) could not find handshake.");
@@ -92,7 +89,7 @@ HandshakeManager::add_incoming(SocketFd fd, const rak::socket_address& sa) {
 
   manager->connection_manager()->inc_socket_count();
 
-  Handshake* h = new Handshake(fd, this, manager->connection_manager()->encryption_options());
+  auto h = new Handshake(fd, this, manager->connection_manager()->encryption_options());
   h->initialize_incoming(sa.c_sockaddr());
 
   base_type::push_back(h);
@@ -152,7 +149,7 @@ HandshakeManager::create_outgoing(const rak::socket_address& sa, DownloadMain* d
   LT_LOG_SA(&sa, "created outgoing connection: fd:%i encryption:%x message:%x", fd.get_fd(), encryption_options, message);
   manager->connection_manager()->inc_socket_count();
 
-  Handshake* handshake = new Handshake(fd, this, encryption_options);
+  auto handshake = new Handshake(fd, this, encryption_options);
   handshake->initialize_outgoing(sa.c_sockaddr(), download, peerInfo);
 
   base_type::push_back(handshake);
@@ -181,6 +178,7 @@ HandshakeManager::receive_succeeded(Handshake* handshake) {
                                                  handshake->extensions())) != NULL) {
 
     manager->client_list()->retrieve_id(&handshake->peer_info()->mutable_client_info(), handshake->peer_info()->id());
+
     pcb->peer_chunks()->set_have_timer(handshake->initialized_time());
 
     LT_LOG_SA_C(handshake->peer_info()->socket_address(), "handshake success: type:%s id:%s",
