@@ -1,39 +1,3 @@
-// libTorrent - BitTorrent library
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #include "config.h"
 
 #include <cstdio>
@@ -92,27 +56,10 @@ log_mincore_stats_func(bool is_incore, bool new_index, bool& continous) {
 }
 
 PeerConnectionBase::PeerConnectionBase() :
-  m_download(NULL),
-  
   m_down(new ProtocolRead()),
-  m_up(new ProtocolWrite()),
+  m_up(new ProtocolWrite()) {
 
-  m_downStall(0),
-
-  m_downInterested(false),
-  m_downUnchoked(false),
-
-  m_sendChoked(false),
-  m_sendInterested(false),
-  m_tryRequest(true),
-  m_sendPEXMask(0),
-
-  m_encryptBuffer(NULL),
-  m_extensions(NULL),
-
-  m_incoreContinous(false) {
-
-  m_peerInfo = NULL;
+  m_peerInfo = nullptr;
 }
 
 PeerConnectionBase::~PeerConnectionBase() {
@@ -159,10 +106,10 @@ PeerConnectionBase::initialize(DownloadMain* download, PeerInfo* peerInfo, Socke
   m_down->set_throttle(throttles.second);
 
   m_peerChunks.upload_throttle()->set_list_iterator(m_up->throttle()->end());
-  m_peerChunks.upload_throttle()->slot_activate() = std::bind(&SocketBase::receive_throttle_up_activate, static_cast<SocketBase*>(this));
+  m_peerChunks.upload_throttle()->slot_activate() = [this] { receive_throttle_up_activate(); };
 
   m_peerChunks.download_throttle()->set_list_iterator(m_down->throttle()->end());
-  m_peerChunks.download_throttle()->slot_activate() = std::bind(&SocketBase::receive_throttle_down_activate, static_cast<SocketBase*>(this));
+  m_peerChunks.download_throttle()->slot_activate() = [this] { receive_throttle_down_activate(); };
 
   request_list()->set_delegator(m_download->delegator());
   request_list()->set_peer_chunks(&m_peerChunks);
@@ -180,12 +127,12 @@ PeerConnectionBase::initialize(DownloadMain* download, PeerInfo* peerInfo, Socke
     return;
   }
 
-  manager->poll()->open(this);
-  manager->poll()->insert_read(this);
-  manager->poll()->insert_write(this);
-  manager->poll()->insert_error(this);
+  this_thread::poll()->open(this);
+  this_thread::poll()->insert_read(this);
+  this_thread::poll()->insert_write(this);
+  this_thread::poll()->insert_error(this);
 
-  m_timeLastRead = cachedTime;
+  m_time_last_read = this_thread::cached_time();
 
   m_download->chunk_statistics()->received_connect(&m_peerChunks);
 
@@ -224,11 +171,8 @@ PeerConnectionBase::cleanup() {
   if (!m_extensions->is_default())
     m_extensions->cleanup();
 
-  manager->poll()->remove_read(this);
-  manager->poll()->remove_write(this);
-  manager->poll()->remove_error(this);
-  manager->poll()->close(this);
-  
+  this_thread::poll()->remove_and_close(this);
+
   manager->connection_manager()->dec_socket_count();
 
   get_fd().close();
@@ -260,7 +204,7 @@ PeerConnectionBase::receive_upload_choke(bool choke) {
 
   m_sendChoked = true;
   m_upChoke.set_unchoked(!choke);
-  m_upChoke.set_time_last_choke(cachedTime.usec());
+  m_upChoke.set_time_last_choke(this_thread::cached_time());
 
   if (choke) {
     m_download->info()->set_upload_unchoked(m_download->info()->upload_unchoked() - 1);
@@ -290,7 +234,7 @@ PeerConnectionBase::receive_download_choke(bool choke) {
   write_insert_poll_safe();
 
   m_downChoke.set_unchoked(!choke);
-  m_downChoke.set_time_last_choke(cachedTime.usec());
+  m_downChoke.set_time_last_choke(this_thread::cached_time());
 
   if (choke) {
     m_download->info()->set_download_unchoked(m_download->info()->download_unchoked() - 1);
@@ -376,9 +320,9 @@ PeerConnectionBase::load_up_chunk() {
   }
 
   up_chunk_release();
-  
-  m_upChunk = m_download->chunk_list()->get(m_upPiece.index());
-  
+
+  m_upChunk = m_download->chunk_list()->get(m_upPiece.index(), ChunkList::get_not_hashing);
+
   if (!m_upChunk.is_valid())
     throw storage_error("File chunk read error: " + std::string(m_upChunk.error_number().c_str()));
 
@@ -400,7 +344,7 @@ PeerConnectionBase::load_up_chunk() {
   uint32_t preloadSize = m_upChunk.chunk()->chunk_size() - m_upPiece.offset();
 
   if (cm->preload_type() == 0 ||
-      m_upChunk.object()->time_preloaded() >= cachedTime - rak::timer::from_seconds(60) ||
+      m_upChunk.object()->time_preloaded() >= this_thread::cached_time() - 60s ||
 
       preloadSize < cm->preload_min_size() ||
       m_peerChunks.upload_throttle()->rate()->rate() < cm->preload_required_rate() * ((preloadSize + (2 << 20) - 1) / (2 << 20))) {
@@ -410,7 +354,7 @@ PeerConnectionBase::load_up_chunk() {
 
   cm->inc_stats_preloaded();
 
-  m_upChunk.object()->set_time_preloaded(cachedTime);
+  m_upChunk.object()->set_time_preloaded(this_thread::cached_time());
   m_upChunk.chunk()->preload(m_upPiece.offset(), m_upChunk.chunk()->chunk_size(), cm->preload_type() == 1);
 }
 
@@ -464,11 +408,11 @@ PeerConnectionBase::down_chunk_start(const Piece& piece) {
 
   if (!m_download->file_list()->is_valid_piece(piece))
     throw internal_error("Incoming pieces list contains a bad piece.");
-  
+
   if (!m_downChunk.is_valid() || piece.index() != m_downChunk.index()) {
     down_chunk_release();
-    m_downChunk = m_download->chunk_list()->get(piece.index(), ChunkList::get_writable);
-  
+    m_downChunk = m_download->chunk_list()->get(piece.index(), ChunkList::get_not_hashing | ChunkList::get_writable);
+
     if (!m_downChunk.is_valid())
       throw storage_error("File chunk write error: " + std::string(m_downChunk.error_number().c_str()) + ".");
   }
@@ -486,7 +430,7 @@ PeerConnectionBase::down_chunk_finished() {
     throw internal_error("PeerConnectionBase::down_chunk_finished() Transfer not finished.");
 
   BlockTransfer* transfer = request_list()->transfer();
-  
+
   LT_LOG_PIECE_EVENTS("(down) %s %" PRIu32 " %" PRIu32 " %" PRIu32,
                       transfer->is_leader() ? "completed " : "skipped  ",
                       transfer->piece().index(), transfer->piece().offset(), transfer->piece().length());
@@ -496,15 +440,15 @@ PeerConnectionBase::down_chunk_finished() {
       throw internal_error("PeerConnectionBase::down_chunk_finished() Transfer is the leader, but no chunk allocated.");
 
     request_list()->finished();
-    m_downChunk.object()->set_time_modified(cachedTime);
+    m_downChunk.object()->set_time_modified(this_thread::cached_time());
 
   } else {
     request_list()->skipped();
   }
-        
+
   if (m_downStall > 0)
     m_downStall--;
-        
+
   // We need to release chunks when we're not sure if they will be
   // used in the near future so as to avoid hitting the address space
   // limit in high-bandwidth situations.
@@ -534,7 +478,7 @@ PeerConnectionBase::down_chunk() {
   uint32_t quota = m_down->throttle()->node_quota(m_peerChunks.download_throttle());
 
   if (quota == 0) {
-    manager->poll()->remove_read(this);
+    this_thread::poll()->remove_read(this);
     m_down->throttle()->node_deactivate(m_peerChunks.download_throttle());
     return false;
   }
@@ -574,7 +518,7 @@ PeerConnectionBase::down_chunk_from_buffer() {
     throw internal_error("PeerConnectionBase::down_chunk_from_buffer() !transfer->is_finished() && m_down->buffer()->remaining() != 0.");
 
   return m_request_list.transfer()->is_finished();
-}  
+}
 
 // When this transfer again becomes the leader, we just return false
 // and wait for the next polling. It is an exceptional case so we
@@ -589,7 +533,7 @@ PeerConnectionBase::down_chunk_skip() {
   uint32_t quota = throttle->node_quota(m_peerChunks.download_throttle());
 
   if (quota == 0) {
-    manager->poll()->remove_read(this);
+    this_thread::poll()->remove_read(this);
     throttle->node_deactivate(m_peerChunks.download_throttle());
     return false;
   }
@@ -609,7 +553,7 @@ PeerConnectionBase::down_chunk_skip() {
 bool
 PeerConnectionBase::down_chunk_skip_from_buffer() {
   m_down->buffer()->consume(down_chunk_skip_process(m_down->buffer()->position(), m_down->buffer()->remaining()));
-  
+
   return m_request_list.transfer()->is_finished();
 }
 
@@ -674,7 +618,7 @@ PeerConnectionBase::down_chunk_skip_process(const void* buffer, uint32_t length)
   if (!m_downChunk.chunk()->compare_buffer(buffer, transfer->piece().offset() + transfer->position(), compareLength)) {
     LT_LOG_PIECE_EVENTS("(down) download_data_mismatch %" PRIu32 " %" PRIu32 " %" PRIu32,
                         transfer->piece().index(), transfer->piece().offset(), transfer->piece().length());
-    
+
     m_request_list.transfer_dissimilar();
     m_request_list.transfer()->adjust_position(length);
 
@@ -693,14 +637,14 @@ PeerConnectionBase::down_chunk_skip_process(const void* buffer, uint32_t length)
 
   if (down_chunk_process(static_cast<const char*>(buffer) + compareLength, length - compareLength) != length - compareLength)
     throw internal_error("PeerConnectionBase::down_chunk_skip_process(...) down_chunk_process(...) returned wrong value.");
-  
+
   return length;
 }
 
 bool
 PeerConnectionBase::down_extension() {
   if (m_down->buffer()->remaining()) {
-    uint32_t need = std::min(m_extensions->read_need(), (uint32_t)m_down->buffer()->remaining());
+    uint32_t need = std::min(m_extensions->read_need(), static_cast<uint32_t>(m_down->buffer()->remaining()));
     std::memcpy(m_extensions->read_position(), m_down->buffer()->position(), need);
 
     m_extensions->read_move(need);
@@ -710,7 +654,7 @@ PeerConnectionBase::down_extension() {
   if (!m_extensions->is_complete()) {
     uint32_t bytes = read_stream_throws(m_extensions->read_position(), m_extensions->read_need());
     m_down->throttle()->node_used_unthrottled(bytes);
-    
+
     if (is_encrypted())
       m_encryption.decrypt(m_extensions->read_position(), bytes);
 
@@ -720,7 +664,7 @@ PeerConnectionBase::down_extension() {
   // If extension can't be processed yet (due to a pending write),
   // disable reads until the pending message is completely sent.
   if (m_extensions->is_complete() && !m_extensions->is_invalid() && !m_extensions->read_done()) {
-    manager->poll()->remove_read(this);
+    this_thread::poll()->remove_read(this);
     return false;
   }
 
@@ -767,7 +711,7 @@ PeerConnectionBase::up_chunk() {
   uint32_t quota = m_up->throttle()->node_quota(m_peerChunks.upload_throttle());
 
   if (quota == 0) {
-    manager->poll()->remove_write(this);
+    this_thread::poll()->remove_write(this);
     m_up->throttle()->node_deactivate(m_peerChunks.upload_throttle());
     return false;
   }
@@ -814,7 +758,7 @@ PeerConnectionBase::up_extension() {
       m_encryption.encrypt(m_extensionMessage.data(), m_extensionMessage.length());
 
     } else {
-      char* buffer = new char[m_extensionMessage.length()];
+      auto buffer = new char[m_extensionMessage.length()];
 
       m_encryption.encrypt(m_extensionMessage.data(), buffer, m_extensionMessage.length());
       m_extensionMessage.set(buffer, buffer + m_extensionMessage.length(), true);
@@ -841,7 +785,7 @@ PeerConnectionBase::up_extension() {
     if (!m_extensions->read_done())
       throw internal_error("PeerConnectionBase::up_extension could not process complete extension message.");
 
-    manager->poll()->insert_read(this);
+    this_thread::poll()->insert_read(this);
   }
 
   return true;
@@ -850,21 +794,21 @@ PeerConnectionBase::up_extension() {
 void
 PeerConnectionBase::down_chunk_release() {
   if (m_downChunk.is_valid())
-    m_download->chunk_list()->release(&m_downChunk);
+    m_download->chunk_list()->release(&m_downChunk, ChunkList::release_default);
 }
 
 void
 PeerConnectionBase::up_chunk_release() {
   if (m_upChunk.is_valid())
-    m_download->chunk_list()->release(&m_upChunk);
+    m_download->chunk_list()->release(&m_upChunk, ChunkList::release_default);
 }
 
 void
 PeerConnectionBase::read_request_piece(const Piece& p) {
-  PeerChunks::piece_list_type::iterator itr = std::find(m_peerChunks.upload_queue()->begin(),
-                                                        m_peerChunks.upload_queue()->end(),
-                                                        p);
-  
+  auto itr = std::find(m_peerChunks.upload_queue()->begin(),
+                       m_peerChunks.upload_queue()->end(),
+                       p);
+
   if (m_upChoke.choked() || itr != m_peerChunks.upload_queue()->end() || p.length() > (1 << 17)) {
     LT_LOG_PIECE_EVENTS("(up)   request_ignored  %" PRIu32 " %" PRIu32 " %" PRIu32,
                         p.index(), p.offset(), p.length());
@@ -880,10 +824,10 @@ PeerConnectionBase::read_request_piece(const Piece& p) {
 
 void
 PeerConnectionBase::read_cancel_piece(const Piece& p) {
-  PeerChunks::piece_list_type::iterator itr = std::find(m_peerChunks.upload_queue()->begin(),
-                                                        m_peerChunks.upload_queue()->end(),
-                                                        p);
-  
+  auto itr = std::find(m_peerChunks.upload_queue()->begin(),
+                       m_peerChunks.upload_queue()->end(),
+                       p);
+
   if (itr != m_peerChunks.upload_queue()->end()) {
     m_peerChunks.upload_queue()->erase(itr);
 
@@ -893,7 +837,7 @@ PeerConnectionBase::read_cancel_piece(const Piece& p) {
     LT_LOG_PIECE_EVENTS("(up)   cancel_ignored   %" PRIu32 " %" PRIu32 " %" PRIu32,
                         p.index(), p.offset(), p.length());
   }
-}  
+}
 
 void
 PeerConnectionBase::write_prepare_piece() {
@@ -913,7 +857,7 @@ PeerConnectionBase::write_prepare_piece() {
 
     throw communication_error(buffer);
   }
-  
+
   m_up->write_piece(m_upPiece);
 
   LT_LOG_PIECE_EVENTS("(up)   prepared         %" PRIu32 " %" PRIu32 " %" PRIu32,
@@ -971,7 +915,7 @@ PeerConnectionBase::try_request_pieces() {
     int maxRequests = m_up->max_write_request();
     int maxQueued = pipeSize - request_list()->queued_size();
     int maxPieces = std::max(std::min(maxRequests, maxQueued), 1);
-    
+
     std::vector<const Piece*> pieces = request_list()->delegate(maxPieces);
     if (pieces.empty()) {
       return false;
@@ -1014,7 +958,7 @@ PeerConnectionBase::send_pex_message() {
   } else if (m_sendPEXMask & PEX_DO && m_extensions->id(ProtocolExtension::UT_PEX)) {
     const DataBuffer& pexMessage = m_download->get_ut_pex(m_extensions->is_initial_pex());
     m_extensions->clear_initial_pex();
- 
+
     m_sendPEXMask &= ~PEX_DO;
 
     if (pexMessage.empty())
@@ -1038,7 +982,7 @@ PeerConnectionBase::send_ext_message() {
 }
 
 void
-PeerConnectionBase::receive_metadata_piece(uint32_t piece, const char* data, uint32_t length) {
+PeerConnectionBase::receive_metadata_piece([[maybe_unused]] uint32_t piece, [[maybe_unused]] const char* data, [[maybe_unused]] uint32_t length) {
 }
 
 }
