@@ -1,58 +1,18 @@
-// libTorrent - BitTorrent library
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #ifndef LIBTORRENT_PROTOCOL_PEER_CONNECTION_BASE_H
 #define LIBTORRENT_PROTOCOL_PEER_CONNECTION_BASE_H
 
+#include "thread_main.h"
 #include "data/chunk_handle.h"
 #include "net/socket_stream.h"
+#include "protocol/encryption_info.h"
+#include "protocol/extensions.h"
+#include "protocol/peer_chunks.h"
+#include "protocol/protocol_base.h"
+#include "protocol/request_list.h"
 #include "torrent/poll.h"
 #include "torrent/peer/peer.h"
 #include "torrent/peer/choke_status.h"
 
-#include "encryption_info.h"
-#include "extensions.h"
-#include "peer_chunks.h"
-#include "protocol_base.h"
-#include "request_list.h"
-
-#include "globals.h"
-
-#include "manager.h"
-
 namespace torrent {
 
 // Base class for peer connection classes. Rename to PeerConnection
@@ -67,28 +27,28 @@ class DownloadMain;
 
 class PeerConnectionBase : public Peer, public SocketStream {
 public:
-  typedef ProtocolBase           ProtocolRead;
-  typedef ProtocolBase           ProtocolWrite;
+  using ProtocolRead  = ProtocolBase;
+  using ProtocolWrite = ProtocolBase;
 
 #if USE_EXTRA_DEBUG == 666
   // For testing, use a really small buffer.
   typedef ProtocolBuffer<256>  EncryptBuffer;
 #else
-  typedef ProtocolBuffer<16384>  EncryptBuffer;
+  using EncryptBuffer = ProtocolBuffer<16384>;
 #endif
 
   // Find an optimal number for this.
-  static const uint32_t read_size = 64;
+  static constexpr uint32_t read_size = 64;
 
   // Bitmasks for peer exchange messages to send.
-  static const int PEX_DO      = (1 << 0);
-  static const int PEX_ENABLE  = (1 << 1);
-  static const int PEX_DISABLE = (1 << 2);
+  static constexpr int PEX_DO      = (1 << 0);
+  static constexpr int PEX_ENABLE  = (1 << 1);
+  static constexpr int PEX_DISABLE = (1 << 2);
 
   PeerConnectionBase();
-  virtual ~PeerConnectionBase();
-  
-  const char*         type_name() const { return "pcb"; }
+  ~PeerConnectionBase() override;
+
+  const char*         type_name() const override      { return "pcb"; }
 
   void                initialize(DownloadMain* download, PeerInfo* p, SocketFd fd, Bitfield* bitfield, EncryptionInfo* encryptionInfo, ProtocolExtension* extensions);
   void                cleanup();
@@ -127,7 +87,7 @@ public:
 
   void                do_peer_exchange()              { m_sendPEXMask |= PEX_DO; }
   inline void         set_peer_exchange(bool state);
-  
+
   // These must be implemented by the child class.
   virtual void        initialize_custom() = 0;
   virtual void        update_interested() = 0;
@@ -136,7 +96,7 @@ public:
   bool                receive_upload_choke(bool choke);
   bool                receive_download_choke(bool choke);
 
-  virtual void        event_error();
+  void                event_error() override;
 
   void                push_unread(const void* data, uint32_t size);
 
@@ -152,7 +112,7 @@ public:
   bool                should_connection_unchoke(choke_queue* cq) const;
 
 protected:
-  static const uint32_t extension_must_encrypt = ~uint32_t();
+  static constexpr uint32_t extension_must_encrypt = ~uint32_t();
 
   inline bool         read_remaining();
   inline bool         write_remaining();
@@ -192,7 +152,7 @@ protected:
   bool                send_pex_message();
   bool                send_ext_message();
 
-  DownloadMain*       m_download;
+  DownloadMain*       m_download{};
 
   ProtocolRead*       m_down;
   ProtocolWrite*      m_up;
@@ -201,7 +161,7 @@ protected:
 
   RequestList         m_request_list;
   ChunkHandle         m_downChunk;
-  uint32_t            m_downStall;
+  uint32_t            m_downStall{0};
 
   Piece               m_upPiece;
   ChunkHandle         m_upChunk;
@@ -219,25 +179,25 @@ protected:
   choke_status        m_upChoke;
   choke_status        m_downChoke;
 
-  bool                m_downInterested;
-  bool                m_downUnchoked;
+  bool                m_downInterested{false};
+  bool                m_downUnchoked{false};
 
-  bool                m_sendChoked;
-  bool                m_sendInterested;
-  bool                m_tryRequest;
+  bool                m_sendChoked{false};
+  bool                m_sendInterested{false};
+  bool                m_tryRequest{true};
 
-  int                 m_sendPEXMask;
+  int                 m_sendPEXMask{0};
 
-  rak::timer          m_timeLastRead;
+  std::chrono::microseconds m_time_last_read{};
 
   DataBuffer          m_extensionMessage;
   uint32_t            m_extensionOffset;
 
-  EncryptBuffer*      m_encryptBuffer;
+  EncryptBuffer*      m_encryptBuffer{};
   EncryptionInfo      m_encryption;
-  ProtocolExtension*  m_extensions;
+  ProtocolExtension*  m_extensions{};
 
-  bool m_incoreContinous;
+  bool                m_incoreContinous{false};
 };
 
 inline void
@@ -265,7 +225,7 @@ PeerConnectionBase::read_insert_poll_safe() {
   if (m_down->get_state() != ProtocolRead::IDLE)
     return;
 
-  manager->poll()->insert_read(this);
+  this_thread::poll()->insert_read(this);
 }
 
 inline void
@@ -273,7 +233,7 @@ PeerConnectionBase::write_insert_poll_safe() {
   if (m_up->get_state() != ProtocolWrite::IDLE)
     return;
 
-  manager->poll()->insert_write(this);
+  this_thread::poll()->insert_write(this);
 }
 
 }
