@@ -1,55 +1,20 @@
-// libTorrent - BitTorrent library
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #include "config.h"
 
 #include <cstring>
 #include <sstream>
-#include <rak/string_manip.h>
 
+#include "manager.h"
 #include "data/chunk_list_node.h"
 #include "download/chunk_selector.h"
 #include "download/chunk_statistics.h"
 #include "download/download_main.h"
-#include "torrent/dht_manager.h"
+#include "rak/string_manip.h"
 #include "torrent/download_info.h"
 #include "torrent/download/choke_group.h"
 #include "torrent/download/choke_queue.h"
 #include "torrent/peer/connection_list.h"
 #include "torrent/peer/peer_info.h"
+#include "torrent/tracker/dht_controller.h"
 #include "torrent/utils/log.h"
 
 #include "extensions.h"
@@ -116,7 +81,7 @@ PeerConnection<type>::update_interested() {
 template<Download::ConnectionType type>
 bool
 PeerConnection<type>::receive_keepalive() {
-  if (cachedTime - m_timeLastRead > rak::timer::from_seconds(240))
+  if (this_thread::cached_time() - m_time_last_read > 240s)
     return false;
 
   // There's no point in adding ourselves to the write poll if the
@@ -196,7 +161,7 @@ PeerConnection<type>::read_message() {
   } else if (length > (1 << 20)) {
     throw communication_error("PeerConnection::read_message() got an invalid message length.");
   }
-    
+
   // We do not verify the message length of those with static
   // length. A bug in the remote client causing the message start to
   // be unsyncronized would in practically all cases be caught with
@@ -207,7 +172,7 @@ PeerConnection<type>::read_message() {
   // peer. Those cases should be caught elsewhere in the code.
 
   // Temporary.
-  m_down->set_last_command((ProtocolBase::Protocol)buf->peek_8());
+  m_down->set_last_command(static_cast<ProtocolBase::Protocol>(buf->peek_8()));
 
   switch (buf->read_8()) {
   case ProtocolBase::CHOKE:
@@ -299,7 +264,7 @@ PeerConnection<type>::read_message() {
         m_down->throttle()->insert(m_peerChunks.download_throttle());
         return false;
       }
-      
+
     } else {
 
       if (down_chunk_from_buffer()) {
@@ -325,7 +290,7 @@ PeerConnection<type>::read_message() {
     if (!m_down->can_read_port_body())
       break;
 
-    manager->dht_manager()->add_node(m_peerInfo->socket_address(), m_down->buffer()->read_16());
+    manager->dht_controller()->add_node(m_peerInfo->socket_address(), m_down->buffer()->read_16());
     return true;
 
   case ProtocolBase::EXTENSION_PROTOCOL:
@@ -364,7 +329,7 @@ PeerConnection<type>::read_message() {
 template<Download::ConnectionType type>
 void
 PeerConnection<type>::event_read() {
-  m_timeLastRead = cachedTime;
+  m_time_last_read = this_thread::cached_time();
 
   // Need to make sure ProtocolBuffer::end() is pointing to the end of
   // the unread data, and that the unread data starts from the
@@ -373,7 +338,7 @@ PeerConnection<type>::event_read() {
   // the unused data.
 
   try {
-    
+
     // Normal read.
     //
     // We rarely will read zero bytes as the read of 64 bytes will
@@ -396,8 +361,9 @@ PeerConnection<type>::event_read() {
           m_down->buffer()->move_end(length);
         }
 
-        while (read_message());
-        
+        while (read_message())
+          ; // Do nothing.
+
         if (m_down->buffer()->size_end() == read_size) {
           m_down->buffer()->move_unused();
           break;
@@ -538,7 +504,7 @@ PeerConnection<type>::fill_write_buffer() {
 
   DownloadMain::have_queue_type* haveQueue = m_download->have_queue();
 
-  if (type == Download::CONNECTION_LEECH && 
+  if (type == Download::CONNECTION_LEECH &&
       !haveQueue->empty() &&
       m_peerChunks.have_timer() <= haveQueue->front().first &&
       m_up->can_write_have()) {
@@ -551,7 +517,7 @@ PeerConnection<type>::fill_write_buffer() {
       m_up->write_have((--last)->second);
     } while (last != haveQueue->begin() && m_up->can_write_have());
 
-    m_peerChunks.set_have_timer(last->first + 1);
+    m_peerChunks.set_have_timer(last->first + 1us);
   }
 
   if (type == Download::CONNECTION_INITIAL_SEED && m_up->can_write_have())
@@ -585,7 +551,7 @@ template<Download::ConnectionType type>
 void
 PeerConnection<type>::event_write() {
   try {
-  
+
     do {
 
       switch (m_up->get_state()) {
@@ -594,7 +560,7 @@ PeerConnection<type>::event_write() {
         fill_write_buffer();
 
         if (m_up->buffer()->remaining() == 0) {
-          manager->poll()->remove_write(this);
+          this_thread::poll()->remove_write(this);
           return;
         }
 
