@@ -1,58 +1,23 @@
-// libTorrent - BitTorrent library
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #include "config.h"
 
+#include "protocol/peer_connection_metadata.h"
+
 #include <cstring>
 #include <sstream>
 
+#include "manager.h"
 #include "data/chunk_list_node.h"
 #include "download/chunk_selector.h"
 #include "download/chunk_statistics.h"
 #include "download/download_main.h"
-#include "torrent/dht_manager.h"
+#include "protocol/extensions.h"
 #include "torrent/download_info.h"
 #include "torrent/download/choke_queue.h"
 #include "torrent/peer/connection_list.h"
 #include "torrent/peer/peer_info.h"
+#include "torrent/tracker/dht_controller.h"
 #include "torrent/utils/log.h"
 
-#include "extensions.h"
-#include "peer_connection_metadata.h"
-
 #define LT_LOG_METADATA_EVENTS(log_fmt, ...)                            \
   lt_log_print_info(LOG_PROTOCOL_METADATA_EVENTS, this->download()->info(), "metadata_events", "%40s " log_fmt, this->peer_info()->id_hex(), __VA_ARGS__);
 #define LT_LOG_STORAGE_ERRORS(log_fmt, ...)                              \
@@ -60,8 +25,7 @@
 
 namespace torrent {
 
-PeerConnectionMetadata::~PeerConnectionMetadata() {
-}
+PeerConnectionMetadata::~PeerConnectionMetadata() = default;
 
 void
 PeerConnectionMetadata::initialize_custom() {
@@ -73,7 +37,7 @@ PeerConnectionMetadata::update_interested() {
 
 bool
 PeerConnectionMetadata::receive_keepalive() {
-  if (cachedTime - m_timeLastRead > rak::timer::from_seconds(240))
+  if (this_thread::cached_time() - m_time_last_read > 240s)
     return false;
 
   m_tryRequest = true;
@@ -124,8 +88,8 @@ PeerConnectionMetadata::read_message() {
   } else if (length > (1 << 20)) {
     throw communication_error("PeerConnection::read_message() got an invalid message length.");
   }
-    
-  m_down->set_last_command((ProtocolBase::Protocol)buf->peek_8());
+
+  m_down->set_last_command(static_cast<ProtocolBase::Protocol>(buf->peek_8()));
 
   // Ignore most messages, they aren't relevant for a metadata download.
   switch (buf->read_8()) {
@@ -163,7 +127,7 @@ PeerConnectionMetadata::read_message() {
     if (!m_down->can_read_port_body())
       break;
 
-    manager->dht_manager()->add_node(m_peerInfo->socket_address(), m_down->buffer()->read_16());
+    manager->dht_controller()->add_node(m_peerInfo->socket_address(), m_down->buffer()->read_16());
     return true;
 
   case ProtocolBase::EXTENSION_PROTOCOL:
@@ -215,7 +179,7 @@ PeerConnectionMetadata::read_message() {
 
 void
 PeerConnectionMetadata::event_read() {
-  m_timeLastRead = cachedTime;
+  m_time_last_read = this_thread::cached_time();
 
   // Need to make sure ProtocolBuffer::end() is pointing to the end of
   // the unread data, and that the unread data starts from the
@@ -224,7 +188,7 @@ PeerConnectionMetadata::event_read() {
   // the unused data.
 
   try {
-    
+
     // Normal read.
     //
     // We rarely will read zero bytes as the read of 64 bytes will
@@ -246,8 +210,9 @@ PeerConnectionMetadata::event_read() {
           m_down->buffer()->move_end(length);
         }
 
-        while (read_message());
-        
+        while (read_message())
+          ; // Do nothing.
+
         if (m_down->buffer()->size_end() == read_size) {
           m_down->buffer()->move_unused();
           break;
@@ -333,7 +298,7 @@ PeerConnectionMetadata::fill_write_buffer() {
 void
 PeerConnectionMetadata::event_write() {
   try {
-  
+
     do {
 
       switch (m_up->get_state()) {
@@ -342,7 +307,7 @@ PeerConnectionMetadata::event_write() {
         fill_write_buffer();
 
         if (m_up->buffer()->remaining() == 0) {
-          manager->poll()->remove_write(this);
+          this_thread::poll()->remove_write(this);
           return;
         }
 
@@ -399,13 +364,13 @@ PeerConnectionMetadata::event_write() {
 bool
 PeerConnectionMetadata::read_skip_bitfield() {
   if (m_down->buffer()->remaining()) {
-    uint32_t length = std::min(m_skipLength, (uint32_t)m_down->buffer()->remaining());
+    uint32_t length = std::min(m_skipLength, static_cast<uint32_t>(m_down->buffer()->remaining()));
     m_down->buffer()->consume(length);
     m_skipLength -= length;
   }
 
   if (m_skipLength) {
-    uint32_t length = std::min(m_skipLength, (uint32_t)null_buffer_size);
+    uint32_t length = std::min(m_skipLength, static_cast<uint32_t>(null_buffer_size));
     length = read_stream_throws(m_nullBuffer, length);
     if (!length)
       return false;
