@@ -1,44 +1,6 @@
-// libTorrent - BitTorrent library
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #ifndef LIBTORRENT_NET_PROTOCOL_BASE_H
 #define LIBTORRENT_NET_PROTOCOL_BASE_H
 
-#include <rak/timer.h>
-
 #include "net/protocol_buffer.h"
 
 namespace torrent {
@@ -47,12 +9,12 @@ class Piece;
 
 class ProtocolBase {
 public:
-  typedef ProtocolBuffer<512> Buffer;
-  typedef uint32_t            size_type;
+  using Buffer    = ProtocolBuffer<512>;
+  using size_type = uint32_t;
 
-  static const size_type buffer_size = 512;
+  static constexpr size_type buffer_size = 512;
 
-  typedef enum {
+  enum Protocol {
     CHOKE = 0,
     UNCHOKE,
     INTERESTED,
@@ -66,11 +28,11 @@ public:
 
     EXTENSION_PROTOCOL = 20,
 
-    NONE,           // These are not part of the protocol
-    KEEP_ALIVE      // Last command was a keep alive
-  } Protocol;
+    NONE,      // These are not part of the protocol
+    KEEP_ALIVE // Last command was a keep alive
+  };
 
-  typedef enum {
+  enum State {
     IDLE,
     MSG,
     READ_PIECE,
@@ -79,13 +41,10 @@ public:
     WRITE_PIECE,
     WRITE_EXTENSION,
     INTERNAL_ERROR
-  } State;
-
-  ProtocolBase() :
-    m_state(IDLE),
-    m_lastCommand(NONE),
-    m_throttle(NULL) {
+  };
 
+  ProtocolBase()
+  {
     m_buffer.reset();
   }
 
@@ -116,22 +75,22 @@ public:
   void                write_port(uint16_t port);
   void                write_extension(uint8_t id, uint32_t length);
 
-  static const size_type sizeof_keepalive    = 4;
-  static const size_type sizeof_choke        = 5;
-  static const size_type sizeof_interested   = 5;
-  static const size_type sizeof_have         = 9;
-  static const size_type sizeof_have_body    = 4;
-  static const size_type sizeof_bitfield     = 5;
-  static const size_type sizeof_request      = 17;
-  static const size_type sizeof_request_body = 12;
-  static const size_type sizeof_cancel       = 17;
-  static const size_type sizeof_cancel_body  = 12;
-  static const size_type sizeof_piece        = 13;
-  static const size_type sizeof_piece_body   = 8;
-  static const size_type sizeof_port         = 7;
-  static const size_type sizeof_port_body    = 2;
-  static const size_type sizeof_extension    = 6;
-  static const size_type sizeof_extension_body=1;
+  static constexpr size_type sizeof_keepalive    = 4;
+  static constexpr size_type sizeof_choke        = 5;
+  static constexpr size_type sizeof_interested   = 5;
+  static constexpr size_type sizeof_have         = 9;
+  static constexpr size_type sizeof_have_body    = 4;
+  static constexpr size_type sizeof_bitfield     = 5;
+  static constexpr size_type sizeof_request      = 17;
+  static constexpr size_type sizeof_request_body = 12;
+  static constexpr size_type sizeof_cancel       = 17;
+  static constexpr size_type sizeof_cancel_body  = 12;
+  static constexpr size_type sizeof_piece        = 13;
+  static constexpr size_type sizeof_piece_body   = 8;
+  static constexpr size_type sizeof_port         = 7;
+  static constexpr size_type sizeof_port_body    = 2;
+  static constexpr size_type sizeof_extension    = 6;
+  static constexpr size_type sizeof_extension_body=1;
 
   bool                can_write_keepalive() const             { return m_buffer.reserved_left() >= sizeof_keepalive; }
   bool                can_write_choke() const                 { return m_buffer.reserved_left() >= sizeof_choke; }
@@ -155,9 +114,9 @@ public:
 
 
 protected:
-  State               m_state;
-  Protocol            m_lastCommand;
-  ThrottleList*       m_throttle;
+  State               m_state{IDLE};
+  Protocol            m_lastCommand{NONE};
+  ThrottleList*       m_throttle{};
 
   Buffer              m_buffer;
 };
