@@ -1,39 +1,3 @@
-// libTorrent - BitTorrent library
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #ifndef LIBTORRENT_REQUEST_LIST_H
 #define LIBTORRENT_REQUEST_LIST_H
 
@@ -41,18 +5,17 @@
 #include <vector>
 
 #include "torrent/data/block_transfer.h"
+#include "torrent/utils/scheduler.h"
 #include "utils/instrumentation.h"
 #include "utils/queue_buckets.h"
 
-#include "globals.h"
-
 namespace torrent {
 
 class PeerChunks;
 class Delegator;
 
 struct request_list_constants {
-  static const int bucket_count = 4;
+  static constexpr int bucket_count = 4;
 
   static const torrent::instrumentation_enum instrumentation_added[bucket_count];
   static const torrent::instrumentation_enum instrumentation_moved[bucket_count];
@@ -65,16 +28,16 @@ struct request_list_constants {
 
 class RequestList {
 public:
-  typedef torrent::queue_buckets<BlockTransfer*, request_list_constants> queues_type;
+  using queues_type = torrent::queue_buckets<BlockTransfer*, request_list_constants>;
 
-  static const int bucket_queued    = 0;
-  static const int bucket_unordered = 1;
-  static const int bucket_stalled   = 2;
-  static const int bucket_choked    = 3;
+  static constexpr int bucket_queued    = 0;
+  static constexpr int bucket_unordered = 1;
+  static constexpr int bucket_stalled   = 2;
+  static constexpr int bucket_choked    = 3;
 
-  static const int timeout_remove_choked = 6;
-  static const int timeout_choked_received = 60;
-  static const int timeout_process_unordered = 60;
+  static constexpr std::chrono::microseconds timeout_remove_choked{6s};
+  static constexpr std::chrono::microseconds timeout_choked_received{60s};
+  static constexpr std::chrono::microseconds timeout_process_unordered{60s};
 
   RequestList();
   ~RequestList();
@@ -82,6 +45,7 @@ public:
   // Some parameters here, like how fast we are downloading and stuff
   // when we start considering those.
   std::vector<const Piece*>  delegate(uint32_t maxPieces);
+
   void                 stall_initial();
   void                 stall_prolonged();
 
@@ -101,8 +65,6 @@ public:
   bool                 is_downloading()                   { return m_transfer != NULL; }
   bool                 is_interested_in_active() const;
 
-  // bool                 has_index(uint32_t i);
-
   const Piece&         next_queued_piece() const          { return m_queues.front(bucket_queued)->piece(); }
 
   bool                 queued_empty() const               { return m_queues.queue_empty(bucket_queued); }
@@ -117,7 +79,10 @@ public:
   uint32_t             pipe_size() const;
   uint32_t             calculate_pipe_size(uint32_t rate);
 
+  Delegator*           delegator()                       { return m_delegator; }
   void                 set_delegator(Delegator* d)       { m_delegator = d; }
+
+  PeerChunks*          peer_chunks()                     { return m_peerChunks; }
   void                 set_peer_chunks(PeerChunks* b)    { m_peerChunks = b; }
 
   BlockTransfer*       transfer()                        { return m_transfer; }
@@ -131,32 +96,27 @@ private:
   void                 prepare_process_unordered(queues_type::iterator itr);
   void                 delay_process_unordered();
 
-  Delegator*           m_delegator;
-  PeerChunks*          m_peerChunks;
+  Delegator*           m_delegator{};
+  PeerChunks*          m_peerChunks{};
 
-  BlockTransfer*       m_transfer;
+  BlockTransfer*       m_transfer{};
 
   queues_type          m_queues;
 
-  int32_t              m_affinity;
+  int32_t              m_affinity{-1};
 
-  rak::timer           m_last_choke;
-  rak::timer           m_last_unchoke;
-  size_t               m_last_unordered_position;
+  std::chrono::microseconds m_last_choke{};
+  std::chrono::microseconds m_last_unchoke{};
+  size_t                    m_last_unordered_position{0};
 
-  rak::priority_item   m_delay_remove_choked;
-  rak::priority_item   m_delay_process_unordered;
+  torrent::utils::SchedulerEntry m_delay_remove_choked;
+  torrent::utils::SchedulerEntry m_delay_process_unordered;
 };
 
 inline
-RequestList::RequestList() :
-  m_delegator(NULL),
-  m_peerChunks(NULL),
-  m_transfer(NULL),
-  m_affinity(-1),
-  m_last_unordered_position(0) {
-  m_delay_remove_choked.slot() = std::bind(&RequestList::delay_remove_choked, this);
-  m_delay_process_unordered.slot() = std::bind(&RequestList::delay_process_unordered, this);
+RequestList::RequestList() {
+  m_delay_remove_choked.slot()     = [this] { delay_remove_choked(); };
+  m_delay_process_unordered.slot() = [this] { delay_process_unordered(); };
 }
 
 // TODO: Make sure queued_size is never too small.
