@@ -64,10 +64,14 @@ Block::~Block() {
   m_leader = NULL;
   m_state = STATE_INVALID;
 
-  std::for_each(m_queued.begin(), m_queued.end(), std::bind1st(std::mem_fun(&Block::invalidate_transfer), this));
+  for (auto& block : m_queued) {
+    invalidate_transfer(block);
+  }
   m_queued.clear();
 
-  std::for_each(m_transfers.begin(), m_transfers.end(), std::bind1st(std::mem_fun(&Block::invalidate_transfer), this));
+  for (auto& block : m_transfers) {
+    invalidate_transfer(block);
+  }
   m_transfers.clear();
 
   if (m_notStalled != 0)
@@ -83,13 +87,13 @@ Block::insert(PeerInfo* peerInfo) {
 
   m_notStalled++;
 
-  transfer_list_type::iterator itr = m_queued.insert(m_queued.end(), new BlockTransfer());
+  auto itr = m_queued.insert(m_queued.end(), new BlockTransfer());
 
   (*itr)->set_peer_info(peerInfo);
   (*itr)->set_block(this);
   (*itr)->set_piece(m_piece);
   (*itr)->set_state(BlockTransfer::STATE_QUEUED);
-  (*itr)->set_request_time(cachedTime.seconds());
+  (*itr)->set_request_time(this_thread::cached_seconds().count());
   (*itr)->set_position(0);
   (*itr)->set_stall(0);
   (*itr)->set_failed_index(BlockFailed::invalid_index);
@@ -108,7 +112,7 @@ Block::erase(BlockTransfer* transfer) {
   m_notStalled -= transfer->stall() == 0;
 
   if (transfer->is_queued()) {
-    transfer_list_type::iterator itr = std::find(m_queued.begin(), m_queued.end(), transfer);
+    auto itr = std::find(m_queued.begin(), m_queued.end(), transfer);
 
     if (itr == m_queued.end())
       throw internal_error("Block::erase(...) Could not find transfer.");
@@ -116,7 +120,7 @@ Block::erase(BlockTransfer* transfer) {
     m_queued.erase(itr);
 
   } else if (!transfer->is_finished()) {
-    transfer_list_type::iterator itr = std::find(m_transfers.begin(), m_transfers.end(), transfer);
+    auto itr = std::find(m_transfers.begin(), m_transfers.end(), transfer);
 
     if (itr == m_transfers.end())
       throw internal_error("Block::erase(...) Could not find transfer.");
@@ -137,10 +141,10 @@ Block::erase(BlockTransfer* transfer) {
       // Create a range containing transfers with
       // is_not_leader(). Erased transfer will end up in the back.
 
-      transfer_list_type::iterator first = std::find_if(m_transfers.begin(), m_transfers.end(), std::not1(std::mem_fun(&BlockTransfer::is_leader)));
-      transfer_list_type::iterator last = std::stable_partition(first, m_transfers.end(), std::mem_fun(&BlockTransfer::is_not_leader));
+      auto first = std::find_if_not(m_transfers.begin(), m_transfers.end(), std::mem_fn(&BlockTransfer::is_leader));
+      auto last  = std::stable_partition(first, m_transfers.end(), std::mem_fn(&BlockTransfer::is_not_leader));
 
-      transfer_list_type::iterator new_leader = std::max_element(first, last, [](BlockTransfer* t1, BlockTransfer* t2) {
+      auto new_leader = std::max_element(first, last, [](BlockTransfer* t1, BlockTransfer* t2) {
         return t1->position() < t2->position();
       });
 
@@ -173,7 +177,7 @@ Block::transfering(BlockTransfer* transfer) {
   if (!transfer->is_valid())
     throw internal_error("Block::transfering(...) transfer->block() == NULL.");
 
-  transfer_list_type::iterator itr = std::find(m_queued.begin(), m_queued.end(), transfer);
+  auto itr = std::find(m_queued.begin(), m_queued.end(), transfer);
 
   if (itr == m_queued.end())
     throw internal_error("Block::transfering(...) not queued.");
@@ -220,7 +224,7 @@ Block::completed(BlockTransfer* transfer) {
 
   m_parent->inc_finished();
 
-  if ((Block::size_type)std::count_if(m_parent->begin(), m_parent->end(), std::mem_fun_ref(&Block::is_finished)) < m_parent->finished())
+  if (static_cast<Block::size_type>(std::count_if(m_parent->begin(), m_parent->end(), std::mem_fn(&Block::is_finished))) < m_parent->finished())
     throw internal_error("Block::completed(...) Finished blocks too large.");
 
   m_notStalled -= transfer->stall() == 0;
@@ -233,7 +237,9 @@ Block::completed(BlockTransfer* transfer) {
   // Block::transfering(...). But that would propably not be correct
   // as we want to trigger cancel messages from here, as hash fail is
   // a rare occurrence.
-  std::for_each(m_queued.begin(), m_queued.end(), std::bind1st(std::mem_fun(&Block::invalidate_transfer), this));
+  for (const auto& block : m_queued) {
+    invalidate_transfer(block);
+  }
   m_queued.clear();
 
   // We need to invalidate those unfinished and keep the one that
@@ -366,17 +372,17 @@ Block::invalidate_transfer(BlockTransfer* transfer) {
 
 void
 Block::remove_erased_transfers() {
-  transfer_list_type::iterator split = std::stable_partition(m_transfers.begin(), m_transfers.end(), std::not1(std::mem_fun(&BlockTransfer::is_erased)));
+  auto split = std::stable_partition(m_transfers.begin(), m_transfers.end(), [](auto block) { return !block->is_erased(); });
 
-  std::for_each(split, m_transfers.end(), std::bind1st(std::mem_fun(&Block::invalidate_transfer), this));
+  std::for_each(split, m_transfers.end(), [this](auto block) { invalidate_transfer(block); });
   m_transfers.erase(split, m_transfers.end());
 }
 
 void
 Block::remove_non_leader_transfers() {
-  transfer_list_type::iterator split = std::stable_partition(m_transfers.begin(), m_transfers.end(), std::mem_fun(&BlockTransfer::is_leader));
+  auto split = std::stable_partition(m_transfers.begin(), m_transfers.end(), std::mem_fn(&BlockTransfer::is_leader));
 
-  std::for_each(split, m_transfers.end(), std::bind1st(std::mem_fun(&Block::invalidate_transfer), this));
+  std::for_each(split, m_transfers.end(), [this](auto block) { invalidate_transfer(block); });
   m_transfers.erase(split, m_transfers.end());
 }
 
