@@ -1,45 +1,11 @@
-// libTorrent - BitTorrent library
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #include "config.h"
 
+#include "transfer_list.h"
+
 #include <algorithm>
+#include <cassert>
 #include <functional>
 #include <set>
-#include <rak/timer.h>
 
 #include "data/chunk.h"
 #include "peer/peer_info.h"
@@ -50,19 +16,10 @@
 #include "exceptions.h"
 #include "piece.h"
 
-#include "transfer_list.h"
-
 namespace torrent {
 
-TransferList::TransferList() :
-  m_succeededCount(0),
-  m_failedCount(0) { }
-
-// TODO: Derp if transfer list isn't cleared...
-
 TransferList::~TransferList() {
-  if (!base_type::empty())
-    throw internal_error("TransferList::~TransferList() called on an non-empty object");
+  assert(base_type::empty() && "TransferList::~TransferList() called on an non-empty object");
 }
 
 TransferList::iterator
@@ -92,8 +49,8 @@ TransferList::insert(const Piece& piece, uint32_t blockSize) {
   if (find(piece.index()) != end())
     throw internal_error("Delegator::new_chunk(...) received an index that is already delegated.");
 
-  BlockList* blockList = new BlockList(piece, blockSize);
-  
+  auto blockList = new BlockList(piece, blockSize);
+
   m_slot_queued(piece.index());
 
   return base_type::insert(end(), blockList);
@@ -125,10 +82,9 @@ TransferList::finished(BlockTransfer* transfer) {
 
 void
 TransferList::hash_succeeded(uint32_t index, Chunk* chunk) {
-  iterator blockListItr = find(index);
+  auto blockListItr = find(index);
 
-  if ((Block::size_type)std::count_if((*blockListItr)->begin(), (*blockListItr)->end(),
-                                      std::mem_fun_ref(&Block::is_finished)) != (*blockListItr)->size())
+  if (!std::all_of((*blockListItr)->begin(), (*blockListItr)->end(), std::mem_fn(&Block::is_finished)))
     throw internal_error("TransferList::hash_succeeded(...) Finished blocks does not match size.");
 
   // The chunk should also be marked here or by the caller so that it
@@ -146,11 +102,11 @@ TransferList::hash_succeeded(uint32_t index, Chunk* chunk) {
   // pruned every 60 minutes, so any timer that reads values once
   // every 30 minutes is guaranteed to get them all as long as it is
   // ordered properly.
-  m_completedList.emplace_back(rak::timer::current().usec(), index);
+  m_completedList.emplace_back(this_thread::cached_time().count(), index);
 
-  if (rak::timer(m_completedList.front().first) + rak::timer::from_minutes(60) < rak::timer::current()) {
+  if (std::chrono::microseconds(m_completedList.front().first) + 60min < this_thread::cached_time()) {
     auto itr = std::find_if(m_completedList.begin(), m_completedList.end(), [](auto v) {
-      return (rak::timer::current() - rak::timer::from_minutes(30)) <= v.first;
+        return this_thread::cached_time() - 30min <= std::chrono::microseconds(v.first);
     });
 
     m_completedList.erase(m_completedList.begin(), itr);
@@ -173,12 +129,12 @@ struct transfer_list_compare_data {
 
 void
 TransferList::hash_failed(uint32_t index, Chunk* chunk) {
-  iterator blockListItr = find(index);
+  auto blockListItr = find(index);
 
   if (blockListItr == end())
     throw internal_error("TransferList::hash_failed(...) Could not find index.");
 
-  if ((Block::size_type)std::count_if((*blockListItr)->begin(), (*blockListItr)->end(), std::mem_fun_ref(&Block::is_finished)) != (*blockListItr)->size())
+  if (!std::all_of((*blockListItr)->begin(), (*blockListItr)->end(), std::mem_fn(&Block::is_finished)))
     throw internal_error("TransferList::hash_failed(...) Finished blocks does not match size.");
 
   m_failedCount++;
@@ -216,22 +172,21 @@ TransferList::update_failed(BlockList* blockList, Chunk* chunk) {
 
   blockList->inc_failed();
 
-  for (BlockList::iterator itr = blockList->begin(), last = blockList->end(); itr != last; ++itr) {
-    
-    if (itr->failed_list() == NULL)
-      itr->set_failed_list(new BlockFailed());
+  for (auto& transfer : *blockList) {
 
-    BlockFailed::iterator failedItr = std::find_if(itr->failed_list()->begin(), itr->failed_list()->end(),
-                                                   transfer_list_compare_data(chunk, itr->piece()));
+    if (transfer.failed_list() == NULL)
+      transfer.set_failed_list(new BlockFailed());
 
-    if (failedItr == itr->failed_list()->end()) {
+    auto failedItr = std::find_if(transfer.failed_list()->begin(), transfer.failed_list()->end(), transfer_list_compare_data(chunk, transfer.piece()));
+
+    if (failedItr == transfer.failed_list()->end()) {
       // We've never encountered this data before, make a new entry.
-      char* buffer = new char[itr->piece().length()];
+      auto buffer = new char[transfer.piece().length()];
 
-      chunk->to_buffer(buffer, itr->piece().offset(), itr->piece().length());
+      chunk->to_buffer(buffer, transfer.piece().offset(), transfer.piece().length());
 
-      itr->failed_list()->emplace_back(buffer, 1);
-      failedItr = itr->failed_list()->end() - 1;
+      transfer.failed_list()->emplace_back(buffer, 1);
+      failedItr = transfer.failed_list()->end() - 1;
 
       // Count how many new data sets?
 
@@ -239,16 +194,16 @@ TransferList::update_failed(BlockList* blockList, Chunk* chunk) {
       // Increment promoted when the entry's reference count becomes
       // larger than others, but not if it previously was the largest.
 
-      BlockFailed::iterator maxItr = itr->failed_list()->max_element();
+      auto maxItr = transfer.failed_list()->max_element();
 
-      if (maxItr->second == failedItr->second && maxItr != (itr->failed_list()->reverse_max_element().base() - 1))
+      if (maxItr->second == failedItr->second && maxItr != (transfer.failed_list()->reverse_max_element().base() - 1))
         promoted++;
 
       failedItr->second++;
     }
 
-    itr->failed_list()->set_current(failedItr);
-    itr->leader()->set_failed_index(failedItr - itr->failed_list()->begin());
+    transfer.failed_list()->set_current(failedItr);
+    transfer.leader()->set_failed_index(failedItr - transfer.failed_list()->begin());
   }
 
   return promoted;
@@ -258,15 +213,14 @@ void
 TransferList::mark_failed_peers(BlockList* blockList, Chunk* chunk) {
   std::set<PeerInfo*> badPeers;
 
-  for (BlockList::iterator itr = blockList->begin(), last = blockList->end(); itr != last; ++itr) {
+  for (auto& block : *blockList) {
     // This chunk data is good, set it as current and
     // everyone who sent something else is a bad peer.
-    itr->failed_list()->set_current(std::find_if(itr->failed_list()->begin(), itr->failed_list()->end(),
-                                                 transfer_list_compare_data(chunk, itr->piece())));
+    block.failed_list()->set_current(std::find_if(block.failed_list()->begin(), block.failed_list()->end(), transfer_list_compare_data(chunk, block.piece())));
 
-    for (Block::transfer_list_type::const_iterator itr2 = itr->transfers()->begin(), last2 = itr->transfers()->end(); itr2 != last2; ++itr2)
-      if ((*itr2)->failed_index() != itr->failed_list()->current() && (*itr2)->failed_index() != ~uint32_t())
-        badPeers.insert((*itr2)->peer_info());
+    for (auto& transfer : *block.transfers())
+      if (transfer->failed_index() != block.failed_list()->current() && transfer->failed_index() != ~uint32_t())
+        badPeers.insert(transfer->peer_info());
   }
 
   std::for_each(badPeers.begin(), badPeers.end(), m_slot_corrupt);
@@ -276,22 +230,22 @@ TransferList::mark_failed_peers(BlockList* blockList, Chunk* chunk) {
 // largest reference counts.
 void
 TransferList::retry_most_popular(BlockList* blockList, Chunk* chunk) {
-  for (BlockList::iterator itr = blockList->begin(), last = blockList->end(); itr != last; ++itr) {
-    
-    BlockFailed::reverse_iterator failedItr = itr->failed_list()->reverse_max_element();
+  for (auto& block : *blockList) {
 
-    if (failedItr == itr->failed_list()->rend())
+    auto failedItr = block.failed_list()->reverse_max_element();
+
+    if (failedItr == block.failed_list()->rend())
       throw internal_error("TransferList::retry_most_popular(...) No failed list entry found.");
 
     // The data is the same, so no need to copy.
-    if (failedItr == itr->failed_list()->current_reverse_iterator())
+    if (failedItr == block.failed_list()->current_reverse_iterator())
       continue;
 
     // Change the leader to the currently held buffer?
 
-    chunk->from_buffer(failedItr->first, itr->piece().offset(), itr->piece().length());
+    chunk->from_buffer(failedItr->first, block.piece().offset(), block.piece().length());
 
-    itr->failed_list()->set_current(failedItr);
+    block.failed_list()->set_current(failedItr);
   }
 
   m_slot_completed(blockList->index());
