@@ -1,50 +1,13 @@
-// libTorrent - BitTorrent library
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #ifndef LIBTORRENT_DOWNLOAD_H
 #define LIBTORRENT_DOWNLOAD_H
 
 #include <list>
 #include <vector>
 #include <string>
-#include <sigc++/connection.h>
-#include <sigc++/functors/slot.h>
 
 #include <torrent/common.h>
 #include <torrent/peer/peer.h>
+#include <torrent/tracker/wrappers.h>
 
 namespace torrent {
 
@@ -52,24 +15,23 @@ class ConnectionList;
 class DownloadInfo;
 class DownloadMain;
 class download_data;
-class TrackerController;
 
 // Download is safe to copy and destory as it is just a pointer to an
 // internal class.
 
 class LIBTORRENT_EXPORT Download {
 public:
-  static const uint32_t numwanted_diabled = ~uint32_t();
+  static constexpr uint32_t numwanted_diabled = ~uint32_t();
 
   // Start and open flags can be stored in the same integer, same for
   // stop and close flags.
-  static const int open_enable_fallocate = (1 << 0);
+  static constexpr int open_enable_fallocate = (1 << 0);
 
-  static const int start_no_create       = (1 << 1);
-  static const int start_keep_baseline   = (1 << 2);
-  static const int start_skip_tracker    = (1 << 3);
+  static constexpr int start_no_create       = (1 << 1);
+  static constexpr int start_keep_baseline   = (1 << 2);
+  static constexpr int start_skip_tracker    = (1 << 3);
 
-  static const int stop_skip_tracker     = (1 << 0);
+  static constexpr int stop_skip_tracker     = (1 << 0);
 
   Download(DownloadWrapper* d = NULL) : m_ptr(d) {}
 
@@ -104,8 +66,8 @@ public:
   Object*             bencode();
   const Object*       bencode() const;
 
-  TrackerController*  tracker_controller() const;
-  TrackerList*        tracker_list() const;
+  tracker::TrackerControllerWrapper       tracker_controller();
+  const tracker::TrackerControllerWrapper c_tracker_controller() const;
 
   FileList*           file_list() const;
   PeerList*           peer_list();
@@ -133,8 +95,8 @@ public:
   void                set_bitfield(bool allSet);
   void                set_bitfield(uint8_t* first, uint8_t* last);
 
-  static const int update_range_recheck = (1 << 0);
-  static const int update_range_clear   = (1 << 1);
+  static constexpr int update_range_recheck = (1 << 0);
+  static constexpr int update_range_clear   = (1 << 1);
 
   void                update_range(int flags, uint32_t first, uint32_t last);
 
@@ -175,18 +137,18 @@ public:
   void                manual_request(bool force);
   void                manual_cancel();
 
-  typedef enum {
+  enum ConnectionType {
     CONNECTION_LEECH,
     CONNECTION_SEED,
     CONNECTION_INITIAL_SEED,
     CONNECTION_METADATA,
-  } ConnectionType;
+  };
 
   ConnectionType      connection_type() const;
   void                set_connection_type(ConnectionType t);
 
-  typedef enum {
-  } HeuristicType;
+  enum HeuristicType {
+  };
 
   HeuristicType       upload_choke_heuristic() const;
   void                set_upload_choke_heuristic(HeuristicType t);
