@@ -1,8 +1,10 @@
 #include "config.h"
 
+#include "choke_queue.h"
+
 #include <algorithm>
+#include <cassert>
 #include <cstdlib>
-#include <functional>
 #include <numeric>
 
 #include "protocol/peer_connection_base.h"
@@ -11,8 +13,6 @@
 #include "torrent/peer/choke_status.h"
 #include "torrent/utils/log.h"
 
-#include "choke_queue.h"
-
 // TODO: Add a different logging category.
 #define LT_LOG_THIS(log_fmt, ...)                                       \
   lt_log_print_subsystem(LOG_TORRENT_INFO, "choke_queue", log_fmt, __VA_ARGS__);
@@ -39,11 +39,8 @@ log_choke_changes_func_new(void* address, const char* title, int quota, int adju
 }
 
 choke_queue::~choke_queue() {
-  if (m_currently_unchoked != 0)
-    throw internal_error("choke_queue::~choke_queue() called but m_currentlyUnchoked != 0.");
-
-  if (m_currently_queued != 0)
-    throw internal_error("choke_queue::~choke_queue() called but m_currentlyQueued != 0.");
+  assert(m_currently_unchoked == 0 && "choke_queue::~choke_queue() called but m_currently_unchoked != 0.");
+  assert(m_currently_queued == 0 && "choke_queue::~choke_queue() called but m_currently_queued != 0.");
 }
 
 // 1  > 1
@@ -69,21 +66,21 @@ choke_queue::prepare_weights(group_stats gs) {
   //
   // also remember to clear the queue/unchoked thingies.
 
-  for (group_container_type::iterator itr = m_group_container.begin(), last = m_group_container.end(); itr != last; itr++) {
-    m_heuristics_list[m_heuristics].slot_choke_weight((*itr)->mutable_unchoked()->begin(), (*itr)->mutable_unchoked()->end());
-    std::sort((*itr)->mutable_unchoked()->begin(), (*itr)->mutable_unchoked()->end(), choke_manager_less);
+  for (auto group : m_group_container) {
+    m_heuristics_list[m_heuristics].slot_choke_weight(group->mutable_unchoked()->begin(), group->mutable_unchoked()->end());
+    std::sort(group->mutable_unchoked()->begin(), group->mutable_unchoked()->end(), choke_manager_less);
 
-    m_heuristics_list[m_heuristics].slot_unchoke_weight((*itr)->mutable_queued()->begin(), (*itr)->mutable_queued()->end());
-    std::sort((*itr)->mutable_queued()->begin(), (*itr)->mutable_queued()->end(), choke_manager_less);
+    m_heuristics_list[m_heuristics].slot_unchoke_weight(group->mutable_queued()->begin(), group->mutable_queued()->end());
+    std::sort(group->mutable_queued()->begin(), group->mutable_queued()->end(), choke_manager_less);
 
     // Aggregate the statistics... Remember to update them after
     // optimistic/pessimistic unchokes.
-    gs.sum_min_needed += std::min((*itr)->size_connections(), std::min((*itr)->min_slots(), (*itr)->max_slots()));
+    gs.sum_min_needed += std::min({group->size_connections(), group->max_slots(), group->min_slots()});
 
-    uint32_t max_slots = std::min((*itr)->size_connections(), (*itr)->max_slots());
+    uint32_t max_slots = std::min(group->size_connections(), group->max_slots());
 
     gs.sum_max_needed += max_slots;
-    gs.sum_max_leftovers += (*itr)->size_connections() - max_slots;
+    gs.sum_max_leftovers += group->size_connections() - max_slots;
 
     // Counter for how many can choke/unchoke based on weights?
     // However one should never have zero weight for any weight group.
@@ -94,8 +91,7 @@ choke_queue::prepare_weights(group_stats gs) {
 
 group_stats
 choke_queue::retrieve_connections(group_stats gs, container_type* queued, container_type* unchoked) {
-  for (group_container_type::iterator itr = m_group_container.begin(), last = m_group_container.end(); itr != last; itr++) {
-    group_entry* entry = *itr;
+  for (auto entry : m_group_container) {
     unsigned int min_slots = std::min(entry->min_slots(), entry->max_slots());
 
     lt_log_print(LOG_PEER_DEBUG, "Choke queue retrieve_connections; queued:%u unchoked:%u min_slots:%u max_slots:%u.",
@@ -128,8 +124,8 @@ choke_queue::retrieve_connections(group_stats gs, container_type* queued, contai
 
     } else {
       // TODO: This only handles a single weight group, fixme.
-      group_entry::container_type::const_iterator first = entry->unchoked()->begin() + min_slots;
-      group_entry::container_type::const_iterator last  = entry->unchoked()->end();
+      auto first = entry->unchoked()->begin() + min_slots;
+      auto last  = entry->unchoked()->end();
 
       unchoked->insert(unchoked->end(), first, last);
       gs.now_unchoked += min_slots;
@@ -143,7 +139,7 @@ choke_queue::retrieve_connections(group_stats gs, container_type* queued, contai
                      entry->queued()->end() - std::min<uint32_t>(entry->queued()->size(), entry->max_slots() - entry->unchoked()->size()),
                      entry->queued()->end());
     }
-  }    
+  }
 
   return gs;
 }
@@ -153,9 +149,9 @@ choke_queue::rebuild_containers(container_type* queued, container_type* unchoked
   queued->clear();
   unchoked->clear();
 
-  for (group_container_type::iterator itr = m_group_container.begin(), last = m_group_container.end(); itr != last; itr++) {
-    queued->insert(queued->end(), (*itr)->queued()->begin(), (*itr)->queued()->end());
-    unchoked->insert(unchoked->end(), (*itr)->unchoked()->begin(), (*itr)->unchoked()->end());
+  for (auto& group : m_group_container) {
+    queued->insert(queued->end(), group->queued()->begin(), group->queued()->end());
+    unchoked->insert(unchoked->end(), group->unchoked()->begin(), group->unchoked()->end());
   }
 }
 
@@ -191,9 +187,9 @@ choke_queue::balance() {
   // Throws std::bad_function_call if 'set_slot_can_unchoke' is not
   // set.
   int can_unchoke = m_slotCanUnchoke();
-  int max_unchoked = std::min(m_maxUnchoked, (uint32_t)(1 << 20));
+  int max_unchoked = std::min(m_maxUnchoked, uint32_t{1} << 20);
 
-  int adjust = max_unchoked - (int)(unchoked.size() + gs.now_unchoked);
+  int adjust = max_unchoked - static_cast<int>(unchoked.size() + gs.now_unchoked);
   adjust = std::min(adjust, can_unchoke);
 
   log_choke_changes_func_new(this, "balance", m_maxUnchoked, adjust);
@@ -214,7 +210,7 @@ choke_queue::balance() {
   if (result != 0)
     m_slotUnchoke(result);
 
-  LT_LOG_THIS("balanced queue: adjust:%i can_unchoke:%i queued:%" PRIu32 " unchoked:%" PRIu32 " result:%i",
+  LT_LOG_THIS("balanced queue: adjust:%i can_unchoke:%i queued:%zu unchoked:%zu result:%i",
                adjust, can_unchoke, queued.size(), unchoked.size(), result);
 }
 
@@ -285,7 +281,7 @@ choke_queue::cycle(uint32_t quota) {
   lt_log_print(LOG_PEER_DEBUG, "After cycle; queued:%u unchoked:%u unchoked_count:%i old_size:%i.",
                (unsigned)queued.size(), (unsigned)unchoked.size(), unchoked_count, oldSize);
 
-  return ((int)unchoked.size() - (int)oldSize); // + gs.changed_unchoke
+  return (static_cast<int>(unchoked.size()) - oldSize); // + gs.changed_unchoke
 }
 
 void
@@ -301,9 +297,10 @@ choke_queue::set_queued(PeerConnectionBase* pc, choke_status* base) {
   base->entry()->connection_queued(pc);
   modify_currently_queued(1);
 
-  if (!is_full() && (m_flags & flag_unchoke_all_new || m_slotCanUnchoke() > 0) &&
+  if (!is_full() &&
+      (m_flags & flag_unchoke_all_new || m_slotCanUnchoke() > 0) &&
       should_connection_unchoke(this, pc) &&
-      rak::timer(base->time_last_choke()) + rak::timer::from_seconds(10) < cachedTime) {
+      base->time_last_choke() + 10s < this_thread::cached_time()) {
     m_slotConnection(pc, false);
     m_slotUnchoke(1);
   }
@@ -361,15 +358,15 @@ choke_queue::set_not_snubbed(PeerConnectionBase* pc, choke_status* base) {
 
   if (base->unchoked())
     throw internal_error("choke_queue::set_not_snubbed(...) base->unchoked().");
-  
+
   base->entry()->connection_queued(pc);
   modify_currently_queued(1);
 
   if (!is_full() && (m_flags & flag_unchoke_all_new || m_slotCanUnchoke() > 0) &&
       should_connection_unchoke(this, pc) &&
-      rak::timer(base->time_last_choke()) + rak::timer::from_seconds(10) < cachedTime) {
-    m_slotConnection(pc, false);
+      base->time_last_choke() + 10s < this_thread::cached_time()) {
 
+    m_slotConnection(pc, false);
     m_slotUnchoke(1);
   }
 }
@@ -397,9 +394,9 @@ choke_queue::disconnected(PeerConnectionBase* pc, choke_status* base) {
 // No need to do any choking as the next choke balancing will take
 // care of things.
 void
-choke_queue::move_connections(choke_queue* src, choke_queue* dest, DownloadMain* download, group_entry* base) {
+choke_queue::move_connections(choke_queue* src, choke_queue* dest, [[maybe_unused]] DownloadMain* download, group_entry* base) {
   if (src != NULL) {
-    group_container_type::iterator itr = std::find(src->m_group_container.begin(), src->m_group_container.end(), base);
+    auto itr = std::find(src->m_group_container.begin(), src->m_group_container.end(), base);
 
     if (itr == src->m_group_container.end()) throw internal_error("choke_queue::move_connections(...) could not find group.");
 
@@ -426,7 +423,7 @@ choke_queue::move_connections(choke_queue* src, choke_queue* dest, DownloadMain*
 
 void
 choke_manager_allocate_slots(choke_queue::iterator first, choke_queue::iterator last,
-                             uint32_t max, uint32_t* weights, choke_queue::target_type* target) {
+                             uint32_t max, const uint32_t* weights, choke_queue::target_type* target) {
   // Sorting the connections from the lowest to highest value.
   // TODO:  std::sort(first, last, choke_manager_less);
 
@@ -494,7 +491,7 @@ choke_manager_allocate_slots(choke_queue::iterator first, choke_queue::iterator
       if (weights[itr] == 0 || target[itr].first >= s)
         continue;
 
-      uint32_t u = std::min(unchoke, std::min(s - target[itr].first, weights[itr] - start));
+      uint32_t u = std::min({unchoke, s - target[itr].first, weights[itr] - start});
 
       start = 0;
       unchoke -= u;
@@ -528,7 +525,7 @@ choke_queue::adjust_choke_range(iterator first, iterator last,
   if (lt_log_is_valid(LOG_INSTRUMENTATION_CHOKE)) {
     for (uint32_t i = 0; i < choke_queue::order_max_size; i++)
       lt_log_print(LOG_INSTRUMENTATION_CHOKE,
-                   "%p %i %s %u %u %i",
+                   "%p %i %s %u %u %zd",
                    this,
                    0, //lf->last_update(),
                    (const char*)"unchoke" + 2*is_choke,
@@ -551,8 +548,8 @@ choke_queue::adjust_choke_range(iterator first, iterator last,
     (itr - 1)->first += std::min(skipped, order_remaining);
     skipped          -= std::min(skipped, order_remaining);
 
-    iterator first_adjust = itr->second - (itr - 1)->first;
-    iterator last_adjust = itr->second;
+    auto first_adjust = itr->second - (itr - 1)->first;
+    auto last_adjust  = itr->second;
 
     if (!range_is_contained(first_adjust, last_adjust, src_container->begin(), src_container->end()))
       throw internal_error("choke_queue::adjust_choke_range(...) bad iterator range.");
@@ -560,7 +557,7 @@ choke_queue::adjust_choke_range(iterator first, iterator last,
     // We start by unchoking the highest priority in this group, and
     // if we find any peers we can't choke/unchoke we'll move them to
     // the last spot in the container and decrement 'last_adjust'.
-    iterator itr_adjust = last_adjust;
+    auto itr_adjust = last_adjust;
 
     while (itr_adjust != first_adjust) {
       itr_adjust--;
@@ -670,7 +667,7 @@ calculate_upload_unchoke_seed(choke_queue::iterator first, choke_queue::iterator
 }
 
 //
-// New leeching choke algorithm that 
+// New leeching choke algorithm:
 //
 
 // Order 0: Normal
@@ -679,7 +676,7 @@ void
 calculate_choke_upload_leech_experimental(choke_queue::iterator first, choke_queue::iterator last) {
   while (first != last) {
     // Don't choke a peer that hasn't had time to unchoke us.
-    if (rak::timer(first->connection->up_choke()->time_last_choke()) + rak::timer::from_seconds(50) > cachedTime) {
+    if (first->connection->up_choke()->time_last_choke() + 50s > this_thread::cached_time()) {
       first->weight = 1 * choke_queue::order_base;
       first++;
       continue;
