@@ -11,8 +11,7 @@ namespace torrent {
 
 Http::slot_http Http::m_factory;
 
-Http::~Http() {
-}
+Http::~Http() = default;
 
 void
 Http::trigger_done() {
@@ -22,7 +21,7 @@ Http::trigger_done() {
   bool should_delete_self = (m_flags & flag_delete_self);
   bool should_delete_stream = (m_flags & flag_delete_stream);
 
-  utils::slot_list_call(signal_done());
+  ::utils::slot_list_call(signal_done());
 
   if (should_delete_stream) {
     delete m_stream;
@@ -41,7 +40,7 @@ Http::trigger_failed(const std::string& message) {
   bool should_delete_self = (m_flags & flag_delete_self);
   bool should_delete_stream = (m_flags & flag_delete_stream);
 
-  utils::slot_list_call(signal_failed(), message);
+  ::utils::slot_list_call(signal_failed(), message);
 
   if (should_delete_stream) {
     delete m_stream;
