@@ -1,39 +1,3 @@
-// libTorrent - BitTorrent library
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #ifndef LIBTORRENT_OBJECT_RAW_BENCODE_H
 #define LIBTORRENT_OBJECT_RAW_BENCODE_H
 
@@ -41,6 +5,7 @@
 #include <string>
 #include <cstring>
 #include <torrent/common.h>
+#include <torrent/exceptions.h>
 
 namespace torrent {
 
@@ -53,15 +18,15 @@ class raw_map;
 // should never be used directly.
 class raw_object {
 public:
-  typedef const char  value_type;
-  typedef const char* iterator;
-  typedef const char* const_iterator;
-  typedef uint32_t    size_type;
+  using value_type     = const char;
+  using iterator       = const char*;
+  using const_iterator = const char*;
+  using size_type      = uint32_t;
 
   raw_object() : m_data(), m_size() {}
   raw_object(value_type* src_data, size_type src_size) : m_data(src_data), m_size(src_size) {}
 
-  bool        empty() const { return m_size == 0;; }
+  bool        empty() const { return m_size == 0; }
   size_type   size() const { return m_size; }
 
   iterator    begin() const { return m_data; }
@@ -95,7 +60,7 @@ protected:
 // empty.
 class raw_bencode : protected raw_object {
 public:
-  typedef raw_bencode this_type;
+  using this_type = raw_bencode;
   RAW_BENCODE_SET_USING
 
   raw_bencode() : raw_object() {}
@@ -117,10 +82,10 @@ public:
 
 class raw_string : protected raw_object {
 public:
-  typedef raw_string this_type;
+  using this_type = raw_string;
   RAW_BENCODE_SET_USING
 
-  raw_string() {}
+  raw_string() = default;
   raw_string(value_type* src_data, size_type src_size) : raw_object(src_data, src_size) {}
 
   std::string as_string() const { return std::string(m_data, m_size); }
@@ -131,10 +96,10 @@ public:
 
 class raw_list : protected raw_object {
 public:
-  typedef raw_list this_type;
+  using this_type = raw_list;
   RAW_BENCODE_SET_USING
 
-  raw_list() {}
+  raw_list() = default;
   raw_list(value_type* src_data, size_type src_size) : raw_object(src_data, src_size) {}
 
   static raw_list from_c_str(const char* str) { return raw_list(str, std::strlen(str)); }
@@ -142,10 +107,10 @@ public:
 
 class raw_map : protected raw_object {
 public:
-  typedef raw_map this_type;
+  using this_type = raw_map;
   RAW_BENCODE_SET_USING
 
-  raw_map() {}
+  raw_map() = default;
   raw_map(value_type* src_data, size_type src_size) : raw_object(src_data, src_size) {}
 };
 
