@@ -1,39 +1,3 @@
-// libTorrent - BitTorrent library
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #include "config.h"
 
 #include <iterator>
@@ -59,17 +23,20 @@ object_read_string(std::istream* input, std::string& str) {
 
   if (input->fail() || input->get() != ':')
     return false;
-  
+
   try {
   	str.resize(size);
+
+  } catch (std::length_error& e) {
+    return false;
   }
-  catch (std::length_error& e){ 
-	  return false;
+
+  for (auto& c : str) {
+    if (!input->good())
+      break;
+    c = input->get();
   }
 
-  for (std::string::iterator itr = str.begin(); itr != str.end() && input->good(); ++itr)
-    *itr = input->get();
-  
   return !input->fail();
 }
 
@@ -110,8 +77,7 @@ object_read_bencode_c_string(const char* first, const char* last) {
   while (first != last && *first >= '0' && *first <= '9')
     length = length * 10 + (*first++ - '0');
 
-  if (length + 1 > (unsigned int)std::distance(first, last) || length + 1 == 0
-		  || *first++ != ':')
+  if (length + 1 > static_cast<unsigned int>(std::distance(first, last)) || length + 1 == 0 || *first++ != ':')
     throw torrent::bencode_error("Invalid bencode data.");
   
   return raw_string(first, length);
@@ -148,7 +114,7 @@ object_read_bencode(std::istream* input, Object* object, uint32_t depth) {
 	return;
       }
 
-      Object::list_iterator itr = object->as_list().insert(object->as_list().end(), Object());
+      auto itr = object->as_list().insert(object->as_list().end(), Object());
       object_read_bencode(input, &*itr, depth);
 
       // The unordered flag is inherited also from list elements who
@@ -239,7 +205,7 @@ object_read_bencode_c(const char* first, const char* last, Object* object, uint3
       if (*first == 'e')
 	return first + 1;
 
-      Object::list_iterator itr = object->as_list().insert(object->as_list().end(), Object());
+      auto itr = object->as_list().insert(object->as_list().end(), Object());
       first = object_read_bencode_c(first, last, &*itr, depth);
 
       // The unordered flag is inherited also from list elements who
@@ -544,11 +510,11 @@ object_write_bencode_c_object(object_write_data_t* output, const Object* object,
   case Object::TYPE_LIST:
     object_write_bencode_c_char(output, 'l');
 
-    for (Object::list_const_iterator itr = object->as_list().begin(), last = object->as_list().end(); itr != last; ++itr) {
-      if (itr->is_empty() || itr->flags() & skip_mask)
+    for (const auto& list : object->as_list()) {
+      if (list.is_empty() || list.flags() & skip_mask)
         continue;
 
-      object_write_bencode_c_object(output, &*itr, skip_mask);
+      object_write_bencode_c_object(output, &list, skip_mask);
     }
 
     object_write_bencode_c_char(output, 'e');
@@ -557,12 +523,12 @@ object_write_bencode_c_object(object_write_data_t* output, const Object* object,
   case Object::TYPE_MAP:
     object_write_bencode_c_char(output, 'd');
 
-    for (Object::map_const_iterator itr = object->as_map().begin(), last = object->as_map().end(); itr != last; ++itr) {
-      if (itr->second.is_empty() || itr->second.flags() & skip_mask)
+    for (const auto& map : object->as_map()) {
+      if (map.second.is_empty() || map.second.flags() & skip_mask)
         continue;
 
-      object_write_bencode_c_obj_string(output, itr->first);
-      object_write_bencode_c_object(output, &itr->second, skip_mask);
+      object_write_bencode_c_obj_string(output, map.first);
+      object_write_bencode_c_object(output, &map.second, skip_mask);
     }
 
     object_write_bencode_c_char(output, 'e');
@@ -618,16 +584,16 @@ object_write_to_buffer(void* data, object_buffer_t buffer) {
 
 object_buffer_t
 object_write_to_sha1(void* data, object_buffer_t buffer) {
-  reinterpret_cast<Sha1*>(data)->update(buffer.first, std::distance(buffer.first, buffer.second));
+  static_cast<Sha1*>(data)->update(buffer.first, std::distance(buffer.first, buffer.second));
 
   return buffer;
 }
 
 object_buffer_t
 object_write_to_stream(void* data, object_buffer_t buffer) {
-  reinterpret_cast<std::ostream*>(data)->write(buffer.first, std::distance(buffer.first, buffer.second));
+  static_cast<std::ostream*>(data)->write(buffer.first, std::distance(buffer.first, buffer.second));
 
-  if (reinterpret_cast<std::ostream*>(data)->bad())
+  if (static_cast<std::ostream*>(data)->bad())
     return object_buffer_t(buffer.first, buffer.first);
 
   return buffer;
@@ -635,7 +601,7 @@ object_write_to_stream(void* data, object_buffer_t buffer) {
 
 object_buffer_t
 object_write_to_size(void* data, object_buffer_t buffer) {
-  *reinterpret_cast<uint64_t*>(data) += std::distance(buffer.first, buffer.second);
+  *static_cast<uint64_t*>(data) += std::distance(buffer.first, buffer.second);
 
   return buffer;
 }
