@@ -1,5 +1,7 @@
 #include "config.h"
 
+#include "torrent/peer/connection_list.h"
+
 #include <algorithm>
 #include <rak/socket_address.h>
 
@@ -10,12 +12,10 @@
 #include "torrent/download_info.h"
 #include "torrent/download/choke_group.h"
 #include "torrent/download/choke_queue.h"
+#include "torrent/peer/peer.h"
+#include "torrent/peer/peer_info.h"
 #include "utils/functional.h"
 
-#include "connection_list.h"
-#include "peer.h"
-#include "peer_info.h"
-
 // When a peer is connected it should be removed from the list of
 // available peers.
 //
@@ -30,7 +30,7 @@ const int ConnectionList::disconnect_unwanted;
 const int ConnectionList::disconnect_delayed;
 
 ConnectionList::ConnectionList(DownloadMain* download) :
-  m_download(download), m_minSize(50), m_maxSize(100) {
+    m_download(download) {
 }
 
 void
@@ -44,7 +44,7 @@ ConnectionList::clear() {
 }
 
 bool
-ConnectionList::want_connection(PeerInfo* p, Bitfield* bitfield) {
+ConnectionList::want_connection([[maybe_unused]] PeerInfo* p, Bitfield* bitfield) {
   if (m_download->file_list()->is_done() || m_download->initial_seeding() != NULL)
     return !bitfield->is_all_set();
 
@@ -65,7 +65,7 @@ ConnectionList::insert(PeerInfo* peerInfo, const SocketFd& fd, Bitfield* bitfiel
     throw internal_error("ConnectionList::insert(...) received a NULL pointer.");
 
   peerInfo->set_connection(peerConnection);
-  peerInfo->set_last_connection(cachedTime.seconds());
+  peerInfo->set_last_connection(this_thread::cached_seconds().count());
   peerConnection->initialize(m_download, peerInfo, fd, bitfield, encryptionInfo, extensions);
 
   if (!peerConnection->get_fd().is_valid()) {
@@ -76,7 +76,8 @@ ConnectionList::insert(PeerInfo* peerInfo, const SocketFd& fd, Bitfield* bitfiel
   base_type::push_back(peerConnection);
 
   m_download->info()->change_flags(DownloadInfo::flag_accepting_new_peers, size() < m_maxSize);
-  utils::slot_list_call(m_signalConnected, peerConnection);
+
+  ::utils::slot_list_call(m_signalConnected, peerConnection);
 
   return peerConnection;
 }
@@ -88,8 +89,8 @@ ConnectionList::erase(iterator pos, int flags) {
 
   if (flags & disconnect_delayed) {
     m_disconnectQueue.push_back((*pos)->id());
-    if (!m_download->delay_disconnect_peers().is_queued())
-      priority_queue_insert(&taskScheduler, &m_download->delay_disconnect_peers(), cachedTime);
+
+    this_thread::scheduler()->update_wait_for(&m_download->delay_disconnect_peers(), 0us);
     return pos;
   }
 
@@ -102,7 +103,8 @@ ConnectionList::erase(iterator pos, int flags) {
   base_type::pop_back();
 
   m_download->info()->change_flags(DownloadInfo::flag_accepting_new_peers, size() < m_maxSize);
-  utils::slot_list_call(m_signalDisconnected, peerConnection);
+
+  ::utils::slot_list_call(m_signalDisconnected, peerConnection);
 
   // Before of after the signal?
   peerConnection->cleanup();
@@ -123,7 +125,7 @@ ConnectionList::erase(Peer* p, int flags) {
 
 void
 ConnectionList::erase(PeerInfo* peerInfo, int flags) {
-  iterator itr = std::find(begin(), end(), peerInfo->connection());
+  auto itr = std::find(begin(), end(), peerInfo->connection());
 
   if (itr == end())
     return;
@@ -151,14 +153,14 @@ ConnectionList::erase_seeders() {
 
 void
 ConnectionList::disconnect_queued() {
-  for (queue_type::const_iterator itr = m_disconnectQueue.begin(), last = m_disconnectQueue.end(); itr != last; itr++) {
-    ConnectionList::iterator conn_itr = find(m_disconnectQueue.back().c_str());
+  for (const auto& queue : m_disconnectQueue) {
+    auto conn_itr = find(queue.c_str());
 
     if (conn_itr != end())
       erase(conn_itr, 0);
   }
 
-  m_disconnectQueue = queue_type();
+  m_disconnectQueue.clear();
 }
 
 struct connection_list_less {
