@@ -51,18 +51,8 @@ namespace torrent {
 // Move this to peer_info.cc when these are made into the public API.
 //
 // TODO: Use a safer socket address parameter.
-PeerInfo::PeerInfo(const sockaddr* address) : 
-  m_flags(0),
-
-  m_failedCounter(0),
-  m_transferCounter(0),
-  m_lastConnection(0),
-  m_lastHandshake(0),
-  m_listenPort(0),
-
-  m_connection(NULL)
-{
-  rak::socket_address* sa = new rak::socket_address();
+PeerInfo::PeerInfo(const sockaddr* address) {
+  auto sa = new rak::socket_address();
   *sa = *rak::socket_address::cast_from(address);
 
   m_address = sa->c_sockaddr();
