@@ -10,7 +10,6 @@
 
 #include "download_info.h"
 #include "exceptions.h"
-#include "globals.h"
 #include "manager.h"
 #include "peer_info.h"
 #include "peer_list.h"
@@ -55,7 +54,7 @@ socket_address_less(const sockaddr* s1, const sockaddr* s2) {
 //
 
 PeerList::PeerList() :
-  m_available_list(new AvailableList) {
+    m_available_list(std::make_unique<AvailableList>()) {
 }
 
 PeerList::~PeerList() {
@@ -68,7 +67,6 @@ PeerList::~PeerList() {
   base_type::clear();
 
   m_info = NULL;
-  delete m_available_list;
 }
 
 void
@@ -103,7 +101,7 @@ PeerList::insert_address(const sockaddr* sa, int flags) {
     return NULL;
   }
 
-  PeerInfo* peerInfo = new PeerInfo(sa);
+  auto peerInfo = new PeerInfo(sa);
   peerInfo->set_listen_port(address->port());
   uint32_t host_byte_order_ipv4_addr = address->sa_inet()->address_h();
 
@@ -134,7 +132,7 @@ socket_address_less_rak(const rak::socket_address& s1, const rak::socket_address
 
 uint32_t
 PeerList::insert_available(const void* al) {
-  const AddressList* addressList = static_cast<const AddressList*>(al);
+  auto addressList = static_cast<const AddressList*>(al);
 
   uint32_t inserted = 0;
   uint32_t invalid = 0;
@@ -147,30 +145,28 @@ PeerList::insert_available(const void* al) {
   // Optimize this so that we don't traverse the tree for every
   // insert, since we know 'al' is sorted.
 
-  AddressList::const_iterator itr   = addressList->begin();
-  AddressList::const_iterator last  = addressList->end();
-  AvailableList::const_iterator availItr  = m_available_list->begin();
-  AvailableList::const_iterator availLast = m_available_list->end();
+  auto availItr  = m_available_list->begin();
+  auto availLast = m_available_list->end();
 
-  for (; itr != last; itr++) {
-    if (!socket_address_key::is_comparable_sockaddr(itr->c_sockaddr()) || itr->port() == 0) {
+  for (const auto& addr : *addressList) {
+    if (!socket_address_key::is_comparable_sockaddr(addr.c_sockaddr()) || addr.port() == 0) {
       invalid++;
-      LT_LOG_ADDRESS("skipped invalid address " LT_LOG_SA_FMT, itr->address_str().c_str(), itr->port());
+      LT_LOG_ADDRESS("skipped invalid address " LT_LOG_SA_FMT, addr.address_str().c_str(), addr.port());
       continue;
     }
 
-    availItr = std::find_if(availItr, availLast, [&itr](const rak::socket_address& sa) {
-      return socket_address_less_rak(sa, *itr);
+    availItr = std::find_if(availItr, availLast, [&addr](const rak::socket_address& sa) {
+      return socket_address_less_rak(sa, addr);
     });
 
-    if (availItr != availLast && !socket_address_less(availItr->c_sockaddr(), itr->c_sockaddr())) {
+    if (availItr != availLast && !socket_address_less(availItr->c_sockaddr(), addr.c_sockaddr())) {
       // The address is already in m_available_list, so don't bother
       // going further.
       unneeded++;
       continue;
     }
 
-    socket_address_key sock_key = socket_address_key::from_sockaddr(itr->c_sockaddr());
+    socket_address_key sock_key = socket_address_key::from_sockaddr(addr.c_sockaddr());
 
     // Check if the peerinfo exists, if it does, check if we would
     // ever want to connect. Just update the timer for the last
@@ -184,10 +180,10 @@ PeerList::insert_available(const void* al) {
       PeerInfo* peerInfo = range.first->second;
 
       if (peerInfo->listen_port() == 0)
-        peerInfo->set_port(itr->port());
+        peerInfo->set_port(addr.port());
 
       if (peerInfo->connection() != NULL ||
-          peerInfo->last_handshake() + 600 > (uint32_t)cachedTime.seconds()) {
+          peerInfo->last_handshake() + 600 > static_cast<uint32_t>(this_thread::cached_seconds().count())) {
         updated++;
         continue;
       }
@@ -203,9 +199,9 @@ PeerList::insert_available(const void* al) {
     // won't happen often enough to be worth it.
 
     inserted++;
-    m_available_list->push_back(&*itr);
+    m_available_list->push_back(&addr);
 
-    LT_LOG_ADDRESS("added available address " LT_LOG_SA_FMT, itr->address_str().c_str(), itr->port());
+    LT_LOG_ADDRESS("added available address " LT_LOG_SA_FMT, addr.address_str().c_str(), addr.port());
   }
 
   LT_LOG_EVENTS("inserted peers"
@@ -291,7 +287,7 @@ PeerList::connected(const sockaddr* sa, int flags) {
   }
 
   if (flags & connect_filter_recent &&
-      peerInfo->last_handshake() + 600 > (uint32_t)cachedTime.seconds())
+      peerInfo->last_handshake() + 600 > static_cast<uint32_t>(this_thread::cached_seconds().count()))
     return NULL;
 
   if (!(flags & connect_incoming))
@@ -303,7 +299,7 @@ PeerList::connected(const sockaddr* sa, int flags) {
     peerInfo->unset_flags(PeerInfo::flag_incoming);
 
   peerInfo->set_flags(PeerInfo::flag_connected);
-  peerInfo->set_last_handshake(cachedTime.seconds());
+  peerInfo->set_last_handshake(this_thread::cached_seconds().count());
 
   return peerInfo;
 }
@@ -316,7 +312,7 @@ PeerList::disconnected(PeerInfo* p, int flags) {
 
   range_type range = base_type::equal_range(sock_key);
   
-  iterator itr = std::find_if(range.first, range.second, [p](auto& v) { return p == v.second; });
+  auto itr = std::find_if(range.first, range.second, [p](auto& v) { return p == v.second; });
 
   if (itr == range.second) {
     if (std::none_of(base_type::begin(), base_type::end(), [p](auto& v){ return p == v.second; }))
@@ -350,7 +346,7 @@ PeerList::disconnected(iterator itr, int flags) {
   itr->second->set_port(0);
 
   if (flags & disconnect_set_time)
-    itr->second->set_last_connection(cachedTime.seconds());
+    itr->second->set_last_connection(this_thread::cached_seconds().count());
 
   if (flags & disconnect_available && itr->second->listen_port() != 0)
     m_available_list->push_back(rak::socket_address::cast_from(itr->second->socket_address()));
@@ -365,11 +361,11 @@ PeerList::cull_peers(int flags) {
   uint32_t timer;
 
   if (flags & cull_old)
-    timer = cachedTime.seconds() - 24 * 60 * 60;
+    timer = this_thread::cached_seconds().count() - 24 * 60 * 60;
   else
     timer = 0;
 
-  for (iterator itr = base_type::begin(); itr != base_type::end(); ) {
+  for (auto itr = base_type::begin(); itr != base_type::end(); ) {
     if (itr->second->is_connected() ||
         itr->second->transfer_counter() != 0 || // !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
         itr->second->last_connection() >= timer ||
@@ -386,7 +382,7 @@ PeerList::cull_peers(int flags) {
     // The key is a pointer to a member in the value, although the key
     // shouldn't actually be used in erase (I think), just ot be safe
     // we delete it after erase.
-    iterator tmp = itr++;
+    auto tmp = itr++;
     PeerInfo* peerInfo = tmp->second;
 
     base_type::erase(tmp);
