@@ -1,29 +1,31 @@
 #include "config.h"
 
-#include <rak/address_info.h>
-#include <rak/string_manip.h>
-
-#include "exceptions.h"
-#include "torrent.h"
-#include "object.h"
-#include "object_stream.h"
-#include "throttle.h"
-#include "connection_manager.h"
-#include "poll.h"
+#include "torrent/torrent.h"
 
 #include "manager.h"
-
-#include "protocol/handshake_manager.h"
-#include "protocol/peer_factory.h"
+#include "thread_main.h"
 #include "data/file_manager.h"
 #include "data/hash_queue.h"
 #include "data/hash_torrent.h"
+#include "data/thread_disk.h"
 #include "download/download_constructor.h"
 #include "download/download_manager.h"
 #include "download/download_wrapper.h"
-#include "utils/instrumentation.h"
+#include "net/thread_net.h"
+#include "protocol/handshake_manager.h"
+#include "protocol/peer_factory.h"
+#include "rak/address_info.h"
+#include "rak/string_manip.h"
+#include "torrent/connection_manager.h"
+#include "torrent/exceptions.h"
+#include "torrent/object.h"
+#include "torrent/object_stream.h"
+#include "torrent/throttle.h"
+#include "torrent/poll.h"
 #include "torrent/peer/connection_list.h"
 #include "torrent/download/resource_manager.h"
+#include "tracker/thread_tracker.h"
+#include "utils/instrumentation.h"
 
 namespace torrent {
 
@@ -53,27 +55,39 @@ calculate_reserved(uint32_t openMax) {
     return 32;
   else // Assumes we don't try less than 64.
     return 16;
-}    
+}
+
+void
+initialize_main_thread() {
+  ThreadMain::create_thread();
+  thread_main()->init_thread();
+}
 
 void
 initialize() {
   if (manager != NULL)
     throw internal_error("torrent::initialize(...) called but the library has already been initialized");
 
-  cachedTime = rak::timer::current();
-
   instrumentation_initialize();
 
   manager = new Manager;
-  manager->main_thread_main()->init_thread();
 
-  uint32_t maxFiles = calculate_max_open_files(manager->poll()->open_max());
+  ThreadDisk::create_thread();
+  ThreadNet::create_thread();
+  ThreadTracker::create_thread(thread_main());
 
-  manager->connection_manager()->set_max_size(manager->poll()->open_max() - maxFiles - calculate_reserved(manager->poll()->open_max()));
+  uint32_t maxFiles = calculate_max_open_files(this_thread::poll()->open_max());
+
+  manager->connection_manager()->set_max_size(this_thread::poll()->open_max() - maxFiles - calculate_reserved(this_thread::poll()->open_max()));
   manager->file_manager()->set_max_open_files(maxFiles);
 
-  manager->main_thread_disk()->init_thread();
-  manager->main_thread_disk()->start_thread();
+  thread_disk()->init_thread();
+  thread_net()->init_thread();
+  thread_tracker()->init_thread();
+
+  thread_disk()->start_thread();
+  thread_net()->start_thread();
+  thread_tracker()->start_thread();
 }
 
 // Clean up and close stuff. Stopping all torrents and waiting for
@@ -83,7 +97,16 @@ cleanup() {
   if (manager == NULL)
     throw internal_error("torrent::cleanup() called but the library is not initialized.");
 
-  manager->main_thread_disk()->stop_thread_wait();
+  // Might need to wait for the threads to finish?
+  manager->cleanup();
+
+  thread_tracker()->stop_thread_wait();
+  thread_disk()->stop_thread_wait();
+  thread_net()->stop_thread_wait();
+
+  delete thread_tracker();
+  delete thread_disk();
+  delete thread_net();
 
   delete manager;
   manager = NULL;
@@ -96,23 +119,22 @@ is_initialized() {
 
 bool
 is_inactive() {
-  return manager == NULL ||
-    std::find_if(manager->download_manager()->begin(), manager->download_manager()->end(), std::not1(std::mem_fun(&DownloadWrapper::is_stopped)))
-    == manager->download_manager()->end();
+  return manager == nullptr || std::all_of(manager->download_manager()->begin(), manager->download_manager()->end(), std::mem_fn(&DownloadWrapper::is_stopped));
 }
 
-thread_base*
-main_thread() {
-  return manager->main_thread_main();
+void
+set_main_thread_slots(std::function<void()> do_work) {
+  thread_main()->slot_do_work() = std::move(do_work);
 }
 
 ChunkManager*      chunk_manager() { return manager->chunk_manager(); }
 ClientList*        client_list() { return manager->client_list(); }
 ConnectionManager* connection_manager() { return manager->connection_manager(); }
 FileManager*       file_manager() { return manager->file_manager(); }
-DhtManager*        dht_manager() { return manager->dht_manager(); }
 ResourceManager*   resource_manager() { return manager->resource_manager(); }
 
+tracker::DhtController* dht_controller() { return manager->dht_controller(); }
+
 uint32_t
 total_handshakes() {
   return manager->handshake_manager()->size();
@@ -125,16 +147,14 @@ const Rate* down_rate() { return manager->download_throttle()->rate(); }
 const Rate* up_rate() { return manager->upload_throttle()->rate(); }
 const char* version() { return VERSION; }
 
-uint32_t hash_queue_size() { return manager->hash_queue()->size(); }
-
 EncodingList*
 encoding_list() {
   return manager->encoding_list();
 }
 
 Download
-download_add(Object* object) {
-  std::auto_ptr<DownloadWrapper> download(new DownloadWrapper);
+download_add(Object* object, uint32_t tracker_key) {
+  auto download = std::make_unique<DownloadWrapper>();
 
   DownloadConstructor ctor;
   ctor.set_download(download.get());
@@ -160,8 +180,8 @@ download_add(Object* object) {
 
   std::string local_id = PEER_NAME + rak::generate_random<std::string>(20 - std::string(PEER_NAME).size());
 
-  download->set_hash_queue(manager->hash_queue());
-  download->initialize(infoHash, local_id);
+  download->set_hash_queue(thread_main()->hash_queue());
+  download->initialize(infoHash, local_id, tracker_key);
 
   // Add trackers, etc, after setting the info hash so that log
   // entries look sane.
@@ -187,9 +207,7 @@ download_remove(Download d) {
 // Add all downloads to dlist. Make sure it's cleared.
 void
 download_list(DList& dlist) {
-  for (DownloadManager::const_iterator itr = manager->download_manager()->begin();
-       itr != manager->download_manager()->end(); ++itr)
-    dlist.emplace_back(*itr);
+  dlist.insert(dlist.end(), manager->download_manager()->begin(), manager->download_manager()->end());
 }
 
 // Make sure you check that it's valid.
@@ -200,7 +218,7 @@ download_find(const std::string& infohash) {
 
 uint32_t
 download_priority(Download d) {
-  ResourceManager::iterator itr = manager->resource_manager()->find(d.ptr()->main());
+  auto itr = manager->resource_manager()->find(d.ptr()->main());
 
   if (itr == manager->resource_manager()->end())
     throw internal_error("torrent::download_priority(...) could not find the download in the resource manager.");
@@ -211,7 +229,7 @@ download_priority(Download d) {
 // TODO: Remove this.
 void
 download_set_priority(Download d, uint32_t pri) {
-  ResourceManager::iterator itr = manager->resource_manager()->find(d.ptr()->main());
+  auto itr = manager->resource_manager()->find(d.ptr()->main());
 
   if (itr == manager->resource_manager()->end())
     throw internal_error("torrent::download_set_priority(...) could not find the download in the resource manager.");
