@@ -2,7 +2,6 @@
 
 #include "log.h"
 
-#include "globals.h"
 #include "torrent/exceptions.h"
 #include "torrent/hash_string.h"
 
@@ -15,13 +14,12 @@
 #include <fstream>
 #include <functional>
 #include <memory>
-
-#define GROUPFMT (group >= LOG_NON_CASCADING) ? ("%" PRIi32 " ") : ("%" PRIi32 " %c ")
+#include <mutex>
 
 namespace torrent {
 
 struct log_cache_entry {
-  typedef log_group::outputs_type outputs_type;
+  using outputs_type = log_group::outputs_type;
 
   bool equal_outputs(const outputs_type& out) const { return out == outputs; }
 
@@ -34,27 +32,26 @@ struct log_cache_entry {
 };
 
 struct log_gz_output {
-  log_gz_output(const char* filename, bool append) { gz_file = gzopen(filename, append ? "a" : "w"); }
-  ~log_gz_output() { if (gz_file != NULL) gzclose(gz_file); }
+  log_gz_output(const char* filename, bool append) :
+      gz_file(gzopen(filename, append ? "a" : "w"), gzclose) {}
 
   bool is_valid() { return gz_file != Z_NULL; }
 
-  // bool set_buffer(unsigned size) { return gzbuffer(gz_file, size) == 0; }
+  // bool set_buffer(unsigned size) { return gzbuffer(gz_file.get(), size) == 0; }
 
-  gzFile gz_file;
+  std::unique_ptr<gzFile_s, decltype(&gzclose)> gz_file;
 };
 
-typedef std::vector<log_cache_entry>                   log_cache_list;
-typedef std::vector<std::pair<int, int> >              log_child_list;
-typedef std::vector<log_slot>                          log_slot_list;
-typedef std::vector<std::pair<std::string, log_slot> > log_output_list;
+using log_cache_list  = std::vector<log_cache_entry>;
+using log_child_list  = std::vector<std::pair<int, int>>;
+using log_slot_list   = std::vector<log_slot>;
+using log_output_list = std::vector<std::pair<std::string, log_slot>>;
 
-log_output_list log_outputs;
+log_output_list log_outputs LIBTORRENT_EXPORT;
 log_child_list  log_children;
 log_cache_list  log_cache;
 log_group_list  log_groups;
-
-pthread_mutex_t log_mutex = PTHREAD_MUTEX_INITIALIZER;
+std::mutex      log_mutex;
 
 const char log_level_char[] = { 'C', 'E', 'W', 'N', 'I', 'D' };
 
@@ -63,9 +60,8 @@ const char log_level_char[] = { 'C', 'E', 'W', 'N', 'I', 'D' };
 
 void
 log_update_child_cache(int index) {
-  log_child_list::const_iterator first =
-    std::find_if(log_children.begin(), log_children.end(),
-                 std::bind2nd(std::greater_equal<std::pair<int, int> >(), std::make_pair(index, 0)));
+  auto first =
+    std::find_if(log_children.begin(), log_children.end(), [index](const auto& pair) { return pair >= std::make_pair(index, 0); });
 
   if (first == log_children.end())
     return;
@@ -89,27 +85,26 @@ log_update_child_cache(int index) {
 
 void
 log_rebuild_cache() {
-  std::for_each(log_groups.begin(), log_groups.end(), std::mem_fun_ref(&log_group::clear_cached_outputs));
+  std::for_each(log_groups.begin(), log_groups.end(), std::mem_fn(&log_group::clear_cached_outputs));
 
   for (int i = 0; i < LOG_GROUP_MAX_SIZE; i++)
     log_update_child_cache(i);
 
   // Clear the cache...
-  std::for_each(log_cache.begin(), log_cache.end(), std::mem_fun_ref(&log_cache_entry::clear));
+  std::for_each(log_cache.begin(), log_cache.end(), std::mem_fn(&log_cache_entry::clear));
   log_cache.clear();
 
-  for (int idx = 0, last = log_groups.size(); idx != last; idx++) {
-    const log_group::outputs_type& use_outputs = log_groups[idx].cached_outputs();
+  for (auto& idx : log_groups) {
+    const log_group::outputs_type& use_outputs = idx.cached_outputs();
 
     if (use_outputs == 0) {
-      log_groups[idx].set_cached(NULL, NULL);
+      idx.set_cached(NULL, NULL);
       continue;
     }
 
-    log_cache_list::iterator cache_itr = 
-      std::find_if(log_cache.begin(), log_cache.end(),
-                   std::bind(&log_cache_entry::equal_outputs, std::placeholders::_1, use_outputs));
-    
+    auto cache_itr = std::find_if(log_cache.begin(), log_cache.end(), [&use_outputs](const auto& entry) {
+      return entry.equal_outputs(use_outputs);
+    });
     if (cache_itr == log_cache.end()) {
       cache_itr = log_cache.insert(log_cache.end(), log_cache_entry());
       cache_itr->outputs = use_outputs;
@@ -123,14 +118,14 @@ log_rebuild_cache() {
       }
     }
 
-    log_groups[idx].set_cached(cache_itr->cache_first, cache_itr->cache_last);
+    idx.set_cached(cache_itr->cache_first, cache_itr->cache_last);
   }
 }
 
 void
 log_group::internal_print(const HashString* hash, const char* subsystem, const void* dump_data, size_t dump_size, const char* fmt, ...) {
   va_list ap;
-  unsigned int buffer_size = 4096;
+  const unsigned int buffer_size = 4096;
   char buffer[buffer_size];
   char* first = buffer;
 
@@ -151,22 +146,16 @@ log_group::internal_print(const HashString* hash, const char* subsystem, const v
   if (count <= 0)
     return;
 
-  pthread_mutex_lock(&log_mutex);
+  auto lock = std::scoped_lock(log_mutex);
 
-  std::for_each(m_first, m_last, std::bind(&log_slot::operator(),
-                                           std::placeholders::_1,
-                                           (const char*)buffer,
-                                           std::distance(buffer, first),
-                                           std::distance(log_groups.begin(), this)));
+  std::for_each(m_first, m_last, [this, &buffer, first](const auto& elem) {
+    return elem(buffer, std::distance(buffer, first), std::distance(log_groups.begin(), this));
+  });
   if (dump_data != NULL) {
-    std::for_each(m_first, m_last, std::bind(&log_slot::operator(),
-                                             std::placeholders::_1,
-                                             (const char*)dump_data,
-                                             dump_size,
-                                             -1));
+    std::for_each(m_first, m_last, [dump_data, dump_size](const auto& log) {
+      return log(static_cast<const char*>(dump_data), dump_size, -1);
+    });
   }
-
-  pthread_mutex_unlock(&log_mutex);
 }
 
 #define LOG_CASCADE(parent) LOG_CHILDREN_CASCADE(parent, parent)
@@ -189,7 +178,7 @@ log_group::internal_print(const HashString* hash, const char* subsystem, const v
 
 void
 log_initialize() {
-  pthread_mutex_lock(&log_mutex);
+  auto lock = std::scoped_lock(log_mutex);
 
   LOG_CASCADE(LOG_CRITICAL);
 
@@ -221,28 +210,25 @@ log_initialize() {
   std::sort(log_children.begin(), log_children.end());
 
   log_rebuild_cache();
-  pthread_mutex_unlock(&log_mutex);
 }
 
 void
 log_cleanup() {
-  pthread_mutex_lock(&log_mutex);
+  auto lock = std::scoped_lock(log_mutex);
 
   std::fill(log_groups.begin(), log_groups.end(), log_group());
 
   log_outputs.clear();
   log_children.clear();
 
-  std::for_each(log_cache.begin(), log_cache.end(), std::mem_fun_ref(&log_cache_entry::clear));
+  std::for_each(log_cache.begin(), log_cache.end(), std::mem_fn(&log_cache_entry::clear));
   log_cache.clear();
-
-  pthread_mutex_unlock(&log_mutex);
 }
 
 log_output_list::iterator
 log_find_output_name(const char* name) {
-  log_output_list::iterator itr = log_outputs.begin();
-  log_output_list::iterator last = log_outputs.end();
+  auto itr = log_outputs.begin();
+  auto last = log_outputs.end();
 
   while (itr != last && itr->first != name)
     itr++;
@@ -251,15 +237,14 @@ log_find_output_name(const char* name) {
 }
 
 void
-log_open_output(const char* name, log_slot slot) {
-  pthread_mutex_lock(&log_mutex);
+log_open_output(const char* name, const log_slot& slot) {
+  auto lock = std::scoped_lock(log_mutex);
 
   if (log_outputs.size() >= log_group::max_size_outputs()) {
-    pthread_mutex_unlock(&log_mutex);
     throw input_error("Cannot open more than 64 log output handlers.");
   }
-  
-  log_output_list::iterator itr = log_find_output_name(name);
+
+  auto itr = log_find_output_name(name);
 
   if (itr == log_outputs.end()) {
     log_outputs.emplace_back(name, slot);
@@ -270,54 +255,45 @@ log_open_output(const char* name, log_slot slot) {
   }
 
   log_rebuild_cache();
-
-  pthread_mutex_unlock(&log_mutex);
 }
 
 void
 log_close_output(const char* name) {
-  pthread_mutex_lock(&log_mutex);
+  auto lock = std::scoped_lock(log_mutex);
 
-  log_output_list::iterator itr = log_find_output_name(name);
+  auto itr = log_find_output_name(name);
 
   if (itr != log_outputs.end())
     log_outputs.erase(itr);
-
-  pthread_mutex_unlock(&log_mutex);
 }
 
 void
 log_add_group_output(int group, const char* name) {
-  pthread_mutex_lock(&log_mutex);
+  auto lock = std::scoped_lock(log_mutex);
 
-  log_output_list::iterator itr = log_find_output_name(name);
+  auto itr = log_find_output_name(name);
   size_t index = std::distance(log_outputs.begin(), itr);
 
-  if (itr == log_outputs.end()) {
-    pthread_mutex_unlock(&log_mutex);
-    throw input_error("Log name not found.");
-  }
+  if (itr == log_outputs.end())
+    throw input_error("Log name not found: '" + std::string(name) + "'");
 
-  if (index >= log_group::max_size_outputs()) {
-    pthread_mutex_unlock(&log_mutex);
+  if (index >= log_group::max_size_outputs())
     throw input_error("Cannot add more log group outputs.");
-  }
 
   log_groups[group].set_output_at(index, true);
   log_rebuild_cache();
-
-  pthread_mutex_unlock(&log_mutex);
 }
 
 void
-log_remove_group_output(int group, const char* name) {
+log_remove_group_output([[maybe_unused]] int group, [[maybe_unused]] const char* name) {
 }
 
 // The log_children list is <child, group> since we build the output
 // cache by crawling from child to parent.
 void
 log_add_child(int group, int child) {
-  pthread_mutex_lock(&log_mutex);
+  auto lock = std::scoped_lock(log_mutex);
+
   if (std::find(log_children.begin(), log_children.end(), std::make_pair(group, child)) != log_children.end())
     return;
 
@@ -325,23 +301,22 @@ log_add_child(int group, int child) {
   std::sort(log_children.begin(), log_children.end());
 
   log_rebuild_cache();
-  pthread_mutex_unlock(&log_mutex);
 }
 
 void
-log_remove_child(int group, int child) {
+log_remove_child([[maybe_unused]] int group, [[maybe_unused]] int child) {
   // Remove from all groups, then modify all outputs.
 }
 
 void
-log_file_write(std::shared_ptr<std::ofstream>& outfile, const char* data, size_t length, int group) {
+log_file_write(const std::shared_ptr<std::ofstream>& outfile, const char* data, size_t length, int group) {
   // Add group name, data, etc as flags.
 
   // Normal groups are nul-terminated strings.
   if (group >= LOG_NON_CASCADING) {
-    *outfile << cachedTime.seconds() << ' ' << data << std::endl;
+    *outfile << this_thread::cached_seconds().count() << ' ' << data << std::endl;
   } else if (group >= 0) {
-    *outfile << cachedTime.seconds() << ' ' << log_level_char[group % 6] << ' ' << data << std::endl;
+    *outfile << this_thread::cached_seconds().count() << ' ' << log_level_char[group % 6] << ' ' << data << std::endl;
   } else if (group == -1) {
     *outfile << "---DUMP---" << std::endl;
     if (length != 0) {
@@ -353,28 +328,29 @@ log_file_write(std::shared_ptr<std::ofstream>& outfile, const char* data, size_t
 }
 
 void
-log_gz_file_write(std::shared_ptr<log_gz_output>& outfile, const char* data, size_t length, int group) {
+log_gz_file_write(const std::shared_ptr<log_gz_output>& outfile, const char* data, size_t length, int group) {
   char buffer[64];
 
   // Normal groups are nul-terminated strings.
   if (group >= 0) {
-    int buffer_length = snprintf(buffer, 64, GROUPFMT,
-                                 cachedTime.seconds(),
+    int buffer_length = snprintf(buffer, 64,
+                                 (group >= LOG_NON_CASCADING) ? ("%" PRIi64 " ") : ("%" PRIi64 " %c "),
+                                 (int64_t)this_thread::cached_seconds().count(),
                                  log_level_char[group % 6]);
-    
-    if (buffer_length > 0)
-      gzwrite(outfile->gz_file, buffer, buffer_length);
 
-    gzwrite(outfile->gz_file, data, length);
-    gzwrite(outfile->gz_file, "\n", 1);
+    if (buffer_length > 0)
+      gzwrite(outfile->gz_file.get(), buffer, buffer_length);
+
+    gzwrite(outfile->gz_file.get(), data, length);
+    gzwrite(outfile->gz_file.get(), "\n", 1);
 
   } else if (group == -1) {
-    gzwrite(outfile->gz_file, "---DUMP---\n", sizeof("---DUMP---\n") - 1);
-    
-    if (length != 0)
-      gzwrite(outfile->gz_file, data, length);
+    gzwrite(outfile->gz_file.get(), "---DUMP---\n", sizeof("---DUMP---\n") - 1);
 
-    gzwrite(outfile->gz_file, "---END---\n", sizeof("---END---\n") - 1);
+    if (length != 0)
+      gzwrite(outfile->gz_file.get(), data, length);
+
+    gzwrite(outfile->gz_file.get(), "---END---\n", sizeof("---END---\n") - 1);
   }
 }
 
@@ -383,20 +359,17 @@ log_open_file_output(const char* name, const char* filename, bool append) {
   std::ios_base::openmode mode = std::ofstream::out;
   if (append)
     mode |= std::ofstream::app;
-  std::shared_ptr<std::ofstream> outfile(new std::ofstream(filename, mode));
+  auto outfile = std::make_shared<std::ofstream>(filename, mode);
 
   if (!outfile->good())
     throw input_error("Could not open log file '" + std::string(filename) + "'.");
 
-  log_open_output(name, std::bind(&log_file_write, outfile,
-                                  std::placeholders::_1,
-                                  std::placeholders::_2,
-                                  std::placeholders::_3));
+  log_open_output(name, [outfile](auto d, auto l, auto g) { log_file_write(outfile, d, l, g); });
 }
 
 void
 log_open_gz_file_output(const char* name, const char* filename, bool append) {
-  std::shared_ptr<log_gz_output> outfile(new log_gz_output(filename, append));
+  auto outfile = std::make_shared<log_gz_output>(filename, append);
 
   if (!outfile->is_valid())
     throw input_error("Could not open log gzip file '" + std::string(filename) + "'.");
@@ -404,10 +377,7 @@ log_open_gz_file_output(const char* name, const char* filename, bool append) {
   // if (!outfile->set_buffer(1 << 14))
   //   throw input_error("Could not set gzip log file buffer size.");
 
-  log_open_output(name, std::bind(&log_gz_file_write, outfile,
-                                  std::placeholders::_1,
-                                  std::placeholders::_2,
-                                  std::placeholders::_3));
+  log_open_output(name, [outfile](auto d, auto l, auto g) { log_gz_file_write(outfile, d, l, g); });
 }
 
 }
