@@ -2,8 +2,9 @@
 
 #include "log_buffer.h"
 
+#include <algorithm>
+
 #include "log.h"
-#include "globals.h"
 
 namespace torrent {
 
@@ -13,7 +14,7 @@ log_buffer::find_older(int32_t older_than) {
   if (empty() || !back().is_younger_than(older_than))
     return end();
 
-  return std::find_if(begin(), end(), std::bind(&log_entry::is_younger_or_same, std::placeholders::_1, older_than));
+  return std::find_if(begin(), end(), [older_than](const auto& entry) { return entry.is_younger_or_same(older_than); });
 }
 
 void
@@ -26,7 +27,7 @@ log_buffer::lock_and_push_log(const char* data, size_t length, int group) {
   if (size() >= max_size())
     base_type::pop_front();
 
-  base_type::push_back(log_entry(cachedTime.seconds(), group % 6, std::string(data, length)));
+  base_type::push_back(log_entry(this_thread::cached_seconds().count(), group % 6, std::string(data, length)));
 
   if (m_slot_update)
     m_slot_update();
@@ -44,8 +45,7 @@ log_open_log_buffer(const char* name) {
   // TODO: Deregister when deleting.
   auto buffer = log_buffer_ptr(new log_buffer, std::bind(&log_buffer_deleter, std::placeholders::_1));
 
-  log_open_output(name, std::bind(&log_buffer::lock_and_push_log, buffer.get(),
-                                  std::placeholders::_1, std::placeholders::_2, std::placeholders::_3));
+  log_open_output(name, [b = buffer.get()](auto d, auto l, auto g) { b->lock_and_push_log(d, l, g); });
   return buffer;
 }
 
