@@ -1,39 +1,3 @@
-// libTorrent - BitTorrent library
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #include "config.h"
 
 #include <torrent/utils/uri_parser.h>
@@ -42,7 +6,7 @@
 
 #include "rak/string_manip.h"
 
-namespace torrent { namespace utils {
+namespace torrent::utils {
 
 inline bool
 is_unreserved_uri_char(char c) {
@@ -196,4 +160,39 @@ uri_parse_query_str(const char* query, uri_query_state& state) {
   uri_parse_query_str(std::string(query), state);
 }
 
-}}
+std::string
+uri_generate_scrape_url(std::string uri) {
+  size_t delim_slash = uri.rfind('/');
+
+  if (delim_slash == std::string::npos || uri.find("/announce", delim_slash) != delim_slash)
+    throw input_error("Tried to make scrape url from invalid uri.");
+
+  return uri.replace(delim_slash, sizeof("/announce") - 1, "/scrape");
+}
+
+bool
+uri_can_scrape(const std::string& uri) {
+  // TODO: Replace with uri parsers above.
+
+  size_t delim_slash = uri.rfind('/');
+
+  if (delim_slash == std::string::npos)
+    return false;
+
+  // TODO: This should be more robust.
+  return uri.find("/announce", delim_slash) == delim_slash;
+}
+
+bool
+uri_has_query(const std::string& uri) {
+  // TODO: Replace with uri parsers above.
+
+  size_t delim_options = uri.rfind('?');
+
+  if (delim_options == std::string::npos)
+    return false;
+
+  return uri.find('/', delim_options) == std::string::npos;
+}
+
+} // namespace torrent::utils
