@@ -10,11 +10,14 @@ namespace torrent {
 
 class DiffieHellman {
 public:
-  typedef std::unique_ptr<char[]> secret_ptr;
-  typedef std::unique_ptr<void, void (*)(void*)> dh_ptr;
+  using secret_ptr = std::unique_ptr<char[]>;
+  using dh_ptr     = std::unique_ptr<void, void (*)(void*)>;
 
   DiffieHellman(const unsigned char prime[], int primeLength,
                 const unsigned char generator[], int generatorLength);
+  ~DiffieHellman() = default;
+  DiffieHellman(const DiffieHellman&) = delete;
+  DiffieHellman& operator=(const DiffieHellman&) = delete;
 
   bool         is_valid() const;
 
@@ -27,12 +30,9 @@ public:
   std::string  secret_str() const   { return std::string(m_secret.get(), m_size); }
 
 private:
-  DiffieHellman(const DiffieHellman& dh);
-  DiffieHellman& operator = (const DiffieHellman& dh);
-
   dh_ptr       m_dh;
   secret_ptr   m_secret;
-  int          m_size;
+  int          m_size{0};
 };
 
 };
