@@ -38,26 +38,26 @@
 #define LIBTORRENT_QUEUE_BUCKETS_H
 
 #include <algorithm>
+#include <array>
 #include <deque>
-#include lt_tr1_functional
-#include lt_tr1_array
+#include <functional>
 
 namespace torrent {
 
 template <typename Type, typename Constants>
 class queue_buckets : private std::array<std::deque<Type>, Constants::bucket_count> {
 public:
-  typedef std::deque<Type>                                queue_type;
-  typedef std::array<queue_type, Constants::bucket_count> base_type;
+  using queue_type = std::deque<Type>;
+  using base_type  = std::array<queue_type, Constants::bucket_count>;
 
-  typedef Constants constants;
+  using constants = Constants;
 
-  typedef typename queue_type::value_type value_type;
-  typedef typename queue_type::size_type size_type;
-  typedef typename queue_type::difference_type difference_type;
+  using value_type      = typename queue_type::value_type;
+  using size_type       = typename queue_type::size_type;
+  using difference_type = typename queue_type::difference_type;
 
-  typedef typename queue_type::iterator iterator;
-  typedef typename queue_type::const_iterator const_iterator;
+  using iterator       = typename queue_type::iterator;
+  using const_iterator = typename queue_type::const_iterator;
 
   size_type queue_size(int idx)  const { return queue_at(idx).size(); }
   bool      queue_empty(int idx) const { return queue_at(idx).empty(); }
@@ -72,7 +72,7 @@ public:
   value_type       front(int idx)       { return queue_at(idx).front(); }
   value_type       back(int idx)        { return queue_at(idx).back(); }
   const value_type front(int idx) const { return queue_at(idx).front(); }
-  const value_type back(int idx)  const { return queue_at(idx).back(); }
+  value_type back(int idx)  const { return queue_at(idx).back(); }
 
   void pop_front(int idx);
   void pop_back(int idx);
@@ -128,7 +128,7 @@ template<typename QueueBucket, typename Ftor>
 inline std::pair<int, typename QueueBucket::iterator>
 queue_bucket_find_if_in_any(QueueBucket& queues, Ftor ftor) {
   for (int i = 0; i < QueueBucket::constants::bucket_count; i++) {
-    typename QueueBucket::iterator itr = std::find_if(queues.begin(i), queues.end(i), ftor);
+    auto itr = std::find_if(queues.begin(i), queues.end(i), ftor);
 
     if (itr != queues.end(i))
       return std::make_pair(i, itr);
