@@ -1,10 +1,8 @@
 #include "config.h"
 
-#define __STDC_CONSTANT_MACROS
-
 #include <iostream>
 #include <sstream>
-#include <inttypes.h>
+#include <cinttypes>
 #include <torrent/object.h>
 
 #include "object_stream_test.h"
