@@ -1,8 +1,10 @@
-#include "helpers/test_fixture.h"
+#include "test/helpers/test_main_thread.h"
 
-class test_extents : public test_fixture {
+class test_extents : public TestFixtureWithMainThread {
   CPPUNIT_TEST_SUITE(test_extents);
+
   CPPUNIT_TEST(test_basic);
+
   CPPUNIT_TEST_SUITE_END();
 
 public:
