@@ -1,6 +1,6 @@
 #include "helpers/test_fixture.h"
 
-#include "torrent/utils/thread_base.h"
+#include "torrent/utils/thread.h"
 
 class test_tracker_http : public test_fixture {
   CPPUNIT_TEST_SUITE(test_tracker_http);
